pref("browser.phoenix.version", "2026.06.10.1", locked);
pref("toolkit.policies.perUserDir", false, locked); // [HIDDEN] [DEFAULT]
pref("app.support.vendor", "Phoenix - Extended: 2026.06.10.1"); // [EXTENDED-ONLY] [NO-MAIL] [HIDDEN]
pref("distribution.id", "default", locked); // [ANDROID-ONLY] [HIDDEN]
pref("distribution.version", "default", locked); // [ANDROID-ONLY] [HIDDEN]
pref("general.aboutConfig.enable", true, locked); // [DEFAULT - non-Android]
pref("browser.phoenix.status", "000");
pref("network.dns.localDomains", "250analytics.com,a.omappapi.com,activity-stream-icons.services.mozilla.com,ads.allizom.org,ads.mozilla.org,ads.nonprod.webservices.mozgcp.net,ads.prod.webservices.mozgcp.net,ads-img.mozilla.org,analytics.getpocket.com,analytics.google.com,analytics.withgoogle.com,anf1.fuzzing.mozilla.org,anonymco.com,api.divviup.org,asan-nightly-frontend-elb-1348905149.us-east-2.elb.amazonaws.com,braze.com,contile.services.mozilla.com,contile-images.services.mozilla.com,classify-client.nonprod.webservices.mozgcp.net,classify-client.prod.webservices.mozgcp.net,classify-client.services.mozilla.com,crash-reports.allizom.org,crash-reports.mozilla.com,crash-reports-xpsp2.mozilla.com,crash-stacks.mozilla.com,crash-stats.allizom.org,crash-stats.mozilla.com,crash-stats.mozilla.org,dap.services.mozilla.com,dap.nonprod.webservices.mozgcp.net,dap.prod.webservices.mozgcp.net,dap-09-3.api.divviup.org,data.mozilla.com,data-ingestion.prod.dataops.mozgcp.net,dataops.mozgcp.net,dataservices.mozgcp.net,debug-ping-preview.firebaseapp.com,discovery.addons.allizom.org,discovery.addons.mozilla.org,discovery.addons-dev.allizom.org,divviup.org,download-stats.mozilla.org,download-stats.r53-2.services.mozilla.com,experimenter.services.mozilla.com,experimenter.nonprod.webservices.mozgcp.net,experimenter.prod.webservices.mozgcp.net,fhr.data.mozilla.com,fhr.r53-2.services.mozilla.com,firefox-android-home-recommendations.getpocket.com,firefox-dns-perf-test.net,fuzzing.mozilla.org,google-analytics.com,google-analytics-cn.com,googleanalytics.com,googlesyndication.com,googlesyndication-cn.com,googletagmanager.com,googletagmanager-cn.com,googletagservices.com,googletagservices-cn.com,improving.duckduckgo.com,incoming.glean.example.com,incoming.telemetry.mozilla.org,incoming.thunderbird.net,incoming-telemetry.thunderbird.net,ingestion-edge.prod.dataops.mozgcp.net,location.services.mozilla.com,locprod1-elb-eu-west-1.prod.mozaws.net,locprod2-elb-us-west-2.prod.mozaws.net,metrics-content.duckduckgo.com,new-sentry.gitlab.net,nonprod.classify-client.nonprod.webservices.mozgcp.net,normandy.cdn.mozilla.net,normandy.nonprod.cloudops.mozgcp.net,normandy.prod.cloudops.mozgcp.net,normandy-cdn.services.mozilla.com,omappapi.com,pipeline-incoming-prod-elb-149169523.us-west-2.elb.amazonaws.com,prod.ads.prod.webservices.mozgcp.net,prod.classify-client.prod.webservices.mozgcp.net,prod.dap.prod.webservices.mozgcp.net,prod.data-ingestion.prod.dataops.mozgcp.net,prod.dataops.mozgcp.net,prod.experimenter.prod.webservices.mozgcp.net,prod.ingestion-edge.prod.dataops.mozgcp.net,prod.sentry.prod.cloudops.mozgcp.net,prod-classifyclient.normandy.prod.cloudops.mozgcp.net,sdk.iad-05.braze.com,search.r53-2.services.mozilla.com,search.services.mozilla.com,self-repair.mozilla.org,self-repair.r53-2.services.mozilla.com,sentry.gitlab.net,sentry.io,sentry.nonprod.cloudops.mozgcp.net,sentry.prod.cloudops.mozgcp.net,sentry.prod.mozaws.net,sitereview.zscaler.com,snippets.allizom.org,snippets.cdn.mozilla.net,snippets.mozilla.com,snippets-prod.frankfurt.moz.works,snippets-prod.moz.works,snippets-prod.oregon-b.moz.works,snippets-stage.moz.works,snippets-stage.oregon-b.moz.works,snowplow.trx.gitlab.net,snowplowalb-1011729428.us-east-1.elb.amazonaws.com,snowplowprd.trx.gitlab.net,snowplowprdnlb-1490493263.us-east-2.elb.amazonaws.com,socorro.nonprod.webservices.mozgcp.net,socorro.prod.webservices.mozgcp.net,socorro-collector.services.mozilla.com,socorro-webapp-allizom.stage.mozaws.net,socorro-webapp.services.mozilla.com,spocs.getpocket.com,spocs.getpocket.dev,spocs.mozilla.net,ssl.google-analytics.com,ssl-google-analytics.l.google.com,stage.sentry.nonprod.cloudops.mozgcp.net,start.fedoraproject.org,start.thunderbird.net,start.ubuntu.com,start-stage.thunderbird.net,survey.mozilla.com,tagmanager.google.com,talkback.mozilla.org,talkback-public.mozilla.org,talkback-reports.mozilla.org,telemetry-coverage.mozilla.org,telemetry-coverage.r53-2.services.mozilla.com,telemetry-experiment.cdn.mozilla.net,telemetry-incoming.r53-2.services.mozilla.com,telemetry-incoming-a.r53-2.services.mozilla.com,telemetry-incoming-b.r53-2.services.mozilla.com,telemetry-prod-1054754349.us-east-1.elb.amazonaws.com,tiles-cdn.prod.ads.prod.webservices.mozgcp.net,updates.thunderbird.net,updates-stage.thunderbird.net,use-application-dns.net,vf.startpage.com,widgets.getpocket.com,www.250analytics.com,www.anonymco.com,www.google-analytics.com,www.google-analytics-cn.com,www.googleanalytics.com,www.googlesyndication.com,www.googlesyndication-cn.com,www.googletagmanager.com,www.googletagmanager-cn.com,www.googletagservices.com,www.googletagservices-cn.com,www.sentry.io,www-google-analytics.l.google.com,www-googletagmanager.l.google.com"); // [ANDROID-ONLY]
pref("toolkit.aboutLogging.uploadProfileToCloud", false); // [DEFAULT - non-Android]
pref("toolkit.aboutlogging.uploadProfileUrl", ""); // [HIDDEN]
pref("browser.engagement.ctrlTab.has-used", true, locked); // [HIDDEN - Android/Thunderbird]
pref("toolkit.coverage.enabled", false, locked); // [HIDDEN - Android/Thunderbird] [DEFAULT]
pref("toolkit.coverage.endpoint.base", "", locked); // [HIDDEN - Android/Thunderbird] [DEFAULT - Android/Thunderbird]
pref("toolkit.coverage.log-level", 70); // [HIDDEN] Limits logging to fatal only
pref("toolkit.coverage.opt-out", true, locked); // [HIDDEN]
pref("asanreporter.apiurl", "", locked); // [HIDDEN - non-MOZ_ASAN_REPORTER builds] [DEFAULT - non-MOZ_ASAN_REPORTER builds]
pref("asanreporter.clientid", "unknown", locked); // [HIDDEN - non-MOZ_ASAN_REPORTER builds] [DEFAULT]
pref("asanreporter.loglevel", 70); // [HIDDEN]
pref("breakpad.reportURL", "", locked);
pref("browser.crashReports.onDemand", false, locked); // Do not request crash reports for background processes from users https://firefox.settings.services.mozilla.com/v1/buckets/main/collections/crash-reports-ondemand/changeset?_expected=0
pref("browser.crashReports.requestedNeverShowAgain", true, locked); // Do not request crash reports for background processes from users https://searchfox.org/firefox-main/source/toolkit/components/crashes/RemoteSettingsCrashPull.sys.mjs
pref("dom.ipc.tabs.createKillHardCrashReports", false, locked); // [DEFAULT - non-Nightly] Ensure we never try to generate minidumps/crash reports https://searchfox.org/firefox-main/rev/cc4a6379/dom/ipc/ContentParent.cpp#4347
pref("toolkit.crashreporter.include_context_heap", false, locked); // [DEFAULT - non-Nightly]
pref("browser.safebrowsing.features.emailtracking.datacollection.update", false, locked); // [HIDDEN] https://searchfox.org/firefox-main/rev/82e2435f/toolkit/components/url-classifier/SafeBrowsing.sys.mjs#264
pref("captchadetection.actor.enabled", false, locked); // Disable CAPTCHA Detection Pings https://searchfox.org/firefox-main/source/toolkit/components/captchadetection/CaptchaDetectionPingUtils.sys.mjs
pref("captchadetection.hasUnsubmittedData", false, locked); // [HIDDEN] Disable CAPTCHA Detection Pings https://searchfox.org/firefox-main/source/toolkit/components/captchadetection/CaptchaDetectionPingUtils.sys.mjs
pref("captchadetection.loglevel", "Off");
pref("datareporting.dau.cachedUsageProfileID", "beefbeef-beef-beef-beef-beeefbeefbee", locked); // [HIDDEN] https://searchfox.org/firefox-main/rev/82e2435f/toolkit/components/telemetry/app/ClientID.sys.mjs#45
pref("datareporting.dau.cachedUsageProfileGroupID", "b0bacafe-b0ba-cafe-b0ba-cafeb0bacafe", locked); // [HIDDEN] https://searchfox.org/firefox-main/rev/82e2435f/toolkit/components/telemetry/app/ClientID.sys.mjs#46
pref("datareporting.healthreport.uploadEnabled", false, locked); // [DEFAULT - Android] Required for Firefox Labs on Desktop
pref("datareporting.policy.dataSubmissionEnabled", false, locked);
pref("datareporting.policy.dataSubmissionPolicyBypassNotification", true, locked); // [DEFAULT - non-MOZILLA_OFFICIAL builds]
pref("datareporting.policy.firstRunURL", "", locked);
pref("datareporting.usage.uploadEnabled", false, locked); // [HIDDEN - ANDROID] [DEFAULT - Android] Disables "daily usage pings" https://support.mozilla.org/kb/usage-ping-settings
pref("dom.security.unexpected_system_load_telemetry_enabled", false, locked); // [DEFAULT - non-Nightly]
pref("extensions.dataCollectionPermissions.enabled", false, locked); // https://support.mozilla.org/kb/extension-data-collection https://extensionworkshop.com/documentation/develop/firefox-builtin-data-consent/
pref("extensions.gleanPingAddons.daily.interval", 2147483647, locked); // [HIDDEN] Disable the Glean add-on ping scheduler https://searchfox.org/firefox-main/rev/e5219f2a/toolkit/mozapps/extensions/extensions.manifest#1
pref("extensions.gleanPingAddons.updated.delay", 2147483647, locked); // [HIDDEN] https://searchfox.org/firefox-main/rev/e5219f2a/toolkit/mozapps/extensions/AddonManager.sys.mjs#116
pref("extensions.gleanPingAddons.updated.idleTimeout", 2147483647, locked); // [HIDDEN] https://searchfox.org/firefox-main/source/toolkit/mozapps/extensions/AddonManager.sys.mjs#124
pref("extensions.gleanPingAddons.updated.testing", false, locked); // [HIDDEN] [DEFAULT] https://searchfox.org/firefox-main/source/toolkit/mozapps/extensions/AddonManager.sys.mjs#132
pref("extensions.telemetry.EnvironmentAddonBuilder", false, locked); // [HIDDEN - non-Android] [NIGHTLY] Do not use Glean for add-on telemetry https://bugzilla.mozilla.org/show_bug.cgi?id=1981496 https://searchfox.org/firefox-main/rev/d285a4fb/toolkit/mozapps/extensions/AddonManager.sys.mjs#4801
pref("network.jar.record_failure_reason", false, locked); // [DEFAULT - non-Nightly] https://searchfox.org/firefox-release/rev/9d94f5e3/modules/libpref/init/StaticPrefList.yaml#15576
pref("network.traffic_analyzer.enabled", false, locked); // https://searchfox.org/firefox-release/rev/9d94f5e3/modules/libpref/init/StaticPrefList.yaml#14262
pref("nimbus.telemetry.targetingContextEnabled", false, locked); // [HIDDEN - ANDROID/THUNDERBIRD] [DEFAULT - Artifact builds] Targeting context telemetry - https://searchfox.org/firefox-release/rev/9d94f5e3/browser/app/profile/firefox.js#2139
pref("privacy.trackingprotection.emailtracking.data_collection.enabled", false, locked);
pref("telemetry.fog.artifact_build", false, locked); // [DEFAULT - non-Artifact builds] Disable JOG to prevent runtime registration of metrics https://firefox-source-docs.mozilla.org/toolkit/components/glean/dev/jog.html https://firefox-source-docs.mozilla.org/toolkit/components/glean/dev/preferences.html#internal-preferences
pref("telemetry.fog.test.activity_limit", -1, locked); // Disable activity-based ping submission - ex. https://mozilla.github.io/glean/book/user/pings/baseline.html#scheduling
pref("telemetry.fog.test.inactivity_limit", -1, locked); // Disable inactivity-based ping submission - ex. https://mozilla.github.io/glean/book/user/pings/baseline.html#scheduling
pref("telemetry.fog.init_on_shutdown", false, locked); // Prevent Glean from initializing on shutdown https://searchfox.org/firefox-main/rev/82e2435f/toolkit/components/glean/docs/dev/preferences.md#49
pref("telemetry.fog.test.localhost_port", 70000, locked); // Force telemetry pings to be sent to localhost instead of Mozilla's servers, if they're somehow enabled... (port just has to be higher than 0, I chose 70000 as its invalid, locked) - https://searchfox.org/firefox-main/rev/82e2435f/toolkit/components/glean/docs/dev/preferences.md#15
pref("telemetry.glean.internal.finalInactive", false, locked); // [HIDDEN] [DEFAULT] Disable early shutdown pings https://searchfox.org/firefox-main/rev/82e2435f/toolkit/components/glean/xpcom/FOG.cpp#148
pref("telemetry.glean.internal.maxPingsPerMinute", 0, locked); // [HIDDEN] Prevent Glean from sending pings https://searchfox.org/firefox-main/rev/82e2435f/toolkit/components/glean/xpcom/FOG.cpp#133
pref("telemetry.number_of_site_origin.min_interval", 2147483647, locked);
pref("toolkit.content-background-hang-monitor.disabled", true, locked); // BHR https://searchfox.org/firefox-main/rev/82e2435f/toolkit/components/backgroundhangmonitor/BackgroundHangMonitor.cpp#597
pref("toolkit.profiles.newProfileSubmitted", true, locked); // [HIDDEN] Prevent submitting the new profile ping https://searchfox.org/firefox-main/rev/cc4a6379/toolkit/profile/nsToolkitProfileService.cpp#790
pref("toolkit.telemetry.archive.enabled", false, locked); // [HIDDEN - Android]
pref("toolkit.telemetry.bhrPing.enabled", false, locked); // [HIDDEN - Android]
pref("toolkit.telemetry.cachedClientID", "c0ffeec0-ffee-c0ff-eec0-ffeec0ffeec0", locked); // [HIDDEN]
pref("toolkit.telemetry.cachedProfileGroupID", "decafdec-afde-cafd-ecaf-decafdecafde", locked); // [HIDDEN]
pref("toolkit.telemetry.collectInterval", 2147483647, locked); // [HIDDEN]
pref("toolkit.telemetry.dap.helper.hpke", "", locked);
pref("toolkit.telemetry.dap.helper.url", "", locked);
pref("toolkit.telemetry.dap.leader.hpke", "", locked);
pref("toolkit.telemetry.dap.leader.url", "", locked);
pref("toolkit.telemetry.dap.logLevel", "Off");
pref("toolkit.telemetry.dap_enabled", false, locked); // [DEFAULT]
pref("toolkit.telemetry.dap_task1_enabled", false, locked); // [DEFAULT]
pref("toolkit.telemetry.dap_task1_taskid", "", locked); // [DEFAULT]
pref("toolkit.telemetry.dap_visit_counting_enabled", false, locked); // [DEFAULT]
pref("toolkit.telemetry.dap_visit_counting_experiment_list", "[]", locked); // [DEFAULT]
pref("toolkit.telemetry.debugSlowSql", false); // [DEFAULT]
pref("toolkit.telemetry.enabled", false, locked);  // [DEFAULT - non-Nightly]
pref("toolkit.telemetry.eventping.maximumFrequency", 2147483647, locked); // [HIDDEN] Disable `event` pings
pref("toolkit.telemetry.eventping.minimumFrequency", 2147483647, locked); // [HIDDEN] Disable `event` pings
pref("toolkit.telemetry.firstShutdownPing.enabled", false, locked); // [HIDDEN - Android]
pref("toolkit.telemetry.healthping.enabled", false, locked); // [HIDDEN]
pref("toolkit.telemetry.initDelay", 2147483647, locked); // [HIDDEN] Prevent the Telemetry component from initializing
pref("toolkit.telemetry.log.dump", false); // [HIDDEN] [DEFAULT] - To expose via the `about:config`
pref("toolkit.telemetry.log.level", "Fatal"); // [HIDDEN] [Default: Warn]
pref("toolkit.telemetry.minSubsessionLength", 2147483647, locked); // [HIDDEN]
pref("toolkit.telemetry.newProfilePing.delay", 2147483647, locked); // [HIDDEN]
pref("toolkit.telemetry.newProfilePing.enabled", false, locked); // [HIDDEN - Android]
pref("toolkit.telemetry.overrideUpdateChannel", "release", locked); // [HIDDEN] [DEFENSE IN DEPTH] Always report channel as `release`, regardless of actual value https://docs.telemetry.mozilla.org/concepts/channels/channel_normalization
pref("toolkit.telemetry.previousBuildID", "", locked); // [HIDDEN]
pref("toolkit.telemetry.reportingpolicy.firstRun", false, locked); // [HIDDEN]
pref("toolkit.telemetry.scheduler.idleTickInterval", 2147483647, locked); // [HIDDEN]
pref("toolkit.telemetry.scheduler.tickInterval", 2147483647, locked); // [HIDDEN]
pref("toolkit.telemetry.send.overrideOfficialCheck", false, locked); // [HIDDEN] [DEFAULT] Never send pings on unofficial builds - https://firefox-source-docs.mozilla.org/toolkit/components/telemetry/internals/preferences.html
pref("toolkit.telemetry.server", "data;", locked);
pref("toolkit.telemetry.server_owner", "", locked);
pref("toolkit.telemetry.shutdownPingSender.backgroundtask.enabled", false, locked); // [HIDDEN - Android/Thunderbird] [DEFAULT - Desktop Firefox]
pref("toolkit.telemetry.shutdownPingSender.enabled", false, locked); // [HIDDEN - Android]
pref("toolkit.telemetry.shutdownPingSender.enabledFirstSession", false, locked); // [HIDDEN - Android] [DEFAULT]
pref("toolkit.telemetry.testing.disableFuzzingDelay", false, locked); // [HIDDEN] [DEFAULT] [DEFENSE IN DEPTH] Always delay sending pings between 0-1 AM
pref("toolkit.telemetry.testing.overridePreRelease", false, locked); // [HIDDEN] [DEFAULT] Never record extended/prelease data on release channels - https://firefox-source-docs.mozilla.org/toolkit/components/telemetry/internals/preferences.html
pref("toolkit.telemetry.testing.overrideProductsCheck", false, locked); // [DEFAULT] Limit probes to only what is supported on the current product - https://firefox-source-docs.mozilla.org/toolkit/components/telemetry/internals/preferences.html
pref("toolkit.telemetry.testing.suppressPingsender", true, locked); // [HIDDEN]
pref("toolkit.telemetry.translations.logLevel", "Off");
pref("toolkit.telemetry.unified", false, locked); // [DEFAULT - Android]
pref("toolkit.telemetry.untrustedModulesPing.frequency", 2147483647, locked); // [HIDDEN]
pref("toolkit.telemetry.updatePing.enabled", false, locked); // [HIDDEN - Android]
pref("toolkit.telemetry.user_characteristics_ping.current_version", 0, locked); // [DEFAULT]
pref("toolkit.telemetry.user_characteristics_ping.last_version_sent", 0, locked); // [DEFAULT]
pref("toolkit.telemetry.user_characteristics_ping.logLevel", "Off");
pref("toolkit.telemetry.user_characteristics_ping.opt-out", true, locked);
pref("toolkit.telemetry.user_characteristics_ping.send-once", false, locked); // [DEFAULT]
pref("toolkit.telemetry.user_characteristics_ping.uuid", "", locked); // [DEFAULT]
pref("urlclassifier.features.emailtracking.datacollection.allowlistTables", "", locked); // https://searchfox.org/firefox-main/rev/82e2435f/toolkit/components/url-classifier/SafeBrowsing.sys.mjs#264
pref("urlclassifier.features.emailtracking.datacollection.blocklistTables", "", locked); // https://searchfox.org/firefox-main/rev/82e2435f/toolkit/components/url-classifier/SafeBrowsing.sys.mjs#264
pref("app.normandy.run_interval_seconds", 0, locked); // [HIDDEN - Android/Thunderbird] Prevent fetching experiments - This pref is also used by Nimbus https://searchfox.org/firefox-main/rev/82e2435f/toolkit/components/nimbus/lib/RemoteSettingsExperimentLoader.sys.mjs#801
pref("app.shield.optoutstudies.enabled", false, locked); // [HIDDEN - Android/Thunderbird] Required for Firefox Labs on Desktop
pref("extensions.formautofill.addresses.experiments.enabled", false, locked); // [DEFAULT - non-Android] Prevent Nimbus from dictating whether address autofill can be used (this ensures the value set at `extensions.formautofill.addresses.supported` is always used instead, locked) https://searchfox.org/firefox-main/rev/c983b985/toolkit/components/formautofill/FormAutofill.sys.mjs#133 https://searchfox.org/firefox-main/rev/c983b985/toolkit/components/nimbus/FeatureManifest.yaml#2033
pref("messaging-system.rsexperimentloader.collection_id", ""); // [DEFAULT: `nimbus-desktop-experiments`] Required for Firefox Labs on Desktop
pref("nimbus.appId", ""); // [HIDDEN] [DEFAULT: `firefox-desktop`] Required for Firefox Labs on Desktop
pref("nimbus.firstUpdateComplete", true, locked); // [HIDDEN - non-Firefox Desktop] Ensure we skip Nimbus enrollment/set-up https://bugzilla.mozilla.org/show_bug.cgi?id=2032544 https://searchfox.org/firefox-main/rev/90143df1/toolkit/components/nimbus/lib/ExperimentManager.sys.mjs#235
pref("nimbus.profileId", "");
pref("nimbus.profileId", "", locked); // [HIDDEN] https://searchfox.org/firefox-main/rev/82e2435f/toolkit/components/nimbus/ExperimentAPI.sys.mjs#80 - We also set this as a "user" pref to ensure that Firefox properly uses/recognizes it
pref("nimbus.profilesdatastoreservice.enabled", false, locked); // Disable writing to the NimbusEnrollments table database https://searchfox.org/firefox-main/rev/16707ce1/toolkit/components/nimbus/lib/Enrollments.sys.mjs#617
pref("nimbus.profilesdatastoreservice.read.enabled", false, locked); // Disable reading from the NimbusEnrollments table database https://searchfox.org/firefox-main/rev/16707ce1/toolkit/components/nimbus/lib/Enrollments.sys.mjs#628
pref("nimbus.profilesdatastoreservice.sync.enabled", false, locked); // Disable syncing NimbusEnrollments data https://searchfox.org/firefox-main/rev/16707ce1/toolkit/components/nimbus/lib/RemoteSettingsExperimentLoader.sys.mjs#425 https://searchfox.org/firefox-main/rev/16707ce1/toolkit/components/nimbus/lib/Enrollments.sys.mjs#638
pref("nimbus.rollouts.enabled", false, locked); // [HIDDEN - non-Firefox Desktop] Nimbus rollouts/"remote improvements" (A/B Testing, locked) https://support.mozilla.org/kb/remote-improvements
pref("network.ohttp.configURL", "", locked); // [ANDROID-ONLY]
pref("network.ohttp.relayURL", "", locked); // [ANDROID-ONLY]
pref("dom.origin-trials.enabled", false);
pref("app.distributor", "", locked); // [HIDDEN] [DEFAULT]
pref("app.distributor.channel", "", locked); // [HIDDEN] [DEFAULT]
pref("mozilla.partner.id", "", locked); // [HIDDEN] [DEFAULT]
pref("browser.phoenix.status", "001");
pref("extensions.recommendations.privacyPolicyUrl", ""); // [DEFAULT - Android]
pref("extensions.getAddons.langpacks.url", ""); // [ANDROID-ONLY] Functionality isn't supported on Android, so no need to connect there - ex. https://services.addons.mozilla.org/api/v4/addons/language-tools/?app=android&type=language&appversion=138.0.1
pref("browser.preonboarding.enabled", false); // [HIDDEN - Android/Thunderbird] [DEFAULT - Linux] Disable the preonboarding modal https://searchfox.org/firefox-main/rev/82e2435f/toolkit/components/nimbus/FeatureManifest.yaml#874 https://searchfox.org/firefox-main/rev/643d7328/toolkit/components/telemetry/app/TelemetryReportingPolicy.sys.mjs#638
pref("browser.discovery.enabled", false, locked); // [HIDDEN - Android/Thunderbird] [DEFAULT - Android/Thunderbird]
pref("browser.translations.mostRecentTargetLanguages", "en-US"); // https://searchfox.org/firefox-main/rev/4258ca07/browser/components/enterprisepolicies/Policies.sys.mjs#2829
pref("browser.translations.panelShown", true, locked); // [HIDDEN]
pref("extensions.getAddons.browseAddons", ""); // [HIDDEN - non-Android]
pref("extensions.getAddons.discovery.api_url", "data;");
pref("extensions.getAddons.showPane", false); // [HIDDEN]
pref("extensions.htmlaboutaddons.recommendations.enabled", false);
pref("extensions.recommendations.hideNotice", true, locked); // [HIDDEN] "Some of these recommendations are personalized..." banner
pref("extensions.recommendations.themeRecommendationUrl", "");
pref("extensions.ui.lastCategory", "addons://list/extension"); // [HIDDEN] [DEFAULT = `addons://discover/`] Ensure default view of `about:addons` is always local/installed extensions
pref("extensions.webservice.discoverURL", ""); // [HIDDEN - non-Thunderbird]
pref("doh-rollout._testing", false); // [HIDDEN] [DEFAULT]
pref("doh-rollout.disable-heuristics", true, locked); // [HIDDEN]
pref("doh-rollout.doneFirstRun", true, locked); // [HIDDEN]
pref("doh-rollout.enabled", false, locked); // [HIDDEN]
pref("doh-rollout.provider-steering.enabled", false, locked); // [HIDDEN]
pref("doh-rollout.provider-steering.provider-list", "", locked); // [HIDDEN]
pref("doh-rollout.self-enabled", false, locked); // [HIDDEN]
pref("doh-rollout.skipHeuristicsCheck", true, locked); // [HIDDEN]
pref("doh-rollout.trr-selection.enabled", false, locked); // [HIDDEN]
pref("doh-rollout.trr-selection.provider-list", "", locked); // [HIDDEN]
pref("network.android_doh.autoselect_enabled", false, locked); // [ANDROID-ONLY] https://searchfox.org/firefox-main/rev/82e2435f/mobile/android/geckoview/src/main/java/org/mozilla/geckoview/GeckoRuntimeSettings.java#1773
pref("doh-rollout.trrRace.canonicalDomain", ""); // [HIDDEN] [Default = firefox-dns-perf-test.net]
pref("doh-rollout.trrRace.complete", true); // [HIDDEN]
pref("doh-rollout.trrRace.enabled", false); // [HIDDEN]
pref("doh-rollout.trrRace.popularDomains", ""); // [HIDDEN]
pref("doh-rollout.trrRace.randomSubdomainCount", 0); // [HIDDEN]
pref("network.essential_domains_fallback", false); // [DEFAULT]
pref("signon.firefoxRelay.allowListRemoteSettingsCollection", ""); // [HIDDEN] [DEFAULT: fxrelay-allowlist]
pref("signon.firefoxRelay.denyListRemoteSettingsCollection", ""); // [HIDDEN] [DEFAULT: fxrelay-denylist]
pref("signon.recipes.remoteRecipes.enabled", false);
pref("devtools.performance.popup.feature-flag", false, locked); // [DEFAULT - non-Nightly/Developer Edition] Ensure we do not add the Profiler UI button https://searchfox.org/firefox-main/rev/5f6d282f/devtools/startup/DevToolsStartup.sys.mjs#713
pref("devtools.performance.recording.ui-base-url", "http://localhost:3"); // See https://searchfox.org/firefox-main/rev/5f6d282f/devtools/startup/DevToolsStartup.sys.mjs#278
pref("logging.config.output_type", "file", locked); // [HIDDEN] Set `about:logging` to log to a file (instead of the Profiler, locked)
pref("toolkit.aboutProcesses.showProfilerIcons", false); // Disables profiler integration/icons at `about:processes`
pref("signon.firefoxRelay.feature", "disabled"); // [HIDDEN - Thunderbird]
pref("gecko.handlerService.defaultHandlersVersion", 2147483647, locked); // [HIDDEN]
pref("toolkit.contentRelevancy.enabled", false, locked); // [HIDDEN - Android/Thunderbird] [DEFAULT]
pref("toolkit.contentRelevancy.ingestEnabled", false, locked); // [HIDDEN - Android/Thunderbird] [DEFAULT]
pref("toolkit.contentRelevancy.log", false); // [HIDDEN - Android/Thunderbird] [DEFAULT]
pref("browser.promo.cookiebanners.enabled", false, locked); // [HIDDEN - Android/Thunderbird] [DEFAULT - Desktop] https://searchfox.org/firefox-main/rev/dc1c78e9/toolkit/modules/BrowserUtils.sys.mjs#756
pref("browser.promo.focus.disallowed_regions", "xx");
pref("browser.promo.focus.enabled", false, locked); // [HIDDEN - Android/Thunderbird] https://searchfox.org/firefox-main/rev/dc1c78e9/toolkit/modules/BrowserUtils.sys.mjs#722
pref("browser.promo.pin.enabled", false, locked); // [HIDDEN - Android/Thunderbird] https://searchfox.org/firefox-main/rev/dc1c78e9/toolkit/modules/BrowserUtils.sys.mjs#734
pref("browser.send_to_device_locales", "", locked); // [HIDDEN - Android/Thunderbird] Disables "Send to Device" email promotions https://searchfox.org/firefox-main/rev/dc1c78e9/browser/app/profile/firefox.js#2503 https://searchfox.org/firefox-main/rev/dc1c78e9/toolkit/modules/BrowserUtils.sys.mjs#789 https://searchfox.org/firefox-main/rev/dc1c78e9/browser/components/preferences/moreFromMozilla.js#273
pref("browser.vpn_promo.disallowed_regions", "xx");
pref("browser.vpn_promo.enabled", false, locked); // [HIDDEN - Android/Thunderbird] https://searchfox.org/firefox-main/rev/dc1c78e9/toolkit/modules/BrowserUtils.sys.mjs#692
pref("pdfjs.enableNewBadge", false, locked); // https://searchfox.org/firefox-main/rev/cdf7090f/toolkit/components/pdfjs/content/web/viewer.mjs#9012
pref("privacy.trackingprotection.allow_list.hasUserInteractedWithETPSettings", true, locked); // Disables nag/onboarding to configure ETP exception lists https://searchfox.org/firefox-main/rev/dc1c78e9/modules/libpref/init/all.js#3342 https://searchfox.org/firefox-main/rev/dc1c78e9/netwerk/url-classifier/UrlClassifierExceptionListService.sys.mjs#200
pref("dom.origin-trials.private-attribution.state", 2, locked); // [DEFAULT]
pref("dom.private-attribution.submission.enabled", false, locked); // [DEFAULT]
pref("toolkit.shopping.ohttpConfigURL", "", locked);
pref("toolkit.shopping.ohttpRelayURL", "", locked);
pref("permissions.manager.remote.enabled", false);
pref("services.settings.preview_enabled", false); // [HIDDEN] [DEFAULT]
pref("extensions.webcompat-reporter.enabled", false); // [DEFAULT - Release/ESR]
pref("extensions.webcompat-reporter.newIssueEndpoint", "https://phoenix.celenity.dev/issues"); // Temporarily override to our URL instead of Mozilla's to work-around upstream bug - https://bugzilla.mozilla.org/show_bug.cgi?id=1963764
pref("media.decoder-doctor.new-issue-endpoint", "https://phoenix.celenity.dev/issues"); // For decoding errors https://searchfox.org/firefox-main/rev/82e2435f/browser/actors/DecoderDoctorParent.sys.mjs#83
pref("extensions.getAddons.cache.enabled", false);
pref("distribution.yandex.removePartnerBookmarks", true, locked);
pref("browser.tabs.remote.separatePrivilegedMozillaWebContentProcess", false, locked); // [DEFAULT - non-Firefox Desktop]
pref("browser.tabs.remote.separatedMozillaDomains", "", locked);
pref("dom.ipc.processCount.privilegedmozilla", 0, locked);
pref("extensions.webextensions.restrictedDomains", "");
pref("permissions.manager.defaultsUrl", ""); // [HIDDEN - Android] [DEFAULT - Android]
pref("svg.context-properties.content.allowed-domains", "", locked); // [DEFAULT - Android/Thunderbird]
pref("xpinstall.whitelist.add", "", locked); // [HIDDEN - non-Android] [DEFAULT - non-Android] Clear default list of sites allowed to install add-ons
pref("browser.backup.template.fallback-download.aurora", "https://www.mozilla.org/firefox/channel/desktop/#developer");
pref("browser.backup.template.fallback-download.beta", "https://www.mozilla.org/firefox/channel/desktop/#beta");
pref("browser.backup.template.fallback-download.esr", "https://www.mozilla.org/firefox/enterprise/#download");
pref("browser.backup.template.fallback-download.nightly", "https://www.mozilla.org/firefox/channel/desktop/#nightly");
pref("browser.backup.template.fallback-download.release", "https://www.mozilla.org/firefox/download/thanks/?s=direct");
pref("extensions.abuseReport.amoFormURL", "https://addons.mozilla.org/feedback/addon/%addonID%/");
pref("extensions.blocklist.addonItemURL", "https://addons.mozilla.org/blocked-addon/%addonID%/%addonVersion%/");
pref("pdfjs.altTextLearnMoreUrl", "https://support.mozilla.org/kb/pdf-alt-text");
pref("pdfjs.commentLearnMoreUrl", "https://support.mozilla.org/kb/view-pdf-files-firefox-or-choose-another-viewer#w_add-a-comment-to-a-pdf");
pref("signon.firefoxRelay.learn_more_url", "https://support.mozilla.org/kb/relay-integration#w_frequently-asked-questions");
pref("signon.firefoxRelay.manage_url", "https://relay.firefox.com/accounts/profile/");
pref("signon.firefoxRelay.privacy_policy_url", "https://www.mozilla.org/privacy/subscription-services/");
pref("signon.firefoxRelay.terms_of_service_url", "https://www.mozilla.org/about/legal/terms/subscription-services/");
pref("extensions.update.background.url", "https://versioncheck-bg.addons.mozilla.org/update/VersionCheck.php?reqVersion=%REQ_VERSION%&id=%ITEM_ID%&version=%ITEM_VERSION%&status=%ITEM_STATUS%&appID=%APP_ID%&appVersion=%APP_VERSION%&currentAppVersion=%CURRENT_APP_VERSION%&updateType=%UPDATE_TYPE%"); // [NO-MAIL] Removes maximum app/browser version (maxAppVersion), operating system (appOS), ABI (appABI), locale (locale), and compatibility mode (compatMode)
pref("extensions.update.url", "https://versioncheck.addons.mozilla.org/update/VersionCheck.php?reqVersion=%REQ_VERSION%&id=%ITEM_ID%&version=%ITEM_VERSION%&status=%ITEM_STATUS%&appID=%APP_ID%&appVersion=%APP_VERSION%&currentAppVersion=%CURRENT_APP_VERSION%&updateType=%UPDATE_TYPE%"); // [NO-MAIL] Removes maximum app/browser version (maxAppVersion), operating system (appOS), ABI (appABI), locale (locale), and compatibility mode (compatMode)
pref("extensions.getAddons.search.browseURL", "https://addons.mozilla.org/android/search?q=%TERMS%"); // [ANDROID-ONLY]
pref("datareporting.policy.dataSubmissionPolicyAcceptedVersion", 999, locked);
pref("datareporting.policy.dataSubmissionPolicyNotifiedTime", "32503679999000", locked);
pref("termsofuse.acceptedDate", "32503679999000", locked); // [HIDDEN - Android/Thunderbird]
pref("termsofuse.acceptedVersion", 999, locked); // [HIDDEN - Android/Thunderbird]
pref("termsofuse.bypassNotification", true, locked); // [HIDDEN - Android/Thunderbird] [DEFAULT - builds without MOZILLA_OFFICIAL]
pref("browser.phoenix.status", "002");
pref("urlclassifier.trackingAnnotationTable.testEntries", ""); // [HIDDEN] [DEFAULT]
pref("privacy.rejectForeign.allowList", ""); // [DEFAULT]
pref("urlclassifier.features.consentmanager.annotate.skipURLs", ""); // [HIDDEN] [DEFAULT]
pref("urlclassifier.features.cryptomining.skipURLs", ""); // [HIDDEN] [DEFAULT]
pref("urlclassifier.features.emailtracking.skipURLs", ""); // [HIDDEN] [DEFAULT]
pref("urlclassifier.features.fingerprinting.skipURLs", ""); // [HIDDEN] [DEFAULT]
pref("urlclassifier.features.socialtracking.skipURLs", ""); // [HIDDEN] [DEFAULT]
pref("urlclassifier.trackingSkipURLs", ""); // [HIDDEN] [DEFAULT]
pref("privacy.trackingprotection.allow_list.convenience.enabled", false);
pref("browser.contentblocking.category", "strict", locked); // [HIDDEN]
pref("privacy.trackingprotection.harmfuladdon.enabled", true); // [DEFAULT - Desktop Firefox] https://searchfox.org/firefox-main/rev/93aad2a6615f670b1279c229dd37f7397236131a/browser/app/profile/firefox.js#2434
pref("privacy.trackingprotection.consentmanager.annotate_channels", true); // [DEFAULT]
pref("privacy.trackingprotection.consentmanager.skip.enabled", false); // [DEFAULT]
pref("privacy.trackingprotection.consentmanager.skip.pbmode.enabled", false);
pref("privacy.trackingprotection.cryptomining.enabled", true); // [DEFAULT - non-Thunderbird]
pref("privacy.trackingprotection.emailtracking.enabled", true);
pref("privacy.trackingprotection.emailtracking.pbmode.enabled", true); // [DEFAULT]
pref("privacy.trackingprotection.antifraud.annotate_channels", true); // [DEFAULT] [NIGHTLY]
pref("privacy.trackingprotection.antifraud.skip.enabled", false); // [DEFAULT] [NIGHTLY]
pref("privacy.trackingprotection.antifraud.skip.pbmode.enabled", false); // [NIGHTLY]
pref("privacy.trackingprotection.fingerprinting.enabled", true); // [DEFAULT - non-Thunderbird]
pref("privacy.trackingprotection.socialtracking.enabled", true);
pref("privacy.trackingprotection.annotate_channels", true); // [DEFAULT]
pref("privacy.trackingprotection.enabled", true);
pref("privacy.trackingprotection.pbmode.enabled", true); // [DEFAULT - non-Android]
pref("privacy.annotate_channels.strict_list.enabled", true); // [DEFAULT - Android]
pref("privacy.annotate_channels.strict_list.pbmode.enabled", true); // [DEFAULT]
pref("network.cookie.cookieBehavior.trackerCookieBlocking", true); // [HIDDEN - Android/Thunderbird] [DEFAULT - Desktop]
pref("privacy.socialtracking.block_cookies.enabled", true); // [DEFAULT]
pref("privacy.bounceTrackingProtection.mode", 1); // [DEFAULT - Nightly]
pref("privacy.bounceTrackingProtection.requireStatefulBounces", false); // [ESR] Protect against all bounce trackers, instead of just those who access cookies/storage https://searchfox.org/firefox-main/rev/dc1c78e9/toolkit/components/nimbus/FeatureManifest.yaml#4930
pref("privacy.query_stripping.enabled", true);
pref("privacy.query_stripping.enabled.pbmode", true);
pref("privacy.query_stripping.redirect", true); // [DEFAULT]
pref("extensions.webcompat.enable_interventions", true); // [HIDDEN] [DEFAULT - non-Thunderbird]
pref("extensions.webcompat.enable_shims", true); // [HIDDEN] [DEFAULT - non-Thunderbird]
pref("extensions.webcompat.perform_injections", true); // [HIDDEN] [DEFAULT - non-Thunderbird]
pref("extensions.webcompat.perform_ua_overrides", true); // [HIDDEN] [DEFAULT - non-Thunderbird]
pref("extensions.webcompat.smartblockEmbeds.enabled", true); // [HIDDEN - Android/Thunderbird] [DEFAULT - Desktop] - Enables Embeds/Placeholders to make certain resources click to load
pref("network.fetch.cache_partition_cross_origin", true); // [DEFAULT] Cross origin fetch/XHR requests
pref("privacy.partition.always_partition_third_party_non_cookie_storage", true); // [DEFAULT]
pref("privacy.partition.always_partition_third_party_non_cookie_storage.exempt_sessionstorage", false); // [DEFAULT]
pref("privacy.partition.bloburl_per_partition_key", true); // [DEFAULT]
pref("privacy.partition.serviceWorkers", true); // [DEFAULT]
pref("privacy.partition.network_state", true); // [ESR] [DEFAULT]
pref("privacy.partition.network_state.ocsp_cache", true); // [ESR] [DEFAULT]
pref("privacy.partition.network_state.ocsp_cache.pbmode", true); // [ESR] [DEFAULT]
pref("privacy.fingerprintingProtection", true);
pref("privacy.fingerprintingProtection.pbmode", true); // [DEFAULT]
pref("privacy.reduceTimerPrecision", true); // [DEFAULT]
pref("privacy.resistFingerprinting", false); // [DEFAULT] Ensure RFP isn't enabled by default
pref("privacy.resistFingerprinting.pbmode", false); // [DEFAULT] Ensure RFP isn't enabled for private browsing windows by default
pref("network.cookie.cookieBehavior", 5); // [DEFAULT - non-Thunderbird]
pref("network.cookie.cookieBehavior.optInPartitioning", true);
pref("network.cookie.cookieBehavior.optInPartitioning.pbmode", true);
pref("network.cookie.cookieBehavior.pbmode", 5); // [DEFAULT - non-Thunderbird]
pref("network.http.referer.disallowCrossSiteRelaxingDefault", true); // [DEFAULT] - for cross-site requests
pref("network.http.referer.disallowCrossSiteRelaxingDefault.pbmode", true); // [DEFAULT] - for cross-site requests in Private Browsing
pref("network.http.referer.disallowCrossSiteRelaxingDefault.pbmode.top_navigation", true); // [DEFAULT] - for top navigations in Private Browsing
pref("network.http.referer.disallowCrossSiteRelaxingDefault.top_navigation", true); // for top navigations
pref("privacy.trackingprotection.allow_list.baseline.enabled", true); // [DEFAULT]
pref("privacy.trackingprotection.allow_list.hasMigratedCategoryPrefs", true, locked); // Skip migration, so that `privacy.trackingprotection.allow_list.baseline.enabled` isn't overriden to `false` https://searchfox.org/firefox-main/rev/dc1c78e9/netwerk/url-classifier/UrlClassifierExceptionListService.sys.mjs#254
pref("privacy.trackingprotection.lower_network_priority", true);
pref("browser.phoenix.status", "003");
pref("dom.webmidi.enabled.0.NOTE", "Changing this value is unnecessary...");
pref("dom.webmidi.enabled.1.NOTE", "and WILL aid fingerprinting.");
pref("dom.webmidi.enabled.2.NOTE", "Set 'dom.sitepermsaddon-provider.enabled' to 'false'...");
pref("dom.webmidi.enabled.3.NOTE", "and 'dom.webmidi.gated' to 'true' instead.");
pref("geo.enabled.0.NOTE", "Changing this value is unnecessary...");
pref("geo.enabled.1.NOTE", "and WILL aid fingerprinting.");
pref("geo.enabled.2.NOTE", "Use the 'Location' site setting instead."); // [ANDROID-ONLY]
pref("gfx.bundled-fonts.activate", 1);
pref("webgl.disable-fail-if-major-performance-caveat", true); // [DEFAULT]
pref("media.benchmark.vp9.threshold", 0);
pref("browser.theme.unified-color-scheme", false); // [HIDDEN - non-Thunderbird] [DEFAULT - non-Thunderbird]
pref("javascript.options.use_fdlibm_for_sin_cos_tan", true); // [DEFAULT - non-Windows]
pref("layout.css.prefers-color-scheme.content-override", 1);
pref("general.useragent.compatMode.firefox", true); // [NO-MAIL]
pref("font.name-list.emoji", "Noto Color Emoji"); // [ANDROID-ONLY]
pref("privacy.resistFingerprinting.letterboxing", true); // [ANDROID-ONLY] [HIDDEN] This doesn't have a noticeable effect on Android - but it's still referenced by toolkit code, so let's just ensure it's enabled/active for good measure
pref("privacy.resistFingerprinting.letterboxing", true); // [EXTENDED-ONLY]
pref("privacy.fingerprintingProtection.overrides", "+AllTargets,-CanvasExtractionBeforeUserInputIsBlocked,-CSSPrefersColorScheme,-EfficientCanvasRandomization,-FrameRate,-CanvasImageExtractionPrompt"); // [EXTENDED-ONLY] [ANDROID-ONLY]
pref("layout.css.font-visibility", 2);
pref("general.useragent.use_device", false); // [ANDROID-ONLY] [HIDDEN] [DEFAULT]
pref("media.devices.enumerate.legacy.enabled", false); // [DEFAULT]
pref("webgl.enable-renderer-query", false); // Spoofs "Vendor" and "Renderer" to "Mozilla" (Like the `WebGLRenderInfo` target does)
pref("webgl.override-unmasked-renderer", "Mozilla"); // Spoofs "Unmasked Renderer" Debug info to "Mozilla" (like FPP/RFP does for the WebGL renderer query)
pref("webgl.override-unmasked-vendor", "Mozilla"); // Spoofs "Unmasked Vendor" Debug info to "Mozilla" (like FPP/RFP does for the WebGL renderer query)
pref("webgl.sanitize-unmasked-renderer", false); // Prevents the "Unmasked Renderer" under Debug Info from being set to "Generic Renderer"; we instead set it to "Mozilla" to always match FPP/RFP
pref("dom.ipc.processPrelaunch.enabled", false);
pref("dom.ipc.processPrelaunch.fission.number", 0);
pref("widget.non-native-theme.use-theme-accent", false); // [DEFAULT - non-Thunderbird Windows]
pref("browser.display.document_color_use", 1); // [DEFAULT - non-Windows] Contrast Control https://github.com/arkenfox/user.js/issues/1965
pref("ui.use_standins_for_native_colors", true);
pref("browser.display.use_system_colors", false); // [ESR] [DEFAULT - non-Windows]
pref("privacy.spoof_english", 0); // [DEFAULT]
pref("privacy.fingerprintingProtection.granularOverrides.0.example", '[{"firstPartyDomain":"example1.invalid","overrides":"+ProtectionIWantToEnableOnThisWebsite,-ProtectionIWantToDisableOnThisWebsite"},{"firstPartyDomain":"*","thirdPartyDomain":"example2.invalid","overrides":"+ThirdPartyDomainsAreSupportedToo"}]', locked);
pref("privacy.fingerprintingProtection.overrides.0.example", "+ProtectionIWantToEnableGlobally,-ProtectionIWantToDisableGlobally", locked);
pref("privacy.resistFingerprinting.randomization.daily_reset.enabled", true); // [DEFAULT]
pref("privacy.resistFingerprinting.randomization.daily_reset.private.enabled", true); // [DEFAULT]
pref("browser.startup.blankWindow", false); // [DEFAULT - non-Windows, non-Linux Nightly]
pref("privacy.window.maxInnerHeight", 900); // [DEFAULT - non-Android/Thunderbird]
pref("privacy.window.maxInnerWidth", 1600);
pref("dom.quotaManager.temporaryStorage.fixedLimit", 52428800); // Ex. matches what Tor Browser uses & what Firefox uses by default in most cases
pref("privacy.fingerprintingProtection.granularOverrides", '[{"firstPartyDomain":"google.ad","overrides":"+CanvasRandomization"},{"firstPartyDomain":"google.ae","overrides":"+CanvasRandomization"},{"firstPartyDomain":"google.al","overrides":"+CanvasRandomization"},{"firstPartyDomain":"google.am","overrides":"+CanvasRandomization"},{"firstPartyDomain":"google.as","overrides":"+CanvasRandomization"},{"firstPartyDomain":"google.at","overrides":"+CanvasRandomization"},{"firstPartyDomain":"google.az","overrides":"+CanvasRandomization"},{"firstPartyDomain":"google.ba","overrides":"+CanvasRandomization"},{"firstPartyDomain":"google.be","overrides":"+CanvasRandomization"},{"firstPartyDomain":"google.bf","overrides":"+CanvasRandomization"},{"firstPartyDomain":"google.bg","overrides":"+CanvasRandomization"},{"firstPartyDomain":"google.bi","overrides":"+CanvasRandomization"},{"firstPartyDomain":"google.bj","overrides":"+CanvasRandomization"},{"firstPartyDomain":"google.bs","overrides":"+CanvasRandomization"},{"firstPartyDomain":"google.bt","overrides":"+CanvasRandomization"},{"firstPartyDomain":"google.by","overrides":"+CanvasRandomization"},{"firstPartyDomain":"google.ca","overrides":"+CanvasRandomization"},{"firstPartyDomain":"google.cat","overrides":"+CanvasRandomization"},{"firstPartyDomain":"google.cd","overrides":"+CanvasRandomization"},{"firstPartyDomain":"google.cf","overrides":"+CanvasRandomization"},{"firstPartyDomain":"google.cg","overrides":"+CanvasRandomization"},{"firstPartyDomain":"google.ch","overrides":"+CanvasRandomization"},{"firstPartyDomain":"google.ci","overrides":"+CanvasRandomization"},{"firstPartyDomain":"google.cl","overrides":"+CanvasRandomization"},{"firstPartyDomain":"google.cm","overrides":"+CanvasRandomization"},{"firstPartyDomain":"google.cn","overrides":"+CanvasRandomization"},{"firstPartyDomain":"google.co.ao","overrides":"+CanvasRandomization"},{"firstPartyDomain":"google.co.bw","overrides":"+CanvasRandomization"},{"firstPartyDomain":"google.co.ck","overrides":"+CanvasRandomization"},{"firstPartyDomain":"google.co.cr","overrides":"+CanvasRandomization"},{"firstPartyDomain":"google.co.id","overrides":"+CanvasRandomization"},{"firstPartyDomain":"google.co.il","overrides":"+CanvasRandomization"},{"firstPartyDomain":"google.co.in","overrides":"+CanvasRandomization"},{"firstPartyDomain":"google.co.jp","overrides":"+CanvasRandomization"},{"firstPartyDomain":"google.co.ke","overrides":"+CanvasRandomization"},{"firstPartyDomain":"google.co.kr","overrides":"+CanvasRandomization"},{"firstPartyDomain":"google.co.ls","overrides":"+CanvasRandomization"},{"firstPartyDomain":"google.co.ma","overrides":"+CanvasRandomization"},{"firstPartyDomain":"google.co.mz","overrides":"+CanvasRandomization"},{"firstPartyDomain":"google.co.nz","overrides":"+CanvasRandomization"},{"firstPartyDomain":"google.co.th","overrides":"+CanvasRandomization"},{"firstPartyDomain":"google.co.tz","overrides":"+CanvasRandomization"},{"firstPartyDomain":"google.co.ug","overrides":"+CanvasRandomization"},{"firstPartyDomain":"google.co.uk","overrides":"+CanvasRandomization"},{"firstPartyDomain":"google.co.uz","overrides":"+CanvasRandomization"},{"firstPartyDomain":"google.co.ve","overrides":"+CanvasRandomization"},{"firstPartyDomain":"google.co.vi","overrides":"+CanvasRandomization"},{"firstPartyDomain":"google.co.za","overrides":"+CanvasRandomization"},{"firstPartyDomain":"google.co.zm","overrides":"+CanvasRandomization"},{"firstPartyDomain":"google.co.zw","overrides":"+CanvasRandomization"},{"firstPartyDomain":"google.com","overrides":"+CanvasRandomization"},{"firstPartyDomain":"google.com.af","overrides":"+CanvasRandomization"},{"firstPartyDomain":"google.com.ag","overrides":"+CanvasRandomization"},{"firstPartyDomain":"google.com.ar","overrides":"+CanvasRandomization"},{"firstPartyDomain":"google.com.au","overrides":"+CanvasRandomization"},{"firstPartyDomain":"google.com.bd","overrides":"+CanvasRandomization"},{"firstPartyDomain":"google.com.bh","overrides":"+CanvasRandomization"},{"firstPartyDomain":"google.com.bn","overrides":"+CanvasRandomization"},{"firstPartyDomain":"google.com.bo","overrides":"+CanvasRandomization"},{"firstPartyDomain":"google.com.br","overrides":"+CanvasRandomization"},{"firstPartyDomain":"google.com.bz","overrides":"+CanvasRandomization"},{"firstPartyDomain":"google.com.co","overrides":"+CanvasRandomization"},{"firstPartyDomain":"google.com.cu","overrides":"+CanvasRandomization"},{"firstPartyDomain":"google.com.cy","overrides":"+CanvasRandomization"},{"firstPartyDomain":"google.com.do","overrides":"+CanvasRandomization"},{"firstPartyDomain":"google.com.ec","overrides":"+CanvasRandomization"},{"firstPartyDomain":"google.com.eg","overrides":"+CanvasRandomization"},{"firstPartyDomain":"google.com.et","overrides":"+CanvasRandomization"},{"firstPartyDomain":"google.com.fj","overrides":"+CanvasRandomization"},{"firstPartyDomain":"google.com.gh","overrides":"+CanvasRandomization"},{"firstPartyDomain":"google.com.gi","overrides":"+CanvasRandomization"},{"firstPartyDomain":"google.com.gt","overrides":"+CanvasRandomization"},{"firstPartyDomain":"google.com.hk","overrides":"+CanvasRandomization"},{"firstPartyDomain":"google.com.jm","overrides":"+CanvasRandomization"},{"firstPartyDomain":"google.com.kh","overrides":"+CanvasRandomization"},{"firstPartyDomain":"google.com.kw","overrides":"+CanvasRandomization"},{"firstPartyDomain":"google.com.lb","overrides":"+CanvasRandomization"},{"firstPartyDomain":"google.com.ly","overrides":"+CanvasRandomization"},{"firstPartyDomain":"google.com.mm","overrides":"+CanvasRandomization"},{"firstPartyDomain":"google.com.mt","overrides":"+CanvasRandomization"},{"firstPartyDomain":"google.com.mx","overrides":"+CanvasRandomization"},{"firstPartyDomain":"google.com.my","overrides":"+CanvasRandomization"},{"firstPartyDomain":"google.com.na","overrides":"+CanvasRandomization"},{"firstPartyDomain":"google.com.ng","overrides":"+CanvasRandomization"},{"firstPartyDomain":"google.com.ni","overrides":"+CanvasRandomization"},{"firstPartyDomain":"google.com.np","overrides":"+CanvasRandomization"},{"firstPartyDomain":"google.com.om","overrides":"+CanvasRandomization"},{"firstPartyDomain":"google.com.pa","overrides":"+CanvasRandomization"},{"firstPartyDomain":"google.com.pe","overrides":"+CanvasRandomization"},{"firstPartyDomain":"google.com.pg","overrides":"+CanvasRandomization"},{"firstPartyDomain":"google.com.ph","overrides":"+CanvasRandomization"},{"firstPartyDomain":"google.com.pk","overrides":"+CanvasRandomization"},{"firstPartyDomain":"google.com.pr","overrides":"+CanvasRandomization"},{"firstPartyDomain":"google.com.py","overrides":"+CanvasRandomization"},{"firstPartyDomain":"google.com.qa","overrides":"+CanvasRandomization"},{"firstPartyDomain":"google.com.sa","overrides":"+CanvasRandomization"},{"firstPartyDomain":"google.com.sb","overrides":"+CanvasRandomization"},{"firstPartyDomain":"google.com.sg","overrides":"+CanvasRandomization"},{"firstPartyDomain":"google.com.sl","overrides":"+CanvasRandomization"},{"firstPartyDomain":"google.com.sv","overrides":"+CanvasRandomization"},{"firstPartyDomain":"google.com.tj","overrides":"+CanvasRandomization"},{"firstPartyDomain":"google.com.tr","overrides":"+CanvasRandomization"},{"firstPartyDomain":"google.com.tw","overrides":"+CanvasRandomization"},{"firstPartyDomain":"google.com.ua","overrides":"+CanvasRandomization"},{"firstPartyDomain":"google.com.uy","overrides":"+CanvasRandomization"},{"firstPartyDomain":"google.com.vc","overrides":"+CanvasRandomization"},{"firstPartyDomain":"google.com.vn","overrides":"+CanvasRandomization"},{"firstPartyDomain":"google.cv","overrides":"+CanvasRandomization"},{"firstPartyDomain":"google.cz","overrides":"+CanvasRandomization"},{"firstPartyDomain":"google.de","overrides":"+CanvasRandomization"},{"firstPartyDomain":"google.dj","overrides":"+CanvasRandomization"},{"firstPartyDomain":"google.dk","overrides":"+CanvasRandomization"},{"firstPartyDomain":"google.dm","overrides":"+CanvasRandomization"},{"firstPartyDomain":"google.dz","overrides":"+CanvasRandomization"},{"firstPartyDomain":"google.ee","overrides":"+CanvasRandomization"},{"firstPartyDomain":"google.es","overrides":"+CanvasRandomization"},{"firstPartyDomain":"google.fi","overrides":"+CanvasRandomization"},{"firstPartyDomain":"google.fm","overrides":"+CanvasRandomization"},{"firstPartyDomain":"google.fr","overrides":"+CanvasRandomization"},{"firstPartyDomain":"google.ga","overrides":"+CanvasRandomization"},{"firstPartyDomain":"google.ge","overrides":"+CanvasRandomization"},{"firstPartyDomain":"google.gg","overrides":"+CanvasRandomization"},{"firstPartyDomain":"google.gl","overrides":"+CanvasRandomization"},{"firstPartyDomain":"google.gm","overrides":"+CanvasRandomization"},{"firstPartyDomain":"google.gr","overrides":"+CanvasRandomization"},{"firstPartyDomain":"google.gy","overrides":"+CanvasRandomization"},{"firstPartyDomain":"google.hn","overrides":"+CanvasRandomization"},{"firstPartyDomain":"google.hr","overrides":"+CanvasRandomization"},{"firstPartyDomain":"google.ht","overrides":"+CanvasRandomization"},{"firstPartyDomain":"google.hu","overrides":"+CanvasRandomization"},{"firstPartyDomain":"google.ie","overrides":"+CanvasRandomization"},{"firstPartyDomain":"google.im","overrides":"+CanvasRandomization"},{"firstPartyDomain":"google.iq","overrides":"+CanvasRandomization"},{"firstPartyDomain":"google.is","overrides":"+CanvasRandomization"},{"firstPartyDomain":"google.it","overrides":"+CanvasRandomization"},{"firstPartyDomain":"google.je","overrides":"+CanvasRandomization"},{"firstPartyDomain":"google.jo","overrides":"+CanvasRandomization"},{"firstPartyDomain":"google.kg","overrides":"+CanvasRandomization"},{"firstPartyDomain":"google.ki","overrides":"+CanvasRandomization"},{"firstPartyDomain":"google.kz","overrides":"+CanvasRandomization"},{"firstPartyDomain":"google.la","overrides":"+CanvasRandomization"},{"firstPartyDomain":"google.li","overrides":"+CanvasRandomization"},{"firstPartyDomain":"google.lk","overrides":"+CanvasRandomization"},{"firstPartyDomain":"google.lt","overrides":"+CanvasRandomization"},{"firstPartyDomain":"google.lu","overrides":"+CanvasRandomization"},{"firstPartyDomain":"google.lv","overrides":"+CanvasRandomization"},{"firstPartyDomain":"google.md","overrides":"+CanvasRandomization"},{"firstPartyDomain":"google.me","overrides":"+CanvasRandomization"},{"firstPartyDomain":"google.mg","overrides":"+CanvasRandomization"},{"firstPartyDomain":"google.mk","overrides":"+CanvasRandomization"},{"firstPartyDomain":"google.ml","overrides":"+CanvasRandomization"},{"firstPartyDomain":"google.mn","overrides":"+CanvasRandomization"},{"firstPartyDomain":"google.mu","overrides":"+CanvasRandomization"},{"firstPartyDomain":"google.mv","overrides":"+CanvasRandomization"},{"firstPartyDomain":"google.mw","overrides":"+CanvasRandomization"},{"firstPartyDomain":"google.ne","overrides":"+CanvasRandomization"},{"firstPartyDomain":"google.nl","overrides":"+CanvasRandomization"},{"firstPartyDomain":"google.no","overrides":"+CanvasRandomization"},{"firstPartyDomain":"google.nr","overrides":"+CanvasRandomization"},{"firstPartyDomain":"google.nu","overrides":"+CanvasRandomization"},{"firstPartyDomain":"google.pl","overrides":"+CanvasRandomization"},{"firstPartyDomain":"google.pn","overrides":"+CanvasRandomization"},{"firstPartyDomain":"google.ps","overrides":"+CanvasRandomization"},{"firstPartyDomain":"google.pt","overrides":"+CanvasRandomization"},{"firstPartyDomain":"google.ro","overrides":"+CanvasRandomization"},{"firstPartyDomain":"google.rs","overrides":"+CanvasRandomization"},{"firstPartyDomain":"google.ru","overrides":"+CanvasRandomization"},{"firstPartyDomain":"google.rw","overrides":"+CanvasRandomization"},{"firstPartyDomain":"google.sc","overrides":"+CanvasRandomization"},{"firstPartyDomain":"google.se","overrides":"+CanvasRandomization"},{"firstPartyDomain":"google.sh","overrides":"+CanvasRandomization"},{"firstPartyDomain":"google.si","overrides":"+CanvasRandomization"},{"firstPartyDomain":"google.sk","overrides":"+CanvasRandomization"},{"firstPartyDomain":"google.sn","overrides":"+CanvasRandomization"},{"firstPartyDomain":"google.so","overrides":"+CanvasRandomization"},{"firstPartyDomain":"google.sm","overrides":"+CanvasRandomization"},{"firstPartyDomain":"google.sr","overrides":"+CanvasRandomization"},{"firstPartyDomain":"google.st","overrides":"+CanvasRandomization"},{"firstPartyDomain":"google.td","overrides":"+CanvasRandomization"},{"firstPartyDomain":"google.tg","overrides":"+CanvasRandomization"},{"firstPartyDomain":"google.tl","overrides":"+CanvasRandomization"},{"firstPartyDomain":"google.tm","overrides":"+CanvasRandomization"},{"firstPartyDomain":"google.tn","overrides":"+CanvasRandomization"},{"firstPartyDomain":"google.to","overrides":"+CanvasRandomization"},{"firstPartyDomain":"google.tt","overrides":"+CanvasRandomization"},{"firstPartyDomain":"google.vu","overrides":"+CanvasRandomization"},{"firstPartyDomain":"google.ws","overrides":"+CanvasRandomization"},{"firstPartyDomain":"amazon.ae","overrides":"+CanvasExtractionBeforeUserInputIsBlocked,+CanvasImageExtractionPrompt"},{"firstPartyDomain":"amazon.ca","overrides":"+CanvasExtractionBeforeUserInputIsBlocked,+CanvasImageExtractionPrompt"},{"firstPartyDomain":"amazon.cn","overrides":"+CanvasExtractionBeforeUserInputIsBlocked,+CanvasImageExtractionPrompt"},{"firstPartyDomain":"amazon.co.jp","overrides":"+CanvasExtractionBeforeUserInputIsBlocked,+CanvasImageExtractionPrompt"},{"firstPartyDomain":"amazon.co.uk","overrides":"+CanvasExtractionBeforeUserInputIsBlocked,+CanvasImageExtractionPrompt"},{"firstPartyDomain":"amazon.co.za","overrides":"+CanvasExtractionBeforeUserInputIsBlocked,+CanvasImageExtractionPrompt"},{"firstPartyDomain":"amazon.com","overrides":"+CanvasExtractionBeforeUserInputIsBlocked,+CanvasImageExtractionPrompt"},{"firstPartyDomain":"amazon.com.au","overrides":"+CanvasExtractionBeforeUserInputIsBlocked,+CanvasImageExtractionPrompt"},{"firstPartyDomain":"amazon.com.be","overrides":"+CanvasExtractionBeforeUserInputIsBlocked,+CanvasImageExtractionPrompt"},{"firstPartyDomain":"amazon.com.br","overrides":"+CanvasExtractionBeforeUserInputIsBlocked,+CanvasImageExtractionPrompt"},{"firstPartyDomain":"amazon.com.mx","overrides":"+CanvasExtractionBeforeUserInputIsBlocked,+CanvasImageExtractionPrompt"},{"firstPartyDomain":"amazon.com.tr","overrides":"+CanvasExtractionBeforeUserInputIsBlocked,+CanvasImageExtractionPrompt"},{"firstPartyDomain":"amazon.de","overrides":"+CanvasExtractionBeforeUserInputIsBlocked,+CanvasImageExtractionPrompt"},{"firstPartyDomain":"amazon.eg","overrides":"+CanvasExtractionBeforeUserInputIsBlocked,+CanvasImageExtractionPrompt"},{"firstPartyDomain":"amazon.es","overrides":"+CanvasExtractionBeforeUserInputIsBlocked,+CanvasImageExtractionPrompt"},{"firstPartyDomain":"amazon.fr","overrides":"+CanvasExtractionBeforeUserInputIsBlocked,+CanvasImageExtractionPrompt"},{"firstPartyDomain":"amazon.ie","overrides":"+CanvasExtractionBeforeUserInputIsBlocked,+CanvasImageExtractionPrompt"},{"firstPartyDomain":"amazon.in","overrides":"+CanvasExtractionBeforeUserInputIsBlocked,+CanvasImageExtractionPrompt"},{"firstPartyDomain":"amazon.it","overrides":"+CanvasExtractionBeforeUserInputIsBlocked,+CanvasImageExtractionPrompt"},{"firstPartyDomain":"amazon.nl","overrides":"+CanvasExtractionBeforeUserInputIsBlocked,+CanvasImageExtractionPrompt"},{"firstPartyDomain":"amazon.pl","overrides":"+CanvasExtractionBeforeUserInputIsBlocked,+CanvasImageExtractionPrompt"},{"firstPartyDomain":"amazon.sa","overrides":"+CanvasExtractionBeforeUserInputIsBlocked,+CanvasImageExtractionPrompt"},{"firstPartyDomain":"amazon.se","overrides":"+CanvasExtractionBeforeUserInputIsBlocked,+CanvasImageExtractionPrompt"},{"firstPartyDomain":"amazon.sg","overrides":"+CanvasExtractionBeforeUserInputIsBlocked,+CanvasImageExtractionPrompt"},{"firstPartyDomain":"animepahe.ru","overrides":"+CanvasExtractionBeforeUserInputIsBlocked,+CanvasImageExtractionPrompt"},{"firstPartyDomain":"annas-archive.org","overrides":"+CanvasExtractionBeforeUserInputIsBlocked,+CanvasImageExtractionPrompt"},{"firstPartyDomain":"apple.com","overrides":"+CanvasExtractionBeforeUserInputIsBlocked,+CanvasImageExtractionPrompt"},{"firstPartyDomain":"apple.com.cn","overrides":"+CanvasExtractionBeforeUserInputIsBlocked,+CanvasImageExtractionPrompt"},{"firstPartyDomain":"apple.news","overrides":"+CanvasExtractionBeforeUserInputIsBlocked,+CanvasImageExtractionPrompt,+CSSPrefersColorScheme,+FrameRate,+JSDateTimeUTC"},{"firstPartyDomain":"cloudflare.com","overrides":"+CanvasExtractionBeforeUserInputIsBlocked,+CanvasImageExtractionPrompt,+JSDateTimeUTC"},{"firstPartyDomain":"cvs.com","overrides":"+CanvasExtractionBeforeUserInputIsBlocked,+CanvasImageExtractionPrompt"},{"firstPartyDomain":"discord.gg","overrides":"+CanvasExtractionBeforeUserInputIsBlocked,+CanvasImageExtractionPrompt,+CSSPrefersColorScheme,+FrameRate,+JSDateTimeUTC"},{"firstPartyDomain":"dropbox.com","overrides":"+CanvasExtractionBeforeUserInputIsBlocked,+CanvasImageExtractionPrompt"},{"firstPartyDomain":"enza.fun","overrides":"+CanvasExtractionBeforeUserInputIsBlocked,+CanvasImageExtractionPrompt"},{"firstPartyDomain":"epicgames.com","overrides":"+CanvasExtractionBeforeUserInputIsBlocked,+CanvasImageExtractionPrompt"},{"firstPartyDomain":"favicon.io","overrides":"+JSDateTimeUTC"},{"firstPartyDomain":"goo.gl","overrides":"+CanvasExtractionBeforeUserInputIsBlocked,+CanvasImageExtractionPrompt,+CSSPrefersColorScheme,+FrameRate,+JSDateTimeUTC,+JSLocale"},{"firstPartyDomain":"hoyoverse.com","overrides":"+CanvasExtractionBeforeUserInputIsBlocked,+CanvasImageExtractionPrompt"},{"firstPartyDomain":"imdb.com","overrides":"+CanvasExtractionBeforeUserInputIsBlocked,+CanvasImageExtractionPrompt"},{"firstPartyDomain":"klippy.pro","overrides":"+CanvasExtractionBeforeUserInputIsBlocked,+CanvasImageExtractionPrompt"},{"firstPartyDomain":"kroger.com","overrides":"+CanvasExtractionBeforeUserInputIsBlocked,+CanvasImageExtractionPrompt"},{"firstPartyDomain":"medium.com","overrides":"+CanvasExtractionBeforeUserInputIsBlocked,+CanvasImageExtractionPrompt"},{"firstPartyDomain":"mega.nz","overrides":"+CanvasExtractionBeforeUserInputIsBlocked,+CanvasImageExtractionPrompt"},{"firstPartyDomain":"porkbun.com","overrides":"+CanvasExtractionBeforeUserInputIsBlocked,+CanvasImageExtractionPrompt"},{"firstPartyDomain":"reddit.com","overrides":"+CanvasExtractionBeforeUserInputIsBlocked,+CanvasImageExtractionPrompt"},{"firstPartyDomain":"redditmedia.com","overrides":"+CanvasExtractionBeforeUserInputIsBlocked,+CanvasImageExtractionPrompt"},{"firstPartyDomain":"rezka-ua.in","overrides":"+CanvasExtractionBeforeUserInputIsBlocked,+CanvasImageExtractionPrompt"},{"firstPartyDomain":"riverside.fm","overrides":"+CanvasExtractionBeforeUserInputIsBlocked,+CanvasImageExtractionPrompt"},{"firstPartyDomain":"salespanel.io","overrides":"+CanvasExtractionBeforeUserInputIsBlocked,+CanvasImageExtractionPrompt"},{"firstPartyDomain":"southwest.com","overrides":"+CanvasExtractionBeforeUserInputIsBlocked,+CanvasImageExtractionPrompt"},{"firstPartyDomain":"stacksocial.com","overrides":"+CanvasExtractionBeforeUserInputIsBlocked,+CanvasImageExtractionPrompt"},{"firstPartyDomain":"starlink.com","overrides":"+CanvasExtractionBeforeUserInputIsBlocked,+CanvasImageExtractionPrompt"},{"firstPartyDomain":"svgrepo.com","overrides":"+CanvasExtractionBeforeUserInputIsBlocked,+CanvasImageExtractionPrompt"},{"firstPartyDomain":"t.co","overrides":"+CanvasExtractionBeforeUserInputIsBlocked,+CanvasImageExtractionPrompt,+CSSPrefersColorScheme,+FrameRate,+JSDateTimeUTC,+JSLocale"},{"firstPartyDomain":"thunderbird.net","overrides":"+CSSPrefersColorScheme"},{"firstPartyDomain":"tiktok.com","overrides":"+CanvasExtractionBeforeUserInputIsBlocked,+CanvasImageExtractionPrompt"},{"firstPartyDomain":"tileman.io","overrides":"+CanvasExtractionBeforeUserInputIsBlocked,+CanvasImageExtractionPrompt,+JSDateTimeUTC"},{"firstPartyDomain":"usnews.com","overrides":"+CanvasExtractionBeforeUserInputIsBlocked,+CanvasImageExtractionPrompt"},{"firstPartyDomain":"usps.com","overrides":"+CanvasExtractionBeforeUserInputIsBlocked,+CanvasImageExtractionPrompt"},{"firstPartyDomain":"vhlcentral.com","overrides":"+CanvasExtractionBeforeUserInputIsBlocked,+CanvasImageExtractionPrompt"},{"firstPartyDomain":"yahoo.com","overrides":"+CanvasExtractionBeforeUserInputIsBlocked,+CanvasImageExtractionPrompt"},{"firstPartyDomain":"youtu.be","overrides":"+CanvasExtractionBeforeUserInputIsBlocked,+CanvasImageExtractionPrompt,+CSSPrefersColorScheme,+FrameRate,+JSDateTimeUTC,+JSLocale"},{"firstPartyDomain":"youtube-nocookie.com","overrides":"+CSSPrefersColorScheme,+JSDateTimeUTC"},{"firstPartyDomain":"zoho.com","overrides":"+CanvasExtractionBeforeUserInputIsBlocked,+CanvasImageExtractionPrompt"},{"firstPartyDomain":"zoho.com.au","overrides":"+CanvasExtractionBeforeUserInputIsBlocked,+CanvasImageExtractionPrompt"},{"firstPartyDomain":"zoho.eu","overrides":"+CanvasExtractionBeforeUserInputIsBlocked,+CanvasImageExtractionPrompt"},{"firstPartyDomain":"zoho.in","overrides":"+CanvasExtractionBeforeUserInputIsBlocked,+CanvasImageExtractionPrompt"},{"firstPartyDomain":"zoho.jp","overrides":"+CanvasExtractionBeforeUserInputIsBlocked,+CanvasImageExtractionPrompt"},{"firstPartyDomain":"zoho.sa","overrides":"+CanvasExtractionBeforeUserInputIsBlocked,+CanvasImageExtractionPrompt"},{"firstPartyDomain":"*","thirdPartyDomain":"apple.com","overrides":"+CSSPrefersColorScheme,+FrameRate,+JSDateTimeUTC"},{"firstPartyDomain":"*","thirdPartyDomain":"apple.news","overrides":"+CSSPrefersColorScheme,+FrameRate,+JSDateTimeUTC"},{"firstPartyDomain":"*","thirdPartyDomain":"bsky.app","overrides":"+CSSPrefersColorScheme,+JSDateTimeUTC"},{"firstPartyDomain":"*","thirdPartyDomain":"cdn-apple.com","overrides":"+CSSPrefersColorScheme,+FrameRate,+JSDateTimeUTC"},{"firstPartyDomain":"*","thirdPartyDomain":"cdninstagram.com","overrides":"+CSSPrefersColorScheme,+JSDateTimeUTC"},{"firstPartyDomain":"*","thirdPartyDomain":"cloudflare.com","overrides":"+CSSPrefersColorScheme,+FrameRate,+JSDateTimeUTC"},{"firstPartyDomain":"*","thirdPartyDomain":"discord.gg","overrides":"+CSSPrefersColorScheme,+FrameRate,+JSDateTimeUTC,+JSLocale"},{"firstPartyDomain":"*","thirdPartyDomain":"favicon.io","overrides":"+JSDateTimeUTC"},{"firstPartyDomain":"*","thirdPartyDomain":"goo.gl","overrides":"+CSSPrefersColorScheme,+FrameRate,+JSDateTimeUTC,+JSLocale"},{"firstPartyDomain":"*","thirdPartyDomain":"googlevideo.com","overrides":"+CSSPrefersColorScheme,+JSDateTimeUTC,+JSLocale"},{"firstPartyDomain":"*","thirdPartyDomain":"gravatar.com","overrides":"+CSSPrefersColorScheme,+FrameRate,+JSDateTimeUTC,+JSLocale"},{"firstPartyDomain":"*","thirdPartyDomain":"instagram.com","overrides":"+CSSPrefersColorScheme,+JSDateTimeUTC"},{"firstPartyDomain":"*","thirdPartyDomain":"licdn.com","overrides":"+CSSPrefersColorScheme,+JSDateTimeUTC"},{"firstPartyDomain":"*","thirdPartyDomain":"linkedin.com","overrides":"+CSSPrefersColorScheme,+JSDateTimeUTC"},{"firstPartyDomain":"*","thirdPartyDomain":"loginwithamazon.com","overrides":"+CSSPrefersColorScheme,+FrameRate,+JSDateTimeUTC"},{"firstPartyDomain":"*","thirdPartyDomain":"moviezapiya.fun","overrides":"+JSDateTimeUTC"},{"firstPartyDomain":"*","thirdPartyDomain":"pinimg.com","overrides":"+CSSPrefersColorScheme,+FrameRate,+JSDateTimeUTC"},{"firstPartyDomain":"*","thirdPartyDomain":"pinterest.com","overrides":"+CSSPrefersColorScheme,+FrameRate,+JSDateTimeUTC"},{"firstPartyDomain":"*","thirdPartyDomain":"recaptcha.net","overrides":"+CSSPrefersColorScheme,+FrameRate,+JSDateTimeUTC"},{"firstPartyDomain":"*","thirdPartyDomain":"recaptcha.net.cn","overrides":"+CSSPrefersColorScheme,+FrameRate,+JSDateTimeUTC"},{"firstPartyDomain":"*","thirdPartyDomain":"recaptcha-cn.net","overrides":"+CSSPrefersColorScheme,+FrameRate,+JSDateTimeUTC"},{"firstPartyDomain":"*","thirdPartyDomain":"redd.it","overrides":"+CSSPrefersColorScheme,+JSDateTimeUTC"},{"firstPartyDomain":"*","thirdPartyDomain":"reddit.com","overrides":"+CSSPrefersColorScheme,+JSDateTimeUTC"},{"firstPartyDomain":"*","thirdPartyDomain":"redditmedia.com","overrides":"+CSSPrefersColorScheme,+JSDateTimeUTC"},{"firstPartyDomain":"*","thirdPartyDomain":"redditstatic.com","overrides":"+CSSPrefersColorScheme,+JSDateTimeUTC"},{"firstPartyDomain":"*","thirdPartyDomain":"t.co","overrides":"+CSSPrefersColorScheme,+FrameRate,+JSDateTimeUTC,+JSLocale"},{"firstPartyDomain":"*","thirdPartyDomain":"tileman.io","overrides":"+JSDateTimeUTC"},{"firstPartyDomain":"*","thirdPartyDomain":"tiktok.com","overrides":"+CSSPrefersColorScheme,+JSDateTimeUTC"},{"firstPartyDomain":"*","thirdPartyDomain":"twitter.com","overrides":"+CSSPrefersColorScheme,+JSDateTimeUTC"},{"firstPartyDomain":"*","thirdPartyDomain":"twimg.com","overrides":"+CSSPrefersColorScheme,+JSDateTimeUTC,+JSLocale"},{"firstPartyDomain":"*","thirdPartyDomain":"vimeo.com","overrides":"+CSSPrefersColorScheme,+JSDateTimeUTC"},{"firstPartyDomain":"*","thirdPartyDomain":"vimeocdn.com","overrides":"+CSSPrefersColorScheme,+JSDateTimeUTC"},{"firstPartyDomain":"*","thirdPartyDomain":"x.com","overrides":"+CSSPrefersColorScheme,+JSDateTimeUTC"},{"firstPartyDomain":"*","thirdPartyDomain":"youtu.be","overrides":"+CSSPrefersColorScheme,+FrameRate,+JSDateTimeUTC,+JSLocale"},{"firstPartyDomain":"*","thirdPartyDomain":"youtube.com","overrides":"+CSSPrefersColorScheme,+JSDateTimeUTC"},{"firstPartyDomain":"*","thirdPartyDomain":"youtube-nocookie.com","overrides":"+CSSPrefersColorScheme,+JSDateTimeUTC"},{"firstPartyDomain":"google.ad","overrides":"-JSDateTimeUTC"},{"firstPartyDomain":"google.ae","overrides":"-JSDateTimeUTC"},{"firstPartyDomain":"google.al","overrides":"-JSDateTimeUTC"},{"firstPartyDomain":"google.am","overrides":"-JSDateTimeUTC"},{"firstPartyDomain":"google.as","overrides":"-JSDateTimeUTC"},{"firstPartyDomain":"google.at","overrides":"-JSDateTimeUTC"},{"firstPartyDomain":"google.az","overrides":"-JSDateTimeUTC"},{"firstPartyDomain":"google.ba","overrides":"-JSDateTimeUTC"},{"firstPartyDomain":"google.be","overrides":"-JSDateTimeUTC"},{"firstPartyDomain":"google.bf","overrides":"-JSDateTimeUTC"},{"firstPartyDomain":"google.bg","overrides":"-JSDateTimeUTC"},{"firstPartyDomain":"google.bi","overrides":"-JSDateTimeUTC"},{"firstPartyDomain":"google.bj","overrides":"-JSDateTimeUTC"},{"firstPartyDomain":"google.bs","overrides":"-JSDateTimeUTC"},{"firstPartyDomain":"google.bt","overrides":"-JSDateTimeUTC"},{"firstPartyDomain":"google.by","overrides":"-JSDateTimeUTC"},{"firstPartyDomain":"google.ca","overrides":"-JSDateTimeUTC"},{"firstPartyDomain":"google.cat","overrides":"-JSDateTimeUTC"},{"firstPartyDomain":"google.cd","overrides":"-JSDateTimeUTC"},{"firstPartyDomain":"google.cf","overrides":"-JSDateTimeUTC"},{"firstPartyDomain":"google.cg","overrides":"-JSDateTimeUTC"},{"firstPartyDomain":"google.ch","overrides":"-JSDateTimeUTC"},{"firstPartyDomain":"google.ci","overrides":"-JSDateTimeUTC"},{"firstPartyDomain":"google.cl","overrides":"-JSDateTimeUTC"},{"firstPartyDomain":"google.cm","overrides":"-JSDateTimeUTC"},{"firstPartyDomain":"google.cn","overrides":"-JSDateTimeUTC"},{"firstPartyDomain":"google.co.ao","overrides":"-JSDateTimeUTC"},{"firstPartyDomain":"google.co.bw","overrides":"-JSDateTimeUTC"},{"firstPartyDomain":"google.co.ck","overrides":"-JSDateTimeUTC"},{"firstPartyDomain":"google.co.cr","overrides":"-JSDateTimeUTC"},{"firstPartyDomain":"google.co.id","overrides":"-JSDateTimeUTC"},{"firstPartyDomain":"google.co.il","overrides":"-JSDateTimeUTC"},{"firstPartyDomain":"google.co.in","overrides":"-JSDateTimeUTC"},{"firstPartyDomain":"google.co.jp","overrides":"-JSDateTimeUTC"},{"firstPartyDomain":"google.co.ke","overrides":"-JSDateTimeUTC"},{"firstPartyDomain":"google.co.kr","overrides":"-JSDateTimeUTC"},{"firstPartyDomain":"google.co.ls","overrides":"-JSDateTimeUTC"},{"firstPartyDomain":"google.co.ma","overrides":"-JSDateTimeUTC"},{"firstPartyDomain":"google.co.mz","overrides":"-JSDateTimeUTC"},{"firstPartyDomain":"google.co.nz","overrides":"-JSDateTimeUTC"},{"firstPartyDomain":"google.co.th","overrides":"-JSDateTimeUTC"},{"firstPartyDomain":"google.co.tz","overrides":"-JSDateTimeUTC"},{"firstPartyDomain":"google.co.ug","overrides":"-JSDateTimeUTC"},{"firstPartyDomain":"google.co.uk","overrides":"-JSDateTimeUTC"},{"firstPartyDomain":"google.co.uz","overrides":"-JSDateTimeUTC"},{"firstPartyDomain":"google.co.ve","overrides":"-JSDateTimeUTC"},{"firstPartyDomain":"google.co.vi","overrides":"-JSDateTimeUTC"},{"firstPartyDomain":"google.co.za","overrides":"-JSDateTimeUTC"},{"firstPartyDomain":"google.co.zm","overrides":"-JSDateTimeUTC"},{"firstPartyDomain":"google.co.zw","overrides":"-JSDateTimeUTC"},{"firstPartyDomain":"google.com","overrides":"-JSDateTimeUTC"},{"firstPartyDomain":"google.com.af","overrides":"-JSDateTimeUTC"},{"firstPartyDomain":"google.com.ag","overrides":"-JSDateTimeUTC"},{"firstPartyDomain":"google.com.ar","overrides":"-JSDateTimeUTC"},{"firstPartyDomain":"google.com.au","overrides":"-JSDateTimeUTC"},{"firstPartyDomain":"google.com.bd","overrides":"-JSDateTimeUTC"},{"firstPartyDomain":"google.com.bh","overrides":"-JSDateTimeUTC"},{"firstPartyDomain":"google.com.bn","overrides":"-JSDateTimeUTC"},{"firstPartyDomain":"google.com.bo","overrides":"-JSDateTimeUTC"},{"firstPartyDomain":"google.com.br","overrides":"-JSDateTimeUTC"},{"firstPartyDomain":"google.com.bz","overrides":"-JSDateTimeUTC"},{"firstPartyDomain":"google.com.co","overrides":"-JSDateTimeUTC"},{"firstPartyDomain":"google.com.cu","overrides":"-JSDateTimeUTC"},{"firstPartyDomain":"google.com.cy","overrides":"-JSDateTimeUTC"},{"firstPartyDomain":"google.com.do","overrides":"-JSDateTimeUTC"},{"firstPartyDomain":"google.com.ec","overrides":"-JSDateTimeUTC"},{"firstPartyDomain":"google.com.eg","overrides":"-JSDateTimeUTC"},{"firstPartyDomain":"google.com.et","overrides":"-JSDateTimeUTC"},{"firstPartyDomain":"google.com.fj","overrides":"-JSDateTimeUTC"},{"firstPartyDomain":"google.com.gh","overrides":"-JSDateTimeUTC"},{"firstPartyDomain":"google.com.gi","overrides":"-JSDateTimeUTC"},{"firstPartyDomain":"google.com.gt","overrides":"-JSDateTimeUTC"},{"firstPartyDomain":"google.com.hk","overrides":"-JSDateTimeUTC"},{"firstPartyDomain":"google.com.jm","overrides":"-JSDateTimeUTC"},{"firstPartyDomain":"google.com.kh","overrides":"-JSDateTimeUTC"},{"firstPartyDomain":"google.com.kw","overrides":"-JSDateTimeUTC"},{"firstPartyDomain":"google.com.lb","overrides":"-JSDateTimeUTC"},{"firstPartyDomain":"google.com.ly","overrides":"-JSDateTimeUTC"},{"firstPartyDomain":"google.com.mm","overrides":"-JSDateTimeUTC"},{"firstPartyDomain":"google.com.mt","overrides":"-JSDateTimeUTC"},{"firstPartyDomain":"google.com.mx","overrides":"-JSDateTimeUTC"},{"firstPartyDomain":"google.com.my","overrides":"-JSDateTimeUTC"},{"firstPartyDomain":"google.com.na","overrides":"-JSDateTimeUTC"},{"firstPartyDomain":"google.com.ng","overrides":"-JSDateTimeUTC"},{"firstPartyDomain":"google.com.ni","overrides":"-JSDateTimeUTC"},{"firstPartyDomain":"google.com.np","overrides":"-JSDateTimeUTC"},{"firstPartyDomain":"google.com.om","overrides":"-JSDateTimeUTC"},{"firstPartyDomain":"google.com.pa","overrides":"-JSDateTimeUTC"},{"firstPartyDomain":"google.com.pe","overrides":"-JSDateTimeUTC"},{"firstPartyDomain":"google.com.pg","overrides":"-JSDateTimeUTC"},{"firstPartyDomain":"google.com.ph","overrides":"-JSDateTimeUTC"},{"firstPartyDomain":"google.com.pk","overrides":"-JSDateTimeUTC"},{"firstPartyDomain":"google.com.pr","overrides":"-JSDateTimeUTC"},{"firstPartyDomain":"google.com.py","overrides":"-JSDateTimeUTC"},{"firstPartyDomain":"google.com.qa","overrides":"-JSDateTimeUTC"},{"firstPartyDomain":"google.com.sa","overrides":"-JSDateTimeUTC"},{"firstPartyDomain":"google.com.sb","overrides":"-JSDateTimeUTC"},{"firstPartyDomain":"google.com.sg","overrides":"-JSDateTimeUTC"},{"firstPartyDomain":"google.com.sl","overrides":"-JSDateTimeUTC"},{"firstPartyDomain":"google.com.sv","overrides":"-JSDateTimeUTC"},{"firstPartyDomain":"google.com.tj","overrides":"-JSDateTimeUTC"},{"firstPartyDomain":"google.com.tr","overrides":"-JSDateTimeUTC"},{"firstPartyDomain":"google.com.tw","overrides":"-JSDateTimeUTC"},{"firstPartyDomain":"google.com.ua","overrides":"-JSDateTimeUTC"},{"firstPartyDomain":"google.com.uy","overrides":"-JSDateTimeUTC"},{"firstPartyDomain":"google.com.vc","overrides":"-JSDateTimeUTC"},{"firstPartyDomain":"google.com.vn","overrides":"-JSDateTimeUTC"},{"firstPartyDomain":"google.cv","overrides":"-JSDateTimeUTC"},{"firstPartyDomain":"google.cz","overrides":"-JSDateTimeUTC"},{"firstPartyDomain":"google.de","overrides":"-JSDateTimeUTC"},{"firstPartyDomain":"google.dj","overrides":"-JSDateTimeUTC"},{"firstPartyDomain":"google.dk","overrides":"-JSDateTimeUTC"},{"firstPartyDomain":"google.dm","overrides":"-JSDateTimeUTC"},{"firstPartyDomain":"google.dz","overrides":"-JSDateTimeUTC"},{"firstPartyDomain":"google.ee","overrides":"-JSDateTimeUTC"},{"firstPartyDomain":"google.es","overrides":"-JSDateTimeUTC"},{"firstPartyDomain":"google.fi","overrides":"-JSDateTimeUTC"},{"firstPartyDomain":"google.fm","overrides":"-JSDateTimeUTC"},{"firstPartyDomain":"google.fr","overrides":"-JSDateTimeUTC"},{"firstPartyDomain":"google.ga","overrides":"-JSDateTimeUTC"},{"firstPartyDomain":"google.ge","overrides":"-JSDateTimeUTC"},{"firstPartyDomain":"google.gg","overrides":"-JSDateTimeUTC"},{"firstPartyDomain":"google.gl","overrides":"-JSDateTimeUTC"},{"firstPartyDomain":"google.gm","overrides":"-JSDateTimeUTC"},{"firstPartyDomain":"google.gr","overrides":"-JSDateTimeUTC"},{"firstPartyDomain":"google.gy","overrides":"-JSDateTimeUTC"},{"firstPartyDomain":"google.hn","overrides":"-JSDateTimeUTC"},{"firstPartyDomain":"google.hr","overrides":"-JSDateTimeUTC"},{"firstPartyDomain":"google.ht","overrides":"-JSDateTimeUTC"},{"firstPartyDomain":"google.hu","overrides":"-JSDateTimeUTC"},{"firstPartyDomain":"google.ie","overrides":"-JSDateTimeUTC"},{"firstPartyDomain":"google.im","overrides":"-JSDateTimeUTC"},{"firstPartyDomain":"google.iq","overrides":"-JSDateTimeUTC"},{"firstPartyDomain":"google.is","overrides":"-JSDateTimeUTC"},{"firstPartyDomain":"google.it","overrides":"-JSDateTimeUTC"},{"firstPartyDomain":"google.je","overrides":"-JSDateTimeUTC"},{"firstPartyDomain":"google.jo","overrides":"-JSDateTimeUTC"},{"firstPartyDomain":"google.kg","overrides":"-JSDateTimeUTC"},{"firstPartyDomain":"google.ki","overrides":"-JSDateTimeUTC"},{"firstPartyDomain":"google.kz","overrides":"-JSDateTimeUTC"},{"firstPartyDomain":"google.la","overrides":"-JSDateTimeUTC"},{"firstPartyDomain":"google.li","overrides":"-JSDateTimeUTC"},{"firstPartyDomain":"google.lk","overrides":"-JSDateTimeUTC"},{"firstPartyDomain":"google.lt","overrides":"-JSDateTimeUTC"},{"firstPartyDomain":"google.lu","overrides":"-JSDateTimeUTC"},{"firstPartyDomain":"google.lv","overrides":"-JSDateTimeUTC"},{"firstPartyDomain":"google.md","overrides":"-JSDateTimeUTC"},{"firstPartyDomain":"google.me","overrides":"-JSDateTimeUTC"},{"firstPartyDomain":"google.mg","overrides":"-JSDateTimeUTC"},{"firstPartyDomain":"google.mk","overrides":"-JSDateTimeUTC"},{"firstPartyDomain":"google.ml","overrides":"-JSDateTimeUTC"},{"firstPartyDomain":"google.mn","overrides":"-JSDateTimeUTC"},{"firstPartyDomain":"google.mu","overrides":"-JSDateTimeUTC"},{"firstPartyDomain":"google.mv","overrides":"-JSDateTimeUTC"},{"firstPartyDomain":"google.mw","overrides":"-JSDateTimeUTC"},{"firstPartyDomain":"google.ne","overrides":"-JSDateTimeUTC"},{"firstPartyDomain":"google.nl","overrides":"-JSDateTimeUTC"},{"firstPartyDomain":"google.no","overrides":"-JSDateTimeUTC"},{"firstPartyDomain":"google.nr","overrides":"-JSDateTimeUTC"},{"firstPartyDomain":"google.nu","overrides":"-JSDateTimeUTC"},{"firstPartyDomain":"google.pl","overrides":"-JSDateTimeUTC"},{"firstPartyDomain":"google.pn","overrides":"-JSDateTimeUTC"},{"firstPartyDomain":"google.ps","overrides":"-JSDateTimeUTC"},{"firstPartyDomain":"google.pt","overrides":"-JSDateTimeUTC"},{"firstPartyDomain":"google.ro","overrides":"-JSDateTimeUTC"},{"firstPartyDomain":"google.rs","overrides":"-JSDateTimeUTC"},{"firstPartyDomain":"google.ru","overrides":"-JSDateTimeUTC"},{"firstPartyDomain":"google.rw","overrides":"-JSDateTimeUTC"},{"firstPartyDomain":"google.sc","overrides":"-JSDateTimeUTC"},{"firstPartyDomain":"google.se","overrides":"-JSDateTimeUTC"},{"firstPartyDomain":"google.sh","overrides":"-JSDateTimeUTC"},{"firstPartyDomain":"google.si","overrides":"-JSDateTimeUTC"},{"firstPartyDomain":"google.sk","overrides":"-JSDateTimeUTC"},{"firstPartyDomain":"google.sn","overrides":"-JSDateTimeUTC"},{"firstPartyDomain":"google.so","overrides":"-JSDateTimeUTC"},{"firstPartyDomain":"google.sm","overrides":"-JSDateTimeUTC"},{"firstPartyDomain":"google.sr","overrides":"-JSDateTimeUTC"},{"firstPartyDomain":"google.st","overrides":"-JSDateTimeUTC"},{"firstPartyDomain":"google.td","overrides":"-JSDateTimeUTC"},{"firstPartyDomain":"google.tg","overrides":"-JSDateTimeUTC"},{"firstPartyDomain":"google.tl","overrides":"-JSDateTimeUTC"},{"firstPartyDomain":"google.tm","overrides":"-JSDateTimeUTC"},{"firstPartyDomain":"google.tn","overrides":"-JSDateTimeUTC"},{"firstPartyDomain":"google.to","overrides":"-JSDateTimeUTC"},{"firstPartyDomain":"google.tt","overrides":"-JSDateTimeUTC"},{"firstPartyDomain":"google.vu","overrides":"-JSDateTimeUTC"},{"firstPartyDomain":"google.ws","overrides":"-JSDateTimeUTC"},{"firstPartyDomain":"arcticfoxes.net","overrides":"-JSDateTimeUTC"},{"firstPartyDomain":"aria.im","overrides":"-JSDateTimeUTC"},{"firstPartyDomain":"bahn.expert","overrides":"-JSDateTimeUTC"},{"firstPartyDomain":"bitcoinist.org","overrides":"-JSDateTimeUTC"},{"firstPartyDomain":"calendly.com","overrides":"-JSDateTimeUTC"},{"firstPartyDomain":"chatwave.org","overrides":"-JSDateTimeUTC"},{"firstPartyDomain":"chipotle.com","overrides":"-JSDateTimeUTC"},{"firstPartyDomain":"cinny.in","overrides":"-JSDateTimeUTC"},{"firstPartyDomain":"citybbq.com","overrides":"-JSDateTimeUTC"},{"firstPartyDomain":"discord.com","overrides":"-JSDateTimeUTC"},{"firstPartyDomain":"doordash.com","overrides":"-JSDateTimeUTC"},{"firstPartyDomain":"duesen.chat","overrides":"-JSDateTimeUTC"},{"firstPartyDomain":"element.io","overrides":"-JSDateTimeUTC"},{"firstPartyDomain":"flieger.chat","overrides":"-JSDateTimeUTC"},{"firstPartyDomain":"g24.at","overrides":"-JSDateTimeUTC"},{"firstPartyDomain":"gemeinsam.jetzt","overrides":"-JSDateTimeUTC"},{"firstPartyDomain":"gnulinux.club","overrides":"-JSDateTimeUTC"},{"firstPartyDomain":"hot-chilli.im","overrides":"-JSDateTimeUTC"},{"firstPartyDomain":"kosmikdog.eu","overrides":"-JSDateTimeUTC"},{"firstPartyDomain":"mtrx.nz","overrides":"-JSDateTimeUTC"},{"firstPartyDomain":"neat.chat","overrides":"-JSDateTimeUTC"},{"firstPartyDomain":"nitro.chat","overrides":"-JSDateTimeUTC"},{"firstPartyDomain":"nope.chat","overrides":"-JSDateTimeUTC"},{"firstPartyDomain":"oblak.be","overrides":"-JSDateTimeUTC"},{"firstPartyDomain":"pcriot.org","overrides":"-JSDateTimeUTC"},{"firstPartyDomain":"pendora.io","overrides":"-JSDateTimeUTC"},{"firstPartyDomain":"proton.me","overrides":"-JSDateTimeUTC"},{"firstPartyDomain":"rollenspiel.chat","overrides":"-JSDateTimeUTC"},{"firstPartyDomain":"socialnetwork24.com","overrides":"-JSDateTimeUTC"},{"firstPartyDomain":"studichat.de","overrides":"-JSDateTimeUTC"},{"firstPartyDomain":"synod.im","overrides":"-JSDateTimeUTC"},{"firstPartyDomain":"temoos.app","overrides":"-JSDateTimeUTC"},{"firstPartyDomain":"the-apothecary.club","overrides":"-JSDateTimeUTC"},{"firstPartyDomain":"unredacted.org","overrides":"-JSDateTimeUTC"},{"firstPartyDomain":"utwente.io","overrides":"-JSDateTimeUTC"},{"firstPartyDomain":"we2.ee","overrides":"-JSDateTimeUTC"},{"firstPartyDomain":"yatrix.org","overrides":"-JSDateTimeUTC"},{"firstPartyDomain":"abeto.co","overrides":"-WebGLRenderCapability"},{"firstPartyDomain":"cryptpad.fr","thirdPartyDomain":"cryptpad.info","overrides":"-CanvasExtractionFromThirdPartiesIsBlocked"},{"firstPartyDomain":"figma.com","overrides":"-WebGLRenderCapability"},{"firstPartyDomain":"pogo.com","thirdPartyDomain":"pogospike.com","overrides":"-CanvasExtractionFromThirdPartiesIsBlocked"},{"firstPartyDomain":"vsynctester.com","overrides":"-ReduceTimerPrecision"},{"firstPartyDomain":"zennioptical.com","thirdPartyDomain":"fittingbox.com","overrides":"-CanvasExtractionFromThirdPartiesIsBlocked"},{"firstPartyDomain":"*","thirdPartyDomain":"megacloud.blog","overrides":"-CanvasExtractionFromThirdPartiesIsBlocked"},{"firstPartyDomain":"*","thirdPartyDomain":"megacloud.store","overrides":"-CanvasExtractionFromThirdPartiesIsBlocked"},{"firstPartyDomain":"*","thirdPartyDomain":"pornhub.com","overrides":"-CanvasExtractionFromThirdPartiesIsBlocked"},{"firstPartyDomain":"brave.com","overrides":"-CanvasExtractionBeforeUserInputIsBlocked,-CanvasImageExtractionPrompt"},{"firstPartyDomain":"bsky.app","overrides":"-CanvasExtractionBeforeUserInputIsBlocked,-CanvasImageExtractionPrompt"},{"firstPartyDomain":"cryptpad.fr","thirdPartyDomain":"cryptpad.info","overrides":"-CanvasExtractionBeforeUserInputIsBlocked,-CanvasImageExtractionPrompt"},{"firstPartyDomain":"discord.com","overrides":"-CanvasExtractionBeforeUserInputIsBlocked,-CanvasImageExtractionPrompt"},{"firstPartyDomain":"favicon.io","overrides":"-CanvasExtractionBeforeUserInputIsBlocked,-CanvasImageExtractionPrompt"},{"firstPartyDomain":"figma.com","overrides":"-CanvasExtractionBeforeUserInputIsBlocked,-CanvasImageExtractionPrompt"},{"firstPartyDomain":"fittingbox.com","overrides":"-CanvasExtractionBeforeUserInputIsBlocked,-CanvasImageExtractionPrompt"},{"firstPartyDomain":"gitlab.com","overrides":"-CanvasExtractionBeforeUserInputIsBlocked,-CanvasImageExtractionPrompt"},{"firstPartyDomain":"gsi.go.jp","overrides":"-CanvasExtractionBeforeUserInputIsBlocked,-CanvasImageExtractionPrompt"},{"firstPartyDomain":"harkins.com","overrides":"-CanvasExtractionBeforeUserInputIsBlocked,-CanvasImageExtractionPrompt"},{"firstPartyDomain":"icloud.com","overrides":"-CanvasExtractionBeforeUserInputIsBlocked,-CanvasImageExtractionPrompt"},{"firstPartyDomain":"icloud.com.cn","overrides":"-CanvasExtractionBeforeUserInputIsBlocked,-CanvasImageExtractionPrompt"},{"firstPartyDomain":"jerseymikes.com","overrides":"-CanvasExtractionBeforeUserInputIsBlocked,-CanvasImageExtractionPrompt"},{"firstPartyDomain":"jspaint.app","overrides":"-CanvasExtractionBeforeUserInputIsBlocked,-CanvasImageExtractionPrompt"},{"firstPartyDomain":"letterboxd.com","overrides":"-ScreenRect"},{"firstPartyDomain":"mapple.com","overrides":"-CanvasExtractionBeforeUserInputIsBlocked,-CanvasImageExtractionPrompt"},{"firstPartyDomain":"megacloud.blog","overrides":"-CanvasExtractionBeforeUserInputIsBlocked,-CanvasImageExtractionPrompt"},{"firstPartyDomain":"megacloud.store","overrides":"-CanvasExtractionBeforeUserInputIsBlocked,-CanvasImageExtractionPrompt"},{"firstPartyDomain":"mit.edu","overrides":"-CanvasExtractionBeforeUserInputIsBlocked,-CanvasImageExtractionPrompt"},{"firstPartyDomain":"namemc.com","overrides":"-CanvasExtractionBeforeUserInputIsBlocked,-CanvasImageExtractionPrompt"},{"firstPartyDomain":"nperf.com","overrides":"-CanvasExtractionBeforeUserInputIsBlocked,-CanvasImageExtractionPrompt"},{"firstPartyDomain":"photopea.com","overrides":"-CanvasExtractionBeforeUserInputIsBlocked,-CanvasImageExtractionPrompt"},{"firstPartyDomain":"piskelapp.com","overrides":"-CanvasExtractionBeforeUserInputIsBlocked,-CanvasImageExtractionPrompt"},{"firstPartyDomain":"pogo.com","thirdPartyDomain":"pogospike.com","overrides":"-CanvasExtractionBeforeUserInputIsBlocked,-CanvasImageExtractionPrompt"},{"firstPartyDomain":"pogospike.com","overrides":"-CanvasExtractionBeforeUserInputIsBlocked,-CanvasImageExtractionPrompt"},{"firstPartyDomain":"pornhub.com","overrides":"-CanvasExtractionBeforeUserInputIsBlocked,-CanvasImageExtractionPrompt"},{"firstPartyDomain":"siapre.pl","overrides":"-CanvasExtractionBeforeUserInputIsBlocked,-CanvasImageExtractionPrompt"},{"firstPartyDomain":"ttc.com.ge","overrides":"-CanvasExtractionBeforeUserInputIsBlocked,-CanvasImageExtractionPrompt"},{"firstPartyDomain":"usgs.gov","overrides":"-CanvasExtractionBeforeUserInputIsBlocked,-CanvasImageExtractionPrompt"},{"firstPartyDomain":"viliusle.github.io","overrides":"-CanvasExtractionBeforeUserInputIsBlocked,-CanvasImageExtractionPrompt"},{"firstPartyDomain":"watchduty.org","overrides":"-CanvasExtractionBeforeUserInputIsBlocked,-CanvasImageExtractionPrompt"},{"firstPartyDomain":"x.com","overrides":"-CanvasExtractionBeforeUserInputIsBlocked,-CanvasImageExtractionPrompt"},{"firstPartyDomain":"zennioptical.com","thirdPartyDomain":"fittingbox.com","overrides":"-CanvasExtractionBeforeUserInputIsBlocked,-CanvasImageExtractionPrompt"},{"firstPartyDomain":"*","thirdPartyDomain":"megacloud.blog","overrides":"-CanvasExtractionBeforeUserInputIsBlocked,-CanvasImageExtractionPrompt"},{"firstPartyDomain":"*","thirdPartyDomain":"megacloud.store","overrides":"-CanvasExtractionBeforeUserInputIsBlocked,-CanvasImageExtractionPrompt"},{"firstPartyDomain":"*","thirdPartyDomain":"pornhub.com","overrides":"-CanvasExtractionBeforeUserInputIsBlocked,-CanvasImageExtractionPrompt"}]'); // [ANDROID-ONLY]
pref("privacy.resistFingerprinting.target_video_res", 1080); // [DEFAULT]
pref("browser.zoom.siteSpecific", true); // [DEFAULT - non-Android]
pref("privacy.resistFingerprinting.0.NOTE", "RFP is disabled on purpose.", locked);
pref("privacy.resistFingerprinting.1.NOTE", "We use a hardened configuration of FPP instead.", locked);
pref("privacy.resistFingerprinting.2.NOTE", "Using RFP is not recommended or supported.", locked);
pref("browser.phoenix.status", "004");
pref("permissions.memory_only", false); // [HIDDEN] [DEFAULT]
pref("browser.download.enableDeletePrivate", true); // [DEFAULT] https://bugzilla.mozilla.org/show_bug.cgi?id=1981504
pref("privacy.clearOnShutdown.cache", true);
pref("privacy.clearOnShutdown_v2.cache", true); // [DEFAULT - Desktop Firefox]
pref("privacy.sanitize.sanitizeOnShutdown", true);
pref("browser.sessionstore.max_tabs_undo", 7); // [NO-MAIL]
pref("browser.sessionhistory.max_total_viewers", 0); // (Default = -1 (Automatic) - which is 8 unless you're using a device with under 1GB of RAM)
pref("fission.bfcacheInParent", false);
pref("browser.pagethumbnails.capturing_disabled", true); // [HIDDEN]
pref("browser.history.collectWireframes", false); // [DEFAULT]
pref("layout.css.visited_links_enabled", false);
pref("browser.cache.disk.enable", false);
pref("browser.cache.disk_cache_ssl", true); // [DEFAULT] Controls disk cache for secure (HTTPS) resources, depends on `browser.cache.disk.enable` (which is why we're keeping this on by default)
pref("places.frecency.bookmarkVisitBonus", 0); // [ESR] [HIDDEN - Android/Thunderbird] [Default: 75]
pref("places.frecency.defaultVisitBonus", 0); // [ESR] [HIDDEN - Android/Thunderbird] [DEFAULT]
pref("places.frecency.downloadVisitBonus", 0); // [ESR] [HIDDEN - Android/Thunderbird] [DEFAULT]
pref("places.frecency.embedVisitBonus", 0); // [ESR] [HIDDEN - Android/Thunderbird] [DEFAULT]
pref("places.frecency.framedLinkVisitBonus", 0); // [ESR] [HIDDEN - Android/Thunderbird] [DEFAULT]
pref("places.frecency.linkVisitBonus", 0); // [ESR] [HIDDEN - Android/Thunderbird] [Default: 100]
pref("places.frecency.permRedirectVisitBonus", 0); // [ESR] [HIDDEN - Android/Thunderbird] [DEFAULT - non-Firefox Desktop] [Default on Firefox Desktop: 50]
pref("places.frecency.redirectSourceVisitBonus", 0); // [ESR] [HIDDEN - Android/Thunderbird] [DEFAULT]
pref("places.frecency.reloadVisitBonus", 0); // [ESR] [HIDDEN - Android/Thunderbird] [Default on Firefox Desktop: 0]
pref("places.frecency.tempRedirectVisitBonus", 0); // [ESR] [HIDDEN - Android/Thunderbird] [DEFAULT - non-Firefox Desktop] [Default on Firefox Desktop: 40]
pref("places.frecency.typedVisitBonus", 0); // [ESR] [HIDDEN - Android/Thunderbird] [Default: 2000]
pref("places.frecency.unvisitedTypedBonus", 0); // [ESR] [HIDDEN - Android/Thunderbird] [Default: 200]
pref("browser.contentblocking.database.enabled", false); // [DEFAULT - Android/Thunderbird]
pref("browser.formfill.enable", false);
pref("media.aboutwebrtc.hist.enabled", false); // [DEFAULT - non-Nightly]
pref("browser.restoreWindowState.disabled", true);
pref("browser.sessionstore.interval", 60000); // 1 minute
pref("privacy.clearOnShutdown.siteSettings", false); // [HIDDEN - Android/Thunderbird] [DEFAULT]
pref("privacy.clearOnShutdown_v2.siteSettings", false); // [HIDDEN - Android/Thunderbird] [DEFAULT]
pref("network.ssl_tokens_cache_persistence", false);
pref("browser.sessionstore.privacy_level", 2); // [HIDDEN - Thunderbird]
pref("browser.privatebrowsing.forceMediaMemoryCache", true);
pref("browser.download.start_downloads_in_tmp_dir", true);
pref("browser.helperApps.deleteTempFileOnExit", true); // [DEFAULT - Thunderbird]
pref("browser.phoenix.status", "005");
pref("dom.block_download_insecure", true); // [DEFAULT]
pref("browser.download.alwaysOpenPanel", true); // [DEFAULT - Desktop] [HIDDEN - Android/Thunderbird]
pref("browser.download.manager.addToRecentDocs", false);
pref("browser.download.always_ask_before_handling_new_types", true);
pref("browser.download.useDownloadDir", false); // [DEFAULT - Thunderbird]
pref("browser.phoenix.status", "006");
pref("security.certerror.hideAddException", false); // [HIDDEN] [DEFAULT]
pref("network.dns.force_use_https_rr", true);
pref("security.remote_settings.intermediates.enabled", true); // [DEFAULT]
pref("security.insecure_connection_text.enabled", true);
pref("security.insecure_connection_text.pbmode.enabled", true);
pref("security.ssl.treat_unsafe_negotiation_as_broken", true);
pref("security.insecure_field_warning.ignore_local_ip_address", false);
pref("security.warn_submit_secure_to_insecure", true); // [DEFAULT]
pref("security.osclientcerts.autoload", false); // [DEFAULT - Thunderbird]
pref("security.tls.insecure_fallback_hosts", ""); // [DEFAULT]
pref("security.tls.version.enable-deprecated", false, locked); // [DEFAULT]
pref("security.ssl3.dhe_rsa_aes_128_sha", false); // [DEFAULT]
pref("security.ssl3.dhe_rsa_aes_256_sha", false); // [DEFAULT]
pref("security.ssl3.ecdhe_ecdsa_aes_128_sha", false); // [DEFAULT] TLS_ECDHE_ECDSA_WITH_AES_128_CBC_SHA
pref("security.ssl3.ecdhe_ecdsa_aes_256_sha", false); // [DEFAULT - Nightly] TLS_ECDHE_ECDSA_WITH_AES_256_CBC_SHA
pref("security.OCSP.enabled", 0); // [NO-MAIL]
pref("security.OCSP.require", false); // [NO-MAIL] [DEFAULT]
pref("network.parental_controls_cached_state", false, locked); // [DEFAULT]
pref("security.restrict_to_adults.always", false, locked); // [DEFAULT]
pref("security.restrict_to_adults.respect_platform", false, locked); // [DEFAULT]
pref("security.qwacs.enabled", false, locked); // [DEFAULT - Android]
pref("dom.security.https_only_mode_send_http_background_request", false);
pref("security.certerrors.mitm.auto_enable_enterprise_roots", false); // [HIDDEN - Android/Thunderbird] [DEFAULT]
pref("security.enterprise_roots.enabled", false); // [DEFAULT]
pref("network.http.http3.disable_when_third_party_roots_found", false);
pref("network.http.http3.enable_0rtt", false); // For HTTP3 https://bugzilla.mozilla.org/show_bug.cgi?id=1689550
pref("security.tls.enable_0rtt_data", false);
pref("security.pki.certificate_transparency.disable_for_hosts", ""); // [DEFAULT]
pref("security.pki.certificate_transparency.disable_for_spki_hashes", ""); // [DEFAULT]
pref("security.pki.certificate_transparency.mode", 2); // [DEFAULT - non-Nightly Android]
pref("security.pki.crlite_channel", "default"); // [DEFAULT - non-Android] Use CRLite clubcards that contain all revocations, instead of just "priority" revocations
pref("security.pki.crlite_mode", 2); // [DEFAULT - Nightly]
pref("security.remote_settings.crlite_filters.enabled", true); // [DEFAULT - non-Android]
pref("security.tls.enable_delegated_credentials", true); // [DEFAULT]
pref("dom.security.https_first", true); // [DEFAULT]
pref("dom.security.https_first_add_exception_on_failure", false); // Prevent automatically exempting domains, so that HTTPS-First is always tried no matter what
pref("dom.security.https_first_for_custom_ports", true);
pref("dom.security.https_first_for_local_addresses", true);
pref("dom.security.https_first_for_unknown_suffixes", true);
pref("dom.security.https_first_pbm", true); // [DEFAULT]
pref("dom.security.https_first_schemeless", true); // [DEFAULT]
pref("dom.security.https_only_mode", true);
pref("dom.security.https_only_mode.upgrade_local", true); // Enforce HTTPS-Only Mode for local requests
pref("dom.security.https_only_mode_pbm", true);
pref("dom.security.https_only_mode_error_page_user_suggestions", true); // Show suggestions when an HTTPS page can not be found - ex. if 'example.com' is insecure, the browser may suggest trying to connect to 'www.example.com' instead
pref("security.certerrors.mitm.priming.enabled", true); // [HIDDEN - Android/Thunderbird] [DEFAULT - non-Android/Thunderbird]
pref("security.certerrors.mitm.priming.endpoint", "https://mitmdetection.services.mozilla.com/"); // [HIDDEN - Android/Thunderbird] [DEFAULT - non-Android/Thunderbird]
pref("security.ssl.enable_ocsp_must_staple", true); // [DEFAULT]
pref("security.ssl.enable_ocsp_stapling", true); // [DEFAULT]
pref("media.webrtc.enable_pq_hybrid_kex", true); // [DEFAULT]
pref("media.webrtc.send_mlkem_keyshare", true); // [DEFAULT]
pref("network.http.http3.enable_kyber", true); // [DEFAULT]
pref("security.tls.client_hello.send_p256_keyshare", true); // [DEFAULT]
pref("security.tls.enable_kyber", true); // [DEFAULT]
pref("network.http.prompt-temp-redirect", true);
pref("security.cert_pinning.enforcement_level", 3);
pref("security.tls.hello_downgrade_check", true); // [DEFAULT]
pref("network.fetch.systemDefaultsToOmittingCredentials", true); // [DEFAULT]
pref("network.stricttransportsecurity.preloadlist", true); // [DEFAULT]
pref("security.certerrors.permanentOverride", false); // [HIDDEN - Android/Thunderbird]
pref("network.websocket.allowInsecureFromHTTPS", false); // [DEFAULT]
pref("security.ssl.require_safe_negotiation", true);
pref("browser.xul.error_pages.expert_bad_cert", true);
pref("dom.securecontext.allowlist", ""); // [HIDDEN] [DEFAULT] This can be used for adding exceptions: https://searchfox.org/firefox-main/rev/82e2435f/dom/security/nsMixedContentBlocker.cpp#270
pref("security.mixed_content.block_active_content", true); // [DEFAULT - non-Thunderbird]
pref("security.mixed_content.block_display_content", false); // [DEFAULT] Unnecessary with the "security.mixed_content.upgrade_display_content" pref - that pref tries to upgrade mixed content by default and still blocks it if fails, this pref just blocks all mixed content entirely, causing unnecessary breakage for users: https://github.com/mozilla/policy-templates/issues/1141
pref("security.mixed_content.upgrade_display_content", true); // [DEFAULT]
pref("browser.phoenix.status", "007");
pref("network.early-hints.enabled", false);
pref("network.early-hints.over-http-v1-1.enabled", false);
pref("network.early-hints.preconnect.enabled", false);
pref("network.early-hints.preconnect.max_connections", 0);
pref("dom.prefetch_dns_for_anchor_http_document", false); // https://gitlab.torproject.org/tpo/applications/tor-browser/-/issues/42684
pref("dom.prefetch_dns_for_anchor_https_document", false); // [DEFAULT] https://gitlab.torproject.org/tpo/applications/tor-browser/-/issues/42684
pref("network.dns.disablePrefetch", true);
pref("network.dns.disablePrefetchFromHTTPS", true);
pref("network.dns.prefetch_via_proxy", false); // [DEFAULT]
pref("network.http.speculative-parallel-limit", 0); // [DEFAULT - Thunderbird]
pref("network.predictor.enable-hover-on-ssl", false); // [DEFAULT] https://searchfox.org/firefox-main/rev/3c918058/docshell/base/nsDocShell.cpp#14207
pref("network.prefetch-next", false);
pref("network.preconnect", false);
pref("middlemouse.paste", false);
pref("browser.tabs.searchclipboardfor.middleclick", false);
pref("middlemouse.contentLoadURL", false); // [DEFAULT]
pref("browser.phoenix.status", "008");
pref("browser.search.separatePrivateDefault.ui.enabled", true); // [NO-MAIL]
pref("network.IDN_show_punycode", true);
pref("browser.search.suggest.enabled", false); // [DEFAULT - Android]
pref("browser.search.suggest.enabled.private", false); // [DEFAULT]
pref("browser.search.rustSelector.featureGate", true); // [DEFAULT]
pref("browser.search.separatePrivateDefault.urlbarResult.enabled", true); // [NO-MAIL] [HIDDEN]
pref("browser.search.removeEngineInfobar.enabled", true); // [DEFAULT]
pref("browser.search.separatePrivateDefault", false);
pref("browser.phoenix.status", "009");
pref("doh-rollout.provider-list", '[{"uri":"https://base.dns.mullvad.net/dns-query","UIName":"Mullvad (Base) 🇸🇪","autoDefault":true},{"uri":"https://mozilla.cloudflare-dns.com/dns-query","UIName":"Cloudflare 🇺🇸","autoDefault":false},{"uri":"https://security.cloudflare-dns.com/dns-query","UIName":"Cloudflare (Malware Protection) 🇺🇸","autoDefault":false},{"uri":"https://noads.joindns4.eu/dns-query","UIName":"DNS4EU (Ad Blocking) 🇨🇿","autoDefault":false},{"uri":"https://protective.joindns4.eu/dns-query","UIName":"DNS4EU (Protective) 🇨🇿","autoDefault":false},{"uri":"https://unfiltered.joindns4.eu/dns-query","UIName":"DNS4EU (Unfiltered) 🇨🇿","autoDefault":false},{"uri":"https://dns.mullvad.net/dns-query","UIName":"Mullvad (Unfiltered) 🇸🇪","autoDefault":false}]'); // [HIDDEN]
pref("network.trr.default_provider_uri", "https://base.dns.mullvad.net/dns-query"); // Set the default DoH Provider to Mullvad (Base)
pref("network.connectivity-service.DNS_HTTPS.domain", "");
pref("network.trr.attempt-when-retrying-confirmation", true); // Ensure we always attempt to use DoH no matter what, regardless of the confirmation connectivity check https://searchfox.org/firefox-main/rev/e535ba2b/netwerk/dns/TRRService.cpp#286
pref("network.trr.confirmationNS", "skip"); // https://searchfox.org/firefox-main/rev/e535ba2b/netwerk/dns/TRRService.cpp#273
pref("network.trr.skip-check-for-blocked-host", true); // https://searchfox.org/firefox-main/rev/82e2435f/netwerk/dns/TRRService.cpp#1062
pref("network.trr.wait-for-confirmation", false); // [DEFAULT] Ensure we always attempt to use DoH no matter what, regardless of the confirmation connectivity check https://searchfox.org/firefox-main/rev/e535ba2b/netwerk/dns/TRRService.cpp#282
pref("network.trr.useGET", false); // https://bugzilla.mozilla.org/show_bug.cgi?id=1699759
pref("network.trr.disable-ECS", true); // [DEFAULT]
pref("network.notify.changed", false);
pref("network.notify.checkForNRPT", false);
pref("network.notify.checkForProxies", false);
pref("network.notify.dnsSuffixList", false);
pref("network.notify.initial_call", false);
pref("network.notify.IPv6", false); // [DEFAULT - Windows]
pref("network.notify.resolvers", false);
pref("network.trr.allow-rfc1918", false); // [DEFAULT]
pref("network.trr.mode", 3);
pref("network.dns.echconfig.enabled", true); // [DEFAULT]
pref("network.dns.http3_echconfig.enabled", true); // [DEFAULT]
pref("network.dns.native_https_query", true); // [DEFAULT]
pref("network.dns.native_https_query_in_automation", true); // Used in automation
pref("network.http.http3.sni-slicing", true); // [DEFAULT]
pref("network.trr.clear-cache-on-pref-change", true); // [DEFAULT]
pref("network.trr.bootstrapAddr", ""); // [HIDDEN] [DEFAULT]
pref("network.dns.preferIPv6", true);
pref("network.trr.exclude-etc-hosts", false);
pref("network.trr.send_accept-language_headers", false); // [DEFAULT]
pref("network.trr.send_empty_accept-encoding_headers", true); // [DEFAULT]
pref("network.trr.send_user-agent_headers", false); // [DEFAULT]
pref("network.trr.allow_default_http3_first", true); // [DEFAULT - Nightly]
pref("network.trr.force_http3_first", true);
pref("network.trr.builtin-excluded-domains", "localhost,local,aa.entertainment.viasat.com,aa.viasat.com,aafes.wifi.viasat.com,aainflight.com,account.network-auth.com,acwifi.com,aerlingus-wifi.com,airborne.gogoinflight.com,airbornemedia.inflightinternet.com,airbornesecure.inflightinternet.com,aircanadawifi.com,airtime.geemedia.com,alaskawifi.com,amtrakconnect.com,amtrakwifi.com,ana-inflight-wifi.com,ap1.cloudguest.central.arubanetworks.com,ap1-elb.cloudguest.central.arubanetworks.com,apaceast.cloudguest.central.arubanetworks.com,apaceast-elb.cloudguest.central.arubanetworks.com,apacsouth.cloudguest.central.arubanetworks.com,apacsouth-elb.cloudguest.central.arubanetworks.com,api.airtime.geemedia.com,app.central.arubanetworks.com,app.central.arubanetworks.com.cn,app-apaceast.central.arubanetworks.com,app-apacsouth.central.arubanetworks.com,app-ca.central.arubanetworks.com,app-prod2.central.arubanetworks.com,app-yoda.arubathena.com,app1.central.arubanetworks.com,app1-ap.central.arubanetworks.com,app1-ap-h2.central.arubanetworks.com,app1-h2.central.arubanetworks.com,app2-ap.central.arubanetworks.com,app2-ap-ofc.central.arubanetworks.com,app2-eu.central.arubanetworks.com,app2-eu-ofc.central.arubanetworks.com,app2-ofc.central.arubanetworks.com,aruba.odyssys.net,arubanetworks.com,arubanetworks.com.cn,asset-acms.anuvu.cloud,atlanta-airport.com,atlwifi.atlanta-airport.com,atlwifi0.atlanta-airport.com,atlwifi1.atlanta-airport.com,atlwifi2.atlanta-airport.com,atlwifi3.atlanta-airport.com,atlwifi4.atlanta-airport.com,atlwifi5.atlanta-airport.com,atlwifi6.atlanta-airport.com,atlwifi7.atlanta-airport.com,atlwifi8.atlanta-airport.com,atlwifi9.atlanta-airport.com,atlwifi10.atlanta-airport.com,atlwifi11.atlanta-airport.com,atlwifi12.atlanta-airport.com,atlwifi13.atlanta-airport.com,atlwifi14.atlanta-airport.com,atlwifi15.atlanta-airport.com,atlwifi16.atlanta-airport.com,atlwifi17.atlanta-airport.com,auth.hotspotportals.com,auth.hpe.com,awn.wifi.viasat.com,bap.aws.opennetworkexchange.net,bsas.wifi.viasat.com,buy.gogoinflight.com,bwiam.cust.blueprintrf.com,btwifi.com,ca.cloudguest.central.arubanetworks.com,ca-elb.cloudguest.central.arubanetworks.com,captive.gogoinflight.com,captive.inflightinternet.com,captive.o2wifi.co.uk,captive-2020.aio.cloudauth.net,captive-2022.aio.cloudauth.net,captivemgr.o2wifi.net.uk,captiveportal-login.belex.com,carnivalwifi.com,cbp-guest.cbp.dhs.gov,cdnhotspot.afd.azureedge.net,cdnhotspot.azureedge.net,central.access.network,charter.guestinternet.com,cfr-mprtuam-01.cops.us1.pr.anuvu.cloud,cloud.imedia.ie,cms.airtime.geemedia.com,cms-scdn.airtime.geemedia.com,connect.edge.ihg.com,connect.klm.com,connect.klm.com-01.edgekey.net,connect.viasat.com,connect-edge.ihg.com,connected.southwestwifi.com,connected.xfinity.com,controller.access.network,cp-app.wifi.connected.xfinity.com,cp-app.wifi-dev.connected.xfinity.com,cp-app.wifi-stage.connected.xfinity.com,cp-app-east.wifi.connected.xfinity.com,cp-app-east.wifi-dev.connected.xfinity.com,cp-app-east.wifi-stage.connected.xfinity.com,cp-webapp.wifi.connected.xfinity.com,cp-webapp.wifi-dev.connected.xfinity.com,cp-webapp.wifi-stage.connected.xfinity.com,cust.blueprintrf.com,dalan.cust.blueprintrf.com,deltawifi.com,device.arubanetworks.com,device.central.arubanetworks.com.cn,device-apaceast.central.arubanetworks.com,device-apaceast-h2.central.arubanetworks.com,device-apacsouth.central.arubanetworks.com,device-apacsouth-h2.central.arubanetworks.com,device-ca.central.arubanetworks.com,device-ca-h2.central.arubanetworks.com,device-eu.central.arubanetworks.com,device-eu-h2.central.arubanetworks.com,device-h2.central.arubanetworks.com.cn,device-prod2.central.arubanetworks.com,device-prod2-h2.central.arubanetworks.com,device-yoda2.arubadev.cloud.hpe.com,devices-v2.arubanetworks.com,directaccess.viasat.com,dlrguest-captive.disney.com,doubletree.hiltonwifi.com,ee-wifi.ee.co.uk,esaconnect.extendedstayamerica.com,etihadwi-fly.com,euw1.cloudguest.central.arubanetworks.com,euw1-elb.cloudguest.central.arubanetworks.com,fedsso.yum.com,files.aa.entertainment.viasat.com,flyfi.com,foo.cust.blueprintrf.com,freewlan.sbb.ch,getconnected.southwestwifi.com,guestinternet.com,guestinternet.com.s3-website-us-east-1.amazonaws.com,gogoinair.com,gogoinflight.com,gp1.wendys.com,hamptoninn.hiltonwifi.com,hilton.hiltonwifi.com,hiltongardeninn.hiltonwifi.com,hiltonwifi.com,hotspotportals.com,hs.imedia.ie,hs1ga.wanderingwifi.com,httpforever.com,iceportal.de,inflight.pacwisp.net,inflight-wifi.com,inflightinternet.com,initial.southwestwifi.com,internal.central.arubanetworks.com,internal2.central.arubanetworks.com,internal2-public-device-nc-nlb-b71ba3c951b09682.elb.us-west-2.amazonaws.com,internal2-public-device-nlb-2e2273d4267c0682.elb.us-west-2.amazonaws.com,internetupgrade.marriott.com,kong-gtw-portal-apse2prod5-lb-1386339370.ap-southeast-2.elb.amazonaws.com,kong-gtw-portal-eu-lb-1104785228.eu-central-1.elb.amazonaws.com,kong-gtw-portal-mec1prod6-lb-2104849938.me-central-1.elb.amazonaws.com,kong-gtw-portal-production-lb-686216184.us-west-1.elb.amazonaws.com,kong-gtw-portal-use1prod2-lb-291057632.us-east-1.elb.amazonaws.com,krisworld.singaporeair.com,kw.sq.com,landing.sbb.ch,live.virginwifi.com,loggedin.wifigem.it,login.amtrakwifi.com,login.attwifi.com,login.cloud5.com,login.cloudi-fi.net,login.innflux.com,login.wifigem.com,login.wifionice.de,login.windstream.com,login-awe-cluster.attwifi.com,login-federated.windstream.com,loginportal1.wanderingwifi.com,loginportal3.wanderingwifi.com,loginportal5.wanderingwifi.com,loginportal5ga.wanderingwifi.com,loginportal8.wanderingwifi.com,lounge.aa.com,lpv.attwifi.com,lufthansa-flynet.com,managedwifi.xfinity.com,marriottwifi.com,massportwifi.com,mcita.cust.blueprintrf.com,medallionclass.com,media.southwestwifi.com,mscwifi.com,msftguest-virtual.partners.extranet.microsoft.com,mt1.datavalet.io,n143.network-auth.com,na.network-auth.com,nacportal.massportwifi.com,nae1.cloudguest.central.arubanetworks.com,nae1-elb.cloudguest.central.arubanetworks.com,naw2.cloudguest.central.arubanetworks.com,naw2-elb.cloudguest.central.arubanetworks.com,network-auth.com,neverssl.com,nossl.com,ofc.central.arubanetworks.com.cn,ofc-apaceast.central.arubanetworks.com,ofc-apacsouth.central.arubanetworks.com,ofc-ca.central.arubanetworks.com,ofc-prod2.central.arubanetworks.com,ofc-yoda2.arubadev.cloud.hpe.com,onboard.eurostar.com,onboard.sbb.ch,onboardicafe.com,pay.viasat.com,pay.viasat.com.00d70000000k0rweak.live.siteforce.com,portal.ac2.mist.com,portal.ac5.mist.com,portal.ac6.mist.com,portal.arubainstanton.com,portal.central.arubanetworks.com,portal.central.arubanetworks.com.cn,portal.eu.mist.com,portal.gc1.mist.com,portal.gc2.mist.com,portal.gc3.mist.com,portal.inflight-wifi.com,portal.live.virginwifi.com,portal.massportwifi.com,portal.mist.com,portal.moovmanage.com,portal-apac.central.arubanetworks.com,portal-apaceast.central.arubanetworks.com,portal-apacsouth.central.arubanetworks.com,portal-ca.central.arubanetworks.com,portal-eu.central.arubanetworks.com,portal-eucentral3.central.arubanetworks.com,portal-prod2.central.arubanetworks.com,portal-prodf1.acf.aruba-central.com,portal-uswest4.central.arubanetworks.com,qa-connect-edge.ihg.com,rcs.arubathena.com,rcs-m.arubathena.com,rcs-ng-yoda2.arubadev.cloud.hpe.com,regio-guide.de,register.onboard.eurostar.com,rougewifi.com,rsc.att.com,rsc.wayport.net,sbahnstuttgart.zugportal.de,sbux-j3.datavalet.io,sbux-portal.globalreachtech.com,sbux-portal.odyssys.net,secure.11os.com,secure.datavalet.io,secure.guestinternet.com,secure.wayport.net,secure-login.attwifi.com,securelogin.arubanetworks.com,secureprofile.wifi.connected.xfinity.com,service.thecloud.net,shop.ba.com,singaporeair-krisworld.com,southwestwifi.com,sponsoredaccess.viasat.com,sso.app.arubanetworks.com,sso.arubanetworks.com,sso.wendys.com,stage.connect.edge.ihg.com,starbucks-east.datavalet.io,stay.marriottbonvoy.com,swa.mychasecreditcards.com,test-crm.southwestwifi.com,thalysnet.com,thd.cloudauth.net,timhortonswifi.com,tvgreyhound.com,unitedprivatescreening.com,unitedwifi.com,universal-orlando.ampthink.com,upt.wifi.viasat.com,us.timhortonswifi.com,utils.gogoinflight.com,uucp.wifi.viasat.com,vgw1-03.phl-philly-iap.lpv.attwifi.com,viasat.com,viasat.com.00d70000000k0rweak.live.siteforce.com,virginwifi.com,wanderingwifi.com,we.windstream.com,weconnect.wendys.com,wifi.airasia.com,wifi.bahn.de,wifi.cathaypacific.com,wifi.connected.xfinity.com,wifi.delta.com,wifi.esa.com,wifi.gogoinflight.com,wifi.inflightinternet.com,wifi.kfc.com,wifi.panerabread.com,wifi.singaporeair.com,wifi.sncf,wifi.starbucks.com,wifi.tgv-lyria.com,wifi.tgvlyria.com,wifi.united.com,wifi.united.com.edgekey.net,wifi.we.co,wifi.xfinity.com,wifi-dev.connected.xfinity.com,wifi-stage.connected.xfinity.com,wifi-viarail.ca,wifi-xdb.boingohotspot.net,wifi1.kfc.com,wifi1.viasat.com,wifi2.kfc.com,wifihotspot.io,wifilauncher.com,wifilauncher.com.s3-website.us-east-1.amazonaws.com,wifilrn-ch2-1p.xfinity.com,wifionboard.com,wingsconnect.aero,wirelessportal.americanexpress.com,wirelessportal.americanexpress.com.akadns.net,wirelessportal2.americanexpress.com.akadns.net,wlb1.us-east-1.sbux-portal.globalreachtech.com,wlb1-1579773356.us-east-1.elb.amazonaws.com,www.aainflight.com,www.acwifi.com,www.aerlingus-wifi.com,www.aircanadawifi.com,www.alaskawifi.com,www.amtrakconnect.com,www.ana-inflight-wifi.com,www.btwifi.com,www.carnivalwifi.com,www.deltawifi.com,www.directaccess.viasat.com,www.flyfi.com,www.gogoinair.com,www.gogoinflight.com,www.guestinternet.com,www.guestinternet.com.s3-website-us-east-1.amazonaws.com,www.hiltonwifi.com,www.httpforever.com,www.iceportal.de,www.inflight-wifi.com,www.lufthansa-flynet.com,www.marriottwifi.com,www.medallionclass.com,www.nossl.com,www.neverssl.com,www.onboardicafe.com,www.rougewifi.com,www.secure.datavalet.io,www.singaporeair-krisworld.com,www.southwestwifi.com,www.sponsoredaccess.viasat.com,www.thalysnet.com,www.timhortonswifi.com,www.unitedprivatescreening.com,www.unitedwifi.com,www.wifi.singaporeair.com,www.wifilauncher.com,www.wifilauncher.com.s3-website.us-east-1.amazonaws.com,www.wifionboard.com,www.wingsconnect.aero,www.zugportal.de,yoda-cgqa.arubathena.com,yoda-cgqa-elb.arubathena.com,yoda2-ofc-nlb-f4f923213a2189c7.elb.us-west-2.amazonaws.com,yoda2-public-device-nlb-8343995ce4714f6f.elb.us-west-2.amazonaws.com,yoda2-rcs-nlb-0c9df3882f3f7416.elb.us-west-2.amazonaws.com,zugportal.de"); // [ANDROID-ONLY] [DEFAULT: localhost, local]
pref("browser.phoenix.status", "010");
pref("network.proxy.type", 0);
pref("extensions.webextensions.early_background_wakeup_on_request", true); // [HIDDEN - non-Android] [DEFAULT - Android]
pref("network.proxy.failover_direct", false);
pref("network.file.path_blacklist", ""); // [ANDROID-ONLY] [HIDDEN] [DEFAULT]
pref("network.gio.supported-protocols", ""); // [HIDDEN]
pref("network.file.disable_unc_paths", true); // [HIDDEN]
pref("network.tickle-wifi.enabled", false); // [DEFAULT - non-Android]
pref("network.proxy.allow_bypass", false);
pref("network.proxy.socks_remote_dns", true);
pref("network.proxy.socks5_remote_dns", true); // [DEFAULT]
pref("browser.phoenix.status", "011");
pref("privacy.webrtc.allowSilencingNotifications", true); // [HIDDEN - Android/Thunderbird] [DEFAULT]
pref("privacy.webrtc.hideGlobalIndicator", false); // [HIDDEN - Android/Thunderbird] [DEFAULT]
pref("media.peerconnection.ice.no_host", true); // [EXTENDED-ONLY]
pref("media.peerconnection.mtransport_process", true); // [HIDDEN - Android/Thunderbird] [DEFAULT]
pref("media.webrtc.net.force_disable_rtcp_reception", true);
pref("privacy.webrtc.globalMuteToggles", true); // [HIDDEN - Android]
pref("media.peerconnection.ice.obfuscate_host_addresses", true); // [DEFAULT - non-Android]
pref("media.peerconnection.ice.default_address_only", true); // [EXTENDED-ONLY]
pref("media.peerconnection.ice.relay_only", true); // [EXTENDED-ONLY]
pref("media.peerconnection.ice.proxy_only_if_behind_proxy", true);
pref("privacy.webrtc.sharedTabWarning", true); // [HIDDEN - Android/Thunderbird]
pref("browser.phoenix.status", "012");
pref("media.eme.enabled.0.NOTE", "DRM/EME is NOT supported or recommended.");
pref("media.eme.enabled.1.NOTE", "Enabling it WILL compromise your privacy/security.");
pref("media.eme.enabled.2.NOTE", "Proceed at your own caution.");
pref("media.eme.enabled.3.NOTE", "You will also need to enable a CDM."); // [ANDROID-ONLY]
pref("media.eme.enabled.4.NOTE", "See media.mediadrm-widevinecdm.visible."); // [ANDROID-ONLY]
pref("media.autoplay.default", 5);
pref("media.geckoview.autoplay.request.testing", 2); // [DEFAULT: 0 - Follows the Autoplay site permission]
pref("media.autoplay.blocking_policy", 1);
pref("media.eme.enabled", false);
pref("media.eme.require-app-approval", true); // [DEFAULT - Android] https://bugzilla.mozilla.org/show_bug.cgi?id=1620102 https://searchfox.org/firefox-main/rev/82e2435f/dom/media/eme/MediaKeySystemAccessPermissionRequest.h#17
pref("media.eme.require-app-approval.prompt.testing", true); // [HIDDEN] https://searchfox.org/firefox-main/rev/881a9b31/dom/media/eme/MediaKeySystemAccessPermissionRequest.h#21
pref("media.eme.require-app-approval.prompt.testing.allow", false); // [HIDDEN] https://searchfox.org/firefox-main/rev/881a9b31/dom/media/eme/MediaKeySystemAccessPermissionRequest.h#21
pref("media.mediadrm-widevinecdm.visible", false); // [ANDROID-ONLY] Android's MediaDrm API - https://developer.android.com/reference/android/media/MediaDrm https://bugzilla.mozilla.org/show_bug.cgi?id=1306219
pref("media.eme.mediadrm.origin-id.enabled", true); // [DEFAULT - Android] [DEFENSE IN DEPTH]
pref("media.gmp-manager.updateEnabled", false); // [HIDDEN]
pref("media.gmp.decoder.enabled", false); // [ANDROID-ONLY]
pref("media.gmp.encoder.enabled", false); // [DEFAULT]
pref("media.gmp-manager.allowLocalSources", false);
pref("media.gmp.log.dump", false); // [HIDDEN] [DEFAULT]
pref("media.gmp.log.level", 70); // [HIDDEN] Limits logging to fatal only
pref("media.hls.enabled", false); // [ANDROID-ONLY]
pref("media.ffmpeg.allow-openh264", false); // [DEFAULT - Nightly]
pref("media.gmp-gmpopenh264.enabled", false);
pref("media.gmp-gmpopenh264.visible", false); // Don't display in UI/`about:addons`
pref("media.webrtc.encoder_creation_strategy", 1); // [DEFAULT - Android] Ensure we prefer to use hardware encoding instead of OpenH264/GMP https://searchfox.org/firefox-main/rev/7c07e6f2/modules/libpref/init/StaticPrefList.yaml#13519
pref("media.webrtc.hw.h264.enabled", true); // [DEFAULT - Android] Enables H264 hardware decoding https://bugzilla.mozilla.org/show_bug.cgi?id=1717679
pref("media.rdd-ffmpeg.enabled", true); // [DEFAULT]
pref("media.rdd-ffvpx.enabled", true); // [DEFAULT - non-Android]
pref("media.rdd-opus.enabled", true); // [DEFAULT - non-Android]
pref("media.rdd-vorbis.enabled", true); // [DEFAULT - non-Android]
pref("media.rdd-vpx.enabled", true); // [DEFAULT - non-Android]
pref("media.rdd-wav.enabled", true); // [DEFAULT - non-Android]
pref("media.ffvpx-hw.enabled", true); // [DEFAULT - Linux, Windows Nightly]
pref("media.gmp.decoder.preferred", false); // [DEFAULT]
pref("media.hardware-video-decoding.enabled", true); // [DEFAULT]
    // pref("media.android-media-codec.enabled", false); // [ANDROID-ONLY] Currently required for media playback :(
pref("media.android-media-codec.preferred", false); // [ANDROID-ONLY]
pref("media.ffmpeg.encoder.enabled", true); // [DEFAULT - non-Android]
pref("media.gmp.encoder.preferred", false); // [DEFAULT]
pref("media.hardware-video-encoding.enabled", true); // [DEFAULT]
pref("media.use-remote-encoder.audio", true);
pref("media.use-remote-encoder.video", true); // [NO-WINDOWS] Do not set on Windows for now, due to performance/stability issues: https://codeberg.org/celenity/Phoenix/issues/253#issuecomment-12472035
pref("media.gmp.decoder.multithreaded", true);
pref("media.gmp.encoder.multithreaded", true);
pref("media.gmp-provider.enabled", true); // [DEFAULT - non-Thunderbird]
pref("media.gmp-manager.url", "https://aus5.mozilla.org/update/3/GMP/%VERSION%/%BUILD_ID%/%BUILD_TARGET%/%LOCALE%/%CHANNEL%/%OS_VERSION%/%DISTRIBUTION%/%DISTRIBUTION_VERSION%/update.xml"); // [DEFAULT]
pref("media.gmp-manager.url.override", ""); // [HIDDEN] [DEFAULT] To expose via `about:config`, and some override this to a no-op URL as well
pref("media.allow-audio-non-utility", false); // [DEFAULT - non-iOS]
pref("media.utility-process.enabled", true); // [DEFAULT]
pref("media.utility-android-media-codec.enabled", true); // [ANDROID-ONLY] For the Android MediaCodec PlatformDecoderModule
pref("browser.phoenix.status", "013");
pref("javascript.options.asmjs", false); // [DEFAULT] https://bugzilla.mozilla.org/show_bug.cgi?id=2002635
pref("gfx.font_rendering.graphite.enabled", false);
pref("gfx.font_rendering.opentype_svg.enabled", false);
pref("javascript.options.baselinejit", false); // Baseline Compiler
pref("javascript.options.ion", false); // WarpMonkey
pref("javascript.options.jithints", false); // Eager baseline hints https://bugzilla.mozilla.org/show_bug.cgi?id=1831572
// pref("javascript.options.main_process_disable_jit", true); // [DEFAULT - iOS] Disable all JITs for the (critical/especially sensitive) parent process https://searchfox.org/firefox-main/rev/1c6a8b56/xpcom/build/XPCOMInit.cpp#239 https://firefox-source-docs.mozilla.org/dom/ipc/process_model.html#parent-process
pref("javascript.options.native_regexp", false); // irregexp JIT, for regex evaluation https://searchfox.org/firefox-main/rev/dc1c78e9/modules/libpref/init/StaticPrefList.yaml#8741 https://searchfox.org/firefox-main/rev/dc1c78e9/js/xpconnect/src/XPCJSContext.cpp#901
pref("javascript.options.wasm_optimizingjit", false); // WASM-Ion (BaldrMonkey)
pref("javascript.options.main_process_disable_jit", true); // [EXTENDED-ONLY]
pref("image.jxl.enabled", false); // [DEFAULT] [HIDDEN (Undefined) - non-MOZ_JXL builds]
pref("mathml.disabled", true);
pref("javascript.options.self_hosted.use_shared_memory", false);
pref("dom.postMessage.sharedArrayBuffer.bypassCOOP_COEP.insecure.enabled", false); // [DEFAULT]
pref("dom.postMessage.sharedArrayBuffer.withCOOP_COEP", false); // [NO-MAIL]
pref("javascript.options.wasm", false); // [EXTENDED-ONLY]
pref("webgl.disabled", true); // [EXTENDED-ONLY] [ANDROID-ONLY]
pref("permissions.default.xr", 2); // [HIDDEN - Android/Thunderbird]
pref("dom.xslt.enabled", false);
pref("javascript.options.jit_trustedprincipals", false); // [HIDDEN] [DEFAULT]
pref("browser.phoenix.status", "014");
pref("signon.storeWhenAutocompleteOff", true); // [DEFAULT]
pref("layout.forms.reveal-password-button.enabled", true);
pref("security.webauthn.always_allow_direct_attestation", false); // [DEFAULT]
pref("security.webauthn.always_allow_direct_attestation", false, locked); // [NO-MAIL] [DEFAULT]
pref("signon.autofillForms", false);
pref("signon.autofillForms.http", false); // [DEFAULT]
pref("network.http.basic_http_auth.enabled", false);
pref("signon.privateBrowsingCapture.enabled", false);
pref("network.http.microsoft-entra-sso.container-enabled.0", false);
pref("network.http.microsoft-entra-sso.enabled", false); // [DEFAULT]
pref("network.http.windows-sso.container-enabled.0", false);
pref("network.http.windows-sso.enabled", false); // [DEFAULT]
pref("network.microsoft-sso-authority-list", ""); // DEFENSE IN DEPTH
pref("network.auth.force-generic-ntlm", false); // [DEFAULT] Ensure we don't enforce use of Firefox's less secure "generic"/internal NTLM implementation https://searchfox.org/firefox-main/rev/c983b985/modules/libpref/init/all.js#1380
pref("network.auth.force-generic-ntlm-v1", false); // [DEFAULT] Ensure we don't enforce use of (the less secure) NTLM v1 over NTLM v2 https://searchfox.org/firefox-main/rev/c983b985/modules/libpref/init/StaticPrefList.yaml#13995
pref("network.automatic-ntlm-auth.allow-non-fqdn", false); // [DEFAULT]
pref("network.automatic-ntlm-auth.allow-proxies", false);
pref("network.automatic-ntlm-auth.trusted-uris", ""); // [DEFAULT]
pref("network.auth.private-browsing-sso", false); // [DEFAULT] [DEFENSE IN DEPTH]
pref("extensions.formautofill.addresses.enabled", false);
pref("extensions.formautofill.addresses.supported", "on"); // This feature is currently only exposed in certain regions by default. We set the browser's region to a dummy value ("XX"), so we need to skip that region check and ensure this is always available.
pref("extensions.formautofill.creditCards.enabled", false);
pref("extensions.formautofill.creditCards.supported", "on"); // [DEFAULT]
pref("signon.rememberSignons", false); // [NO-MAIL]
pref("editor.truncate_user_pastes", false);
pref("network.negotiate-auth.allow-non-fqdn", false); // [DEFAULT]
pref("network.negotiate-auth.allow-proxies", false);
pref("network.negotiate-auth.delegation-uris", ""); // [DEFAULT]
pref("network.negotiate-auth.trusted-uris", ""); // [DEFAULT] Modified by ex. RedHat/Fedora
pref("signon.generation.enabled", true); // [DEFAULT]
pref("dom.payments.request.user_interaction_required", true); // [DEFAULT]
pref("network.auth.subresource-img-cross-origin-http-auth-allow", false); // [DEFAULT - non-Thunderbird]
pref("network.auth.non-web-content-triggered-resources-http-auth-allow", false); // [NO-MAIL] [DEFAULT - non-Thunderbird]
pref("network.auth.subresource-http-auth-allow", 1); // [NO-MAIL]
pref("browser.phoenix.status", "015");
pref("extensions.userContextIsolation.defaults.restricted", "[]"); // [HIDDEN] [DEFAULT]
pref("extensions.userContextIsolation.enabled", true); // [HIDDEN]
pref("extensions.quarantineIgnoredByUser.{290ce447-2abb-4d96-8384-7256dd4a1c43}", true); // Runet Censorship Bypass
pref("extensions.quarantineIgnoredByUser.{446900e4-71c2-419f-a6a7-df9c091e268b}", true); // Bitwarden
pref("extensions.quarantineIgnoredByUser.{5d0d1f87-5991-42d3-98c3-54878ead1ed1}", true); // Censor Tracker
pref("extensions.quarantineIgnoredByUser.{6c00218c-707a-4977-84cf-36df1cef310f}", true); // Port Authority
pref("extensions.quarantineIgnoredByUser.{73a6fe31-595d-460b-a920-fcc0f8843232}", true); // NoScript
pref("extensions.quarantineIgnoredByUser.{b86e4813-687a-43e6-ab65-0bde4ab75758}", true); // LocalCDN
pref("extensions.quarantineIgnoredByUser.{d19a89b9-76c1-4a61-bcd4-49e8de916403}", true); // Mullvad
pref("extensions.quarantineIgnoredByUser.78272b6fa58f4a1abaac99321d503a20@proton.me", true); // Proton Pass
pref("extensions.quarantineIgnoredByUser.adguard-vpn@adguard.com", true); // AdGuard VPN
pref("extensions.quarantineIgnoredByUser.adguardadblocker@adguard.com", true); // AdGuard
pref("extensions.quarantineIgnoredByUser.crxviewer-firefox@robwu.nl", true); // Extension source viewer - important since we add AMO (`addons.mozilla.org`) to our restricted/quarantined domain list
pref("extensions.quarantineIgnoredByUser.foxyproxy@eric.h.jung", true); // FoxyProxy
pref("extensions.quarantineIgnoredByUser.foxyproxy-basic@eric.h.jung", true); // FoxyProxy Basic
pref("extensions.quarantineIgnoredByUser.idcac-pub@guus.ninja", true); // I still don't care about cookies
pref("extensions.quarantineIgnoredByUser.jid1-BoFifL9Vbdl2zQ@jetpack", true); // Decentraleyes
pref("extensions.quarantineIgnoredByUser.jid1-KtlZuoiikVfFew@jetpack", true); // GNU LibreJS
pref("extensions.quarantineIgnoredByUser.jid1-MnnxcxisBPnSXQ@jetpack", true); // Privacy Badger
pref("extensions.quarantineIgnoredByUser.jid1-MnnxcxisBPnSXQ-eff@jetpack", true); // Privacy Badger (from eff.org)
pref("extensions.quarantineIgnoredByUser.keepassxc-browser@keepassxc.org", true); // KeePassXC-Browser
pref("extensions.quarantineIgnoredByUser.skipredirect@sblask", true); // Skip Redirect
pref("extensions.quarantineIgnoredByUser.uBlock0@raymondhill.net", true); // uBlock Origin
pref("extensions.quarantineIgnoredByUser.uBOLiteRedux@raymondhill.net", true); // uBlock Origin Lite
pref("extensions.quarantineIgnoredByUser.vpn@proton.ch", true); // Proton VPN
pref("extensions.quarantineIgnoredByUser.@testpilot-containers", true); // Firefox Multi-Account Containers
pref("extensions.strictCompatibility", false); // [DEFAULT - non-Thunderbird Release/Beta]
pref("extensions.ui.disableUnsignedWarnings", false, locked); // [HIDDEN - non-Thunderbird] [DEFAULT - non-Thunderbird]
pref("extensions.webextensions.remote", true); // [DEFAULT]
pref("xpinstall.signatures.weakSignaturesTemporarilyAllowed", false); // [NO-MAIL] [HIDDEN] [DEFAULT]
pref("extensions.autoDisableScopes", 15); // [DEFAULT - non-Thunderbird] Defense in depth, ensures sideloaded extensions are always disabled by default... (Not locked for desktop because it can be useful in certain instances, ex. for those who use impermanence)
pref("extensions.enabledScopes", 5); // [HIDDEN]
pref("extensions.installDistroAddons", false); // [HIDDEN - non-Android] [DEFAULT - Android]
pref("extensions.sideloadScopes", 0); // [HIDDEN]
pref("extensions.startupScanScopes", 0); // [HIDDEN - Android] [DEFAULT - non-Thunderbird]
pref("extensions.autoDisableScopes", 15, locked); // [ANDROID-ONLY] Locked for Android because this isn't needed/supported or wanted at all there
pref("extensions.addonAbuseReport.url", "");
pref("extensions.webextensions.allow_executeScript_in_moz_extension", false); // [DEFAULT]
pref("xpinstall.enabled", true); // [ANDROID-ONLY] [HIDDEN] [DEFAULT]
pref("extensions.webapi.testing", false); // [DEFAULT] Disables mozAddonManager on Mozilla testing domains
pref("extensions.webapi.testing.http", false); // [DEFAULT] Disables mozAddonManager on Mozilla testing domains using insecure protocols
pref("extensions.webapi.enabled", true); // [ANDROID-ONLY] [DEFAULT]
pref("privacy.resistFingerprinting.block_mozAddonManager", false); // [ANDROID-ONLY] [DEFAULT]
pref("extensions.install_origins.enabled", true);
pref("extensions.webextOptionalPermissionPrompts", true); // [DEFAULT]
pref("extensions.blocklist.enabled", true); // [DEFAULT]
pref("extensions.remoteSettings.disabled", true); // [HIDDEN] Used for downloading/updating Mozilla's list https://searchfox.org/firefox-main/source/toolkit/mozapps/extensions/docs/AMRemoteSettings-overview.rst
pref("extensions.quarantinedDomains.enabled", true); // [DEFAULT]
pref("extensions.quarantinedDomains.list", "autoatendimento.bb.com.br,ibpf.sicredi.com.br,ibpj.sicredi.com.br,internetbanking.caixa.gov.br,www.ib12.bradesco.com.br,www2.bancobrasil.com.br,10.0.0.1,192.168.1.1,192.168.50.1,1password.ca,1password.com,1password.eu,365online.com,account.amd.com,account.apple.com,account.asus.com,account.brave.com,account.collegeboard.org,account.live.com,account.microcenter.com,account.microsoft.com,account.nordpass.com,account.proton.me,account.sony.com,account.t-mobile.com,account-api.proton.me,accounts.1password.ca,accounts.1password.com,accounts.1password.eu,accounts.ent.1password.com,accounts.fedoraproject.org,accounts.firefox.com,accounts.google.com,accounts.nintendo.com,accounts.pixiv.net,accounts.scdn.co,accounts.snapchat.com,accounts.spotify.com,accounts.tb.pro,acs-home-prod-login-fde-hhd4d2h9drbfg7hy.a02.azurefd.net,addons.allizom.org,addons.mozilla.org,addons.thunderbird.net,admin.google.com,adyen.com,agrd.io,agreementexpress.net,alipay.com,alipayobjects.com,alipayplus.com,amazon.syf.com,amazonpay.in,amp.pandora.com,anz.com,anz.com.au,ap.www.namecheap.com,apay-us.amazon.com,api.pnc.com,api.stripe.com,api-auth.soundcloud.com,app.1password.ca,app.1password.com,app.1password.eu,app.advancedmd.com,app.dashlane.com,app.privacy.com,app.tuta.com,appleconnect.apple.com,appleid.apple.com,appleid.cdn-apple.com,applepay.cdn-apple.com,apply.commonapp.org,apps.apple.com,apps.microsoft.com,apps.obtainium.imranr.dev,api-dashboard.search.brave.com,apt.izzysoft.de,archive.mozilla.org,archlinux.org,argenta.be,artists.soundcloud.com,artists.spotify.com,asrock.com,asrockchina.com.cn,assets.loginwithamazon.com,att-yahoo.att.net,attestation.app,aur.archlinux.org,auth.adguard.io,auth.adguardaccount.com,auth.calibour.com,auth.hulu.com,auth.meta.com,auth.max.com,auth.mozilla.auth0.com,auth.openai.com,auth.services.adobe.com,auth.sharefile.io,auth.synchronybank.com,auth.tb.pro,auth-stage.tb.pro,auth.uber.com,auth.wikimedia.org,auth.zennioptical.com,authentication.cardinalcommerce.com,b.stripecdn.com,bancogalicia.com.ar,bank99.at,bankaust.com.au,bankaustria.at,bankdirekt.at,bankeasy.com,bankofamerica.com,bankofireland.com,bankvic.com.au,belfius.be,belkart.by,belveb.by,bendigobank.com.au,binance.com,binance.us,bisq.network,bitpay.com,bitwarden.com,bkash.com,bnpparibasfortis.be,bobpony.com,braintree-api.com,braintreegateway.com,brave.com,brave-browser-apk-beta.s3.brave.com,brave-browser-apk-nightly.s3.brave.com,brave-browser-apk-release.s3.brave.com,build.opensuse.org,businessaccess.citibank.citigroup.com,businessonline-boi.com,cakepay.com,cakewallet.com,calendar.proton.me,calyxos.org,cardcomplete.com,cash.app,cbaccount.collegeboard.org,cbzsecure.com,cdn.akamai.steamstatic.com,cdn.mullvad.net,cdn.plaid.com,cdn.sso.mozilla.com,cdimage.debian.org,checkout.com,checkout.stripe.com,coinspot.com.au,commbank.com.au,console.accrescent.app,console.aws.amazon.com,console.calibour.com,console.cloud.google.com,consumer.intel.com,copr.fedorainfracloud.org,creditcall.com,crelan.be,cromite.org,dash.cloudflare.com,developer.apple.com,developer.nvidia.com,discord.gg,dist.torproject.org,dl.google.com,donate.torproject.org,download.cdn.mozilla.net,download.fedoraproject.org,download.gigabyte.com,download.lineageos.org,download.mozilla.org,download-installer.cdn.mozilla.net,download-installer-origin.cdn.mozilla.net,download-origin.cdn.mozilla.net,drive.google.com,drive.proton.me,dsadata.intel.com,easybanking.unifi-digitalbanking.com,easybankint.com,ebanking.easybank.at,eff.org,ente.io,epicmychart.nychhc.org,epicmychart.optum.com,etoro.com,f-droid.org,fdroid.ironfoxoss.org,fdroid.link,fedoraproject.org,flatex.at,flathub.org,flex.okta.com,franciscanmychart.org,franklincollege.okta.com,ftp.eu.mozilla.org,ftp.mozilla.org,ftp.prod.mozaws.net,ftp.prod.mozilla.org,ftp-ssl.mozilla.org,ftp-test.mozilla.org,galicia.ar,gateway.bank,gatewaybank.bank,gatewaybank.com.au,gatewayfirst.com,gds.google.com,geogroup.okta.com,george.sparkasse.at,george-business.sparkasse.at,gfgsa.com,google-admin.corp.google.com,grapheneos.org,greasyfork.org,guardarian.com,heartland.us,heartlandpaymentsystems.com,heartlandportico.com,hellobank.be,hendrick.okta.com,hpc.freedompay.com,hsbc.com,hsbc.com.au,icard.com,id.fedoraproject.org,id.sonyentertainmentnetwork.com,id.spectrum.net,identity.corp.google.com,identity.doordash.com,identity.eset.com,identity.gtm.eset.com,identity.kde.org,identity.lego.com,identity.walmart.com,idmsa.apple.com,idmsa.apple.com.cn,idmsac.apple.com,idp.ddp.akoya.com,idp.iam.mozilla.com,iforgot.apple.com,ing.com,ing.com.au,ingwb.com,iparitet.by,ironfoxoss.org,itsme-id.com,js.stripe.com,kairoscope.org,kbc.be,kdrp.okta.com,keytradebank.be,klarna.com,kraken.com,laptop-updates.brave.com,lastpass.com,lineageos.org,login.aa.com,login.advancedmd.com,login.amd.com,login.aol.com,login.corp.google.com,login.disney.com,login.eset.com,login.gov,login.kroger.com,login.live.com,login.mailbox.org,login.microsoftonline.com,login.nvgs.nvidia.com,login.okta.com,login.sparkasse.at,login.tailscale.com,login.wikimedia.org,login.yahoo.com,login.yahoo.net,login.xfinity.com,login-app.advancedmd.com,login-dev.advancedmd.com,login-no1a.www.tiktok.com,login3.id.hp.com,login4.fisglobal.com,lowes.syf.com,m.stripe.com,m.stripe.network,magic.falcon-2-eu.veriff.me,magic.veriff.me,mail.proton.me,mailbox.org,marmon.okta.com,matrix.to,mblogin.verizonwireless.com,mebank.com.au,merchant-ui-api.stripe.com,methodurl.psp-solutions.com,microg.org,mirrorbits.lineageos.org,linuxmint.com,login.pnc.com,molly.im,monero.com,mpay24.com,msauth.net,msauthimages.net,msdl.gravesoft.dev,msftauth.net,msftauthimages.net,msp.nordpass.com,mt-bank.net,mtb.com,mullvad.net,my.calibour.com,my.collegeboard.org,my.dish.com,my.disney.com,my.eir.ie,myaccount.google.com,myaccount.microsoft.com,myaccounts.wizards.com,mychart.albanymed.org,mychart.asante.org,mychart.atlantichealth.org,mychart.austinregionalclinic.com,mychart.azacp.com,mychart.bmc.org,mychart.carolinaeasthealth.com,mychart.ccf.org,mychart.centracare.com,mychart.childrenscolorado.org,mychart.clevelandclinic.org,mychart.crmcwy.org,mychart.duly.com,mychart.ecommunity.com,mychart.hopkinsmedicine.org,mychart.inova.org,mychart.kansashealthsystem.com,mychart.lovelace.com,mychart.mainehealth.org,mychart.med.utah.edu,mychart.metrohealth.net,mychart.multicare.org,mychart.mwhc.com,mychart.nghs.com,mychart.nortonhealthcare.org,mychart.ohiohealth.com,mychart.orlandohealth.com,mychart.premierhealthpartners.org,mychart.selfregional.org,mychart.sfdph.org,mychart.sih.net,mychart.stcharleshealthcare.org,mychart.texashealth.org,mychart.tmcaz.com,mychart.uchospitals.edu,mychart.uconn.edu,mychart.uihealthcare.org,mychart.uillinois.edu,mychart.upstate.edu,mychart.urmc.rochester.edu,mychartonline.umassmemorial.org,myhealthchart.com,mysignins.microsoft.com,mysinaichicago.org,mystate.com.au,nab.com.au,nmi.com,nordaccount.com,nordpass.com,nordstrom.okta.com,noscript.net,novantmychart.org,nrc.okta.com,oauth.xfinity.com,oidc.idp.clogin.att.com,ok1static.oktacdn.com,ok2static.oktacdn.com,ok7static.oktacdn.com,okta.jumbo.com,oldsecond.com,onedrive.com,onedrive.live.com,online.citi.com,open-banking.pnc.com,openuserjs.org,outlook.com,outlook.office365.com,ow2-cqm-01.advancedmd.com,panel.nordpass.com,paritetbank.by,pass.proton.me,passwordreset.microsoftonline.com,passwords.google,passwords.google.com,patientportal.advancedmd.com,pay.amazon.co.jp,pay.amazon.co.uk,pay.amazon.com,pay.amazon.de,pay.amazon.es,pay.amazon.eu,pay.amazon.fr,pay.amazon.it,pay.google.com,pay.viasat.com,paybox.com,paybox.com.co,payconiq.be,payeezystrg.z19.web.core.windows.net,payments.amazon.com,payments-amazon.com,payoneer.com,payscout.com,paysend.com,payu.com,paywire.com,play.google.com,plex.direct,portal.corp.google.com,poste.dz,pp-wfe-100.advancedmd.com,ppixiv.org,privacybadger.org,probo.ddp.akoya.com,prod.idp.collegeboard.org,productdelivery.mozilla-backup.org,production.plaid.com,profile.theguardian.com,proton.me,protonapps.com,psendbank.com,qdoba-prod.us.auth0.com,raiffeisen.at,rb.okta.com,register.gitlab.gnome.org,register.mailbox.org,registerdisney.go.com,release.calyxinstitute.org,releases.celenity.dev,releases.ironfoxoss.org,releases.mozilla.org,renault-bank-direkt.de,renaultbank.es,renaultbank.fr,retoswap.com,revolut.com,rh.okta.com,rpmfusion.org,secure.chase.com,secure.informaction.com,secure.login.gov,secure.myvirtua.org,secure.pnc.com,secure.sndcdn.com,secure.soundcloud.com,secure.verizon.com,secure-api.pnc.com,secure-qa.pnc.com,securelogin.synchronybank.com,secureonline.pnc.com,secureonline.yourstatebank.com,send.vis.ee,signal.org,signin.att.com,signin.aws.amazon.com,signin.costco.com,signin.ebay.com,signin-static-js.att.com,signup.ebay.com,skydrive.com,smartpay.profitstars.com,sso.canvaslms.com,sso.fachschaften.org,sso.kroger.com,sso.mozilla.com,sso.redhat.com,start.1password.ca,start.1password.com,start.1password.eu,static.adguard.com,static.adtidy.org,stgeorge.com.au,store.epicgames.com,store.nintendo.com.hk,studio.youtube.com,tam.onecampus.com,tpeweb.paybox.com,tuta.com,u.bank,ubank.bank,ubank.com.au,ubuntu.com,unbelgin.com,unionpayintl.com,unzer.com,up.com.au,us.download.nvidia.com,usaepay.com,usbank.com,vault.bitwarden.com,vault.bitwarden.eu,venmo.com,verifone.com,viewmychart.com,vpn.proton.me,wallet.google,wallet.google.com,wallet.proton.me,wero-wallet.eu,westpac.co.nz,westpac.com.au,wiki.lineageos.org,wise.com,www.365online.com,www.chase.com,www.citi.com,www.citidirect.com,www.cromite.org,www.dashlane.com,www.debian.org,www.easybank.at,www.easybanking.net,www.eff.org,www.epicgames.com,www.firefox.com,www.franciscanmychart.org,www.gigabyte.com,www.icloud.com,www.icloud.com.cn,www.intel.com,www.lineageos.org,www.linuxmint.com,www.macquarie.com.au,www.mozilla.org,www.mychart.org,www.noscript.net,www.onlinebanking.pnc.com,www.paypal.com,www.paypalobjects.com,www.pnc.com,www.privacy.com,www.privatebank.citibank.com,www.sparkasse.at,www.synchrony.com,www.synchronymastercard.com,www.thunderbird.net,www.torproject.org,www.virustotal.com,www.wintrustbank.com,www.wintrustdigitalbanking.com,www.xmrbazaar.com,www.yourstatebank.com,xmrbazaar.com");
pref("extensions.quarantinedDomains.uiDisabled", false); // [HIDDEN] [DEFAULT] UI
pref("extensions.userScripts.mv3.enabled", true); // [DEFAULT]
pref("extensions.webextensions.userScripts.enabled", true); // [DEFAULT]
pref("extensions.userContextIsolation.@testpilot-container.restricted", "[]"); // [HIDDEN]
pref("extensions.userContextIsolation.uBlock0@raymondhill.net.restricted", "[]"); // [HIDDEN]
pref("extensions.webextensions.base-content-security-policy", "script-src 'self' 'wasm-unsafe-eval' 'unsafe-inline'; upgrade-insecure-requests;"); // [ANDROID-ONLY] 'wasm-unsafe-eval' appears to be required here for Translations on Android - doesn't seem to impact other platforms
pref("extensions.webextensions.base-content-security-policy.v3", "script-src 'self'; upgrade-insecure-requests;");
pref("extensions.webextensions.base-content-security-policy.v3-with-localhost", "script-src 'self'; upgrade-insecure-requests;");
pref("extensions.webextensions.default-content-security-policy", "script-src 'self'; upgrade-insecure-requests;");
pref("extensions.webextensions.default-content-security-policy.v3", "script-src 'self'; upgrade-insecure-requests;"); // [DEFAULT]
pref("extensions.postDownloadThirdPartyPrompt", false, locked); // [HIDDEN - Android/Thunderbird] https://github.com/arkenfox/user.js/issues/1090
pref("xpinstall.whitelist.directRequest", false); // [HIDDEN] For direct URL requests https://searchfox.org/firefox-main/rev/82e2435f/toolkit/mozapps/extensions/internal/XPIInstall.sys.mjs#4488
pref("xpinstall.whitelist.fileRequest", false); // [HIDDEN - non-Android] [DEFAULT - Android] For `file://` requests https://searchfox.org/firefox-main/rev/82e2435f/toolkit/mozapps/extensions/internal/XPIInstall.sys.mjs#4500
pref("xpinstall.whitelist.required", true, locked); // [DEFAULT] This is the `Warn you when websites try to install add-ons` setting at `about:preferences#privacy`
pref("extensions.install.requireBuiltInCerts", true); // [HIDDEN]
pref("extensions.update.requireBuiltInCerts", true); // [HIDDEN]
pref("extensions.langpacks.signatures.required", true); // [NO-MAIL] [DEFAULT]
pref("xpinstall.signatures.required", true); // [NO-MAIL] [DEFAULT]
pref("extensions.originControls.grantByDefault", false);
pref("extensions.quarantineIgnoredByUser.{00000f2a-7cde-4f20-83ed-434fcb420d71}", false); // Imagus
pref("extensions.quarantineIgnoredByUser.{1018e4d6-728f-4b20-ad56-37578a4de76b}", false); // Flagfox
pref("extensions.quarantineIgnoredByUser.{154cddeb-4c8b-4627-a478-c7e5b427ffdf}", false); // PopUpOFF - Popup and overlay blocker
pref("extensions.quarantineIgnoredByUser.{2e5ff8c8-32fe-46d0-9fc8-6b8986621f3c}", false); // Search by Image
pref("extensions.quarantineIgnoredByUser.{32af1358-428a-446d-873e-5f8eb5f2a72e}", false); // Download All Images
pref("extensions.quarantineIgnoredByUser.{3c078156-979c-498b-8990-85f7987dd929}", false); // Sidebery
pref("extensions.quarantineIgnoredByUser.{4a313247-8330-4a81-948e-b79936516f78}", false); // Image Search Options
pref("extensions.quarantineIgnoredByUser.{506e023c-7f2b-40a3-8066-bc5deb40aebe}", false); // Gesturefy
pref("extensions.quarantineIgnoredByUser.{52bda3fd-dc48-4b3d-a7b9-58af57879f1e}", false); // Stylebot
pref("extensions.quarantineIgnoredByUser.{531906d3-e22f-4a6c-a102-8057b88a1a63}", false); // SingleFile
pref("extensions.quarantineIgnoredByUser.{5384767E-00D9-40E9-B72F-9CC39D655D6F}", false); // EPUBReader
pref("extensions.quarantineIgnoredByUser.{54e2eb33-18eb-46ad-a4e4-1329c29f6e17}", false); // Block Site
pref("extensions.quarantineIgnoredByUser.{63d150c4-394c-4275-bc32-c464e76a891c}", false); // Audio Equalizer
pref("extensions.quarantineIgnoredByUser.{79b2e4de-8fb4-4ccc-b9f6-362ac2fb74b2}", false); // Measure-it
pref("extensions.quarantineIgnoredByUser.{7a7a4a92-a2a0-41d1-9fd7-1e92480d612d}", false); // Stylus
pref("extensions.quarantineIgnoredByUser.{7b1bf0b6-a1b9-42b0-b75d-252036438bdc}", false); // YouTube High Definition
pref("extensions.quarantineIgnoredByUser.{91aa5abe-9de4-4347-b7b5-322c38dd9271}", false); // Clippings
pref("extensions.quarantineIgnoredByUser.{a6c4a591-f1b2-4f03-b3ff-767e5bedf4e7}", false); // User-Agent Switcher and Manager
pref("extensions.quarantineIgnoredByUser.{a9c2ad37-e940-4892-8dce-cd73c6cbbc0c}", false); // Feedbro
pref("extensions.quarantineIgnoredByUser.{b9acf540-acba-11e1-8ccb-001fd0e08bd4}", false); // Easy Youtube Video Downloader Express
pref("extensions.quarantineIgnoredByUser.{b9db16a4-6edc-47ec-a1f4-b86292ed211d}", false); // Video DownloadHelper
pref("extensions.quarantineIgnoredByUser.{c2c003ee-bd69-42a2-b0e9-6f34222cb046}", false); // Auto Tab Discard
pref("extensions.quarantineIgnoredByUser.{c5867acc-54c9-4074-9574-04d8818d53e8}", false); // Livemarks
pref("extensions.quarantineIgnoredByUser.{d07ccf11-c0cd-4938-a265-2a4d6ad01189}", false); // Web Archives
pref("extensions.quarantineIgnoredByUser.{d37dc5d0-431d-44e5-8c91-49419370caa1}", false); // FoxClocks
pref("extensions.quarantineIgnoredByUser.{DDC359D1-844A-42a7-9AA1-88A850A938A8}", false); // DownThemAll!
pref("extensions.quarantineIgnoredByUser.{de22fd49-c9ab-4359-b722-b3febdc3a0b0}", false); // Popup Blocker (strict)
pref("extensions.quarantineIgnoredByUser.{e839c3f9-298e-4cd0-99e0-464431cb7c34}", false); // Foxy Gestures
pref("extensions.quarantineIgnoredByUser.{e90f5de4-8510-4515-9f67-3b6654e1e8c2}", false); // Dictionary Anywhere
pref("extensions.quarantineIgnoredByUser.addon@darkreader.org", false); // Dark Reader
pref("extensions.quarantineIgnoredByUser.adb@mozilla.org", false, locked); // Firefox DevTools ADB Extension
pref("extensions.quarantineIgnoredByUser.ads@mozac.org", false, locked); // Mozilla Android Components - Ads Telemetry
pref("extensions.quarantineIgnoredByUser.ATBC@EasonWong", false); // Adaptive Tab Bar Color
pref("extensions.quarantineIgnoredByUser.cookies@mozac.org", false, locked); // Mozilla Android Components - Search Telemetry
pref("extensions.quarantineIgnoredByUser.copyplaintext@eros.man", false); // Copy PlainText
pref("extensions.quarantineIgnoredByUser.customscrollbars@computerwhiz", false); // Custom Scrollbars
pref("extensions.quarantineIgnoredByUser.dont-track-me-google@robwu.nl", false); // Don't track me Google
pref("extensions.quarantineIgnoredByUser.ddg@search.mozilla.org", false, locked); // DuckDuckGo - search engine
pref("extensions.quarantineIgnoredByUser.deArrow@ajay.app", false); // DeArrow
pref("extensions.quarantineIgnoredByUser.emoji@saveriomorelli.com", false); // Emoji
pref("extensions.quarantineIgnoredByUser.firefox@ghostery.com", false); // Ghostery
pref("extensions.quarantineIgnoredByUser.foxytab@eros.man", false); // Ghostery
pref("extensions.quarantineIgnoredByUser.jid0-dsq67mf5kjjhiiju2dfb6kk8dfw@jetpack", false); // FoxyTab
pref("extensions.quarantineIgnoredByUser.jid1-KdTtiCj6wxVAFA@jetpack", false); // Swift Selection Search
pref("extensions.quarantineIgnoredByUser.jid1-q4sG8pYhq8KGHs@jetpack", false); // AdBlocker for YouTube™
pref("extensions.quarantineIgnoredByUser.jid1-QoFqdK4qzUfGWQ@jetpack", false); // Dark Background and Light Text
pref("extensions.quarantineIgnoredByUser.juraj.masiar@gmail.com_ScrollAnywhere", false); // ScrollAnywhere
pref("extensions.quarantineIgnoredByUser.languagetool-webextension@languagetool.org", false); // LanguageTool
pref("extensions.quarantineIgnoredByUser.leechblockng@proginosko.com", false); // LeechBlock NG
pref("extensions.quarantineIgnoredByUser.linkgopher@oooninja.com", false); // Link Gopher
pref("extensions.quarantineIgnoredByUser.printedit-we@DW-dev", false); // Print Edit WE
pref("extensions.quarantineIgnoredByUser.s3download@statusbar", false); // Download Manager (S3)
pref("extensions.quarantineIgnoredByUser.simple-tab-groups@drive4ik", false); // Simple Tab Groups
pref("extensions.quarantineIgnoredByUser.snaplinks@snaplinks.mozdev.org", false); // Snap Links
pref("extensions.quarantineIgnoredByUser.soundfixer@unrelenting.technology", false); // SoundFixer
pref("extensions.quarantineIgnoredByUser.sponsorBlocker@ajay.app", false); // SponsorBlock
pref("extensions.quarantineIgnoredByUser.stefanvandamme@stefanvd.net", false); // Turn Off the Lights
pref("extensions.quarantineIgnoredByUser.tabby@whatsyouridea.com", false); // Tabby - Window and Tab Manager
pref("extensions.quarantineIgnoredByUser.tranquility@ushnisha.com", false); // Tranquility Reader
pref("extensions.quarantineIgnoredByUser.treestyletab@piro.sakura.ne.jp", false); // Tree Style Tabs
pref("extensions.quarantineIgnoredByUser.wikipedia@search.mozilla.org", false, locked); // Wikipedia (en, locked) - search engine
pref("extensions.quarantineIgnoredByUser.worldwide@radio", false); // Worldwide Radio
pref("extensions.quarantineIgnoredByUser.zoompage-we@DW-dev", false); // Zoom Page WE
pref("xpinstall.blacklist.add.GNU", "gnuzilla.gnu.org"); // Mozzarella - Hosts very outdated versions of extensions...
pref("extensions.manifestV2.actionsPopupURLRestricted", true); // [DEFAULT - Android]
pref("extensions.openPopupWithoutUserGesture.enabled", false);
pref("extensions.geckoProfiler.acceptedExtensionIds", ""); // [HIDDEN - Android] [DEFAULT - Android]
pref("extensions.experiments.enabled", false); // [DEFAULT - non-Thunderbird]
pref("extensions.webextensions.fileSchemeAccess.requireOptIn", true); // [DEFAULT]
pref("extensions.content_web_accessible.enabled", true);
pref("extensions.install.requireSecureOrigin", true); // [HIDDEN]
pref("browser.phoenix.status", "016");
pref("browser.ai.control.default", "blocked");
pref("browser.ai.control.linkPreviewKeyPoints", "blocked");
pref("browser.ai.control.pdfjsAltText", "blocked");
pref("browser.ai.control.sidebarChatbot", "blocked");
pref("browser.ai.control.smartTabGroups", "blocked");
pref("browser.ai.control.smartWindow", "blocked");
pref("extensions.htmlaboutaddons.local_model_management", true); // [DEFAULT]
pref("browser.ml.enable", false);
pref("places.semanticHistory.featureGate", false); // [HIDDEN - Android/Thunderbird] [DEFAULT - non-Nightly/Dev Firefox Desktop]
pref("extensions.ml.enabled", false);
pref("browser.phoenix.status", "017");
pref("geo.prompt.testing", true); // [ANDROID-ONLY] [HIDDEN]
pref("geo.prompt.testing.allow", false); // [ANDROID-ONLY] [HIDDEN]
pref("geo.provider.network.loglevel", "Off"); // [HIDDEN] [DEFAULT]
pref("browser.region.local-geocoding", false); // [HIDDEN] [DEFAULT]
pref("browser.region.network.scan", false); // [DEFAULT] [DEFENSE IN DEPTH] Disable Wi-Fi scanning for these requests
pref("browser.region.network.url", "");
pref("browser.region.update.enabled", false);
pref("browser.search.region", "XX"); // [HIDDEN]
pref("doh-rollout.home-region", "XX"); // [HIDDEN]
pref("geo.provider.testing", false); // [HIDDEN] [DEFAULT]
pref("geo.provider.use_mls", false); // [HIDDEN] [DEFAULT]
pref("geo.provider.network.debug.requestCache.enabled", true); // [HIDDEN] [DEFAULT]
pref("geo.provider.network.url", "https://api.beacondb.net/v1/geolocate");
pref("browser.phoenix.status", "018");
pref("pdfjs.enableAltTextModelDownload", false); // [DEFAULT - non-Android]
pref("pdfjs.enableGuessAltText", false); // [DEFAULT - non-Android]
pref("pdfjs.enableAutoLinking", false);
pref("pdfjs.enableScripting", false);
pref("pdfjs.enableWebGPU", false);
pref("pdfjs.enableXfa", false);
pref("pdfjs.enableSignatureEditor", true); // [DEFAULT - non-Android]
pref("pdfjs.enableComment", true); // [DEFAULT - non-Android]
pref("pdfjs.enableAltText", true); // [DEFAULT - non-Android]
pref("pdfjs.enableAltTextForEnglish", true);
pref("pdfjs.enableNewAltTextWhenAddingImage", true); // [DEFAULT] Enables the Alt Text Editor after adding an image
pref("pdfjs.enableUpdatedAddImage", true); // [DEFAULT]
pref("pdfjs.enableHWA", true); // [DEFAULT]
pref("pdfjs.enableOptimizedPartialRendering", true); // [DEFAULT]
pref("pdfjs.disableFontFace", true);
pref("pdfjs.textLayerMode", 1); // [DEFAULT]
pref("browser.download.open_pdf_attachments_inline", false); // [DEFAULT - non-Android] https://bugzilla.mozilla.org/show_bug.cgi?id=1772569
pref("pdfjs.disableRange", true);
pref("pdfjs.disableStream", true);
pref("browser.download.force_save_internally_handled_attachments", true); // [ANDROID-ONLY] https://bugzilla.mozilla.org/show_bug.cgi?id=1811830 Ensures user is prompted and that PDFs are downloaded locally, though doesn't apply for opening PDFs - we don't need this on Desktop due to our use of the "Handlers" policy (as described above) - hopefully can find a better solution here for Android
pref("pdfjs.enablePermissions", false); // [DEFAULT]
pref("pdfjs.externalLinkTarget", 2);
pref("pdfjs.handleOctetStream", false);
pref("pdfjs.sidebarViewOnLoad", 2);
pref("browser.phoenix.status", "019");
pref("dom.webnotifications.block_if_on_safebrowsing", true); // [DEFAULT]
pref("browser.safebrowsing.provider.google.reportMalwareMistakeURL", "https://safebrowsing.google.com/safebrowsing/report_error/?tpl=mozilla&url=");
pref("browser.safebrowsing.provider.google.reportPhishMistakeURL", "https://safebrowsing.google.com/safebrowsing/report_error/?tpl=mozilla&url=");
pref("browser.safebrowsing.provider.google4.reportMalwareMistakeURL", "https://safebrowsing.google.com/safebrowsing/report_error/?tpl=mozilla&url=");
pref("browser.safebrowsing.provider.google4.reportPhishMistakeURL", "https://safebrowsing.google.com/safebrowsing/report_error/?tpl=mozilla&url=");
pref("browser.safebrowsing.provider.google5.reportMalwareMistakeURL", "https://safebrowsing.google.com/safebrowsing/report_error/?tpl=mozilla&url=");
pref("browser.safebrowsing.provider.google5.reportPhishMistakeURL", "https://safebrowsing.google.com/safebrowsing/report_error/?tpl=mozilla&url=");
pref("browser.safebrowsing.reportPhishURL", "https://safebrowsing.google.com/safebrowsing/report_phish/?tpl=mozilla&url=");
pref("browser.safebrowsing.debug", false); // [DEFAULT]
pref("browser.safebrowsing.realTime.debug", false); // [HIDDEN] [DEFAULT] [NIGHTLY] https://searchfox.org/firefox-main/rev/83d1a08d/toolkit/components/url-classifier/RealTimeRequestSimulator.cpp#31
pref("browser.safebrowsing.provider.google.advisoryName", "Google Safe Browsing (Legacy)"); // Label it so it's clearly distinguishable if it is ever enabled for whatever reason...
pref("browser.safebrowsing.provider.google.lists", "disabled");
pref("browser.safebrowsing.provider.google.lists.default", "goog-badbinurl-shavar,goog-downloadwhite-digest256,goog-phish-shavar,googpub-phish-shavar,goog-malware-shavar,goog-unwanted-shavar"); // [HIDDEN] This pref does nothing, just makes it easier for users to re-enable this Safe Browsing provider if desired by copying and pasting the value of this pref as the value for `browser.safebrowsing.provider.google.lists`
pref("browser.safebrowsing.realTime.enabled", false); // [DEFAULT - non-Nightly]
pref("browser.safebrowsing.realTime.simulation.enabled", false); // [DEFAULT - non-Nightly]
pref("urlclassifier.blockedTable", "moztest-block-simple,mozplugin-block-digest256"); // [DEFAULT - Nightly]
pref("urlclassifier.malwareTable", "goog-malware-proto,goog-unwanted-proto,moztest-harmful-simple,moztest-malware-simple,moztest-unwanted-simple,goog-harmful-proto");
pref("browser.safebrowsing.blockedURIs.enabled", true); // [DEFAULT]
pref("browser.safebrowsing.downloads.enabled", true); // [DEFAULT - non-Android]
pref("browser.safebrowsing.id", "navclient-auto-ffox"); // [DEFAULT - Official] Ensure we use Mozilla's ID
pref("browser.safebrowsing.malware.enabled", true); // [DEFAULT]
pref("browser.safebrowsing.phishing.enabled", true); // [DEFAULT]
pref("browser.safebrowsing.provider.google5.enabled", true); // [DEFAULT]
pref("browser.safebrowsing.provider.mozilla.gethashURL", "https://shavar.services.mozilla.com/gethash?client=navclient-auto-ffox&appver=%MAJOR_VERSION%&pver=2.2"); // Ensure we always use Mozilla's official ID
pref("browser.safebrowsing.update.enabled", true); // [HIDDEN] [DEFAULT] Also covers Mozilla's tracking protection lists
pref("urlclassifier.downloadAllowTable", "goog-downloadwhite-proto"); // [DEFAULT - non-Android]
pref("urlclassifier.downloadBlockTable", "goog-badbinurl-proto"); // [DEFAULT - non-Android]
pref("urlclassifier.enabled_mode", 3); // [DEFAULT] Ensure we enable classification for ETP and Safe Browsing https://searchfox.org/firefox-main/rev/4dad4a9a/netwerk/base/nsNetUtil.cpp#3332 https://searchfox.org/firefox-main/rev/ac83682a/modules/libpref/init/StaticPrefList.yaml#18483
pref("urlclassifier.phishTable", "goog-phish-proto,moztest-phish-simple"); // [DEFAULT - Official] Ensure we're using Google's full/private phishing list https://bugzilla.mozilla.org/show_bug.cgi?id=1288840
pref("browser.safebrowsing.allowOverride", true); // [DEFAULT]
pref("browser.safebrowsing.downloads.remote.enabled", false);
pref("browser.safebrowsing.provider.google.dataSharing.enabled", false, locked); // [HIDDEN - non-Android] [DEFAULT]
pref("browser.safebrowsing.provider.google.dataSharingURL", "", locked); // [HIDDEN] [DEFAULT]
pref("browser.safebrowsing.provider.google4.dataSharing.enabled", false, locked); // [DEFAULT]
pref("browser.safebrowsing.provider.google4.dataSharingURL", "", locked);
pref("browser.safebrowsing.provider.google5.dataSharing.enabled", false, locked); // [HIDDEN] [DEFAULT]
pref("browser.safebrowsing.provider.google5.dataSharingURL", "", locked); // [HIDDEN] [DEFAULT]
pref("browser.safebrowsing.provider.mozilla.dataSharing.enabled", false, locked); // [HIDDEN] [DEFAULT]
pref("browser.safebrowsing.provider.mozilla.dataSharingURL", "", locked); // [HIDDEN] [DEFAULT]
pref("browser.safebrowsing.provider.test.dataSharing.enabled", false, locked); // [HIDDEN] [DEFAULT]
pref("browser.safebrowsing.provider.test.dataSharingURL", "", locked); // [HIDDEN] [DEFAULT]
pref("browser.safebrowsing.downloads.remote.url", "https://safebrowsing.ironfoxoss.org/safebrowsing/clientreport/download?key=%GOOGLE_SAFEBROWSING_API_KEY%");
pref("browser.safebrowsing.provider.google4.advisoryName", "Google Safe Browsing (Proxied by IronFox) - v4");
pref("browser.safebrowsing.provider.google4.gethashURL", "https://safebrowsing.ironfoxoss.org/v4/fullHashes:find?$ct=application/x-protobuf&key=%GOOGLE_SAFEBROWSING_API_KEY%&$httpMethod=POST");
pref("browser.safebrowsing.provider.google4.nextupdatetime", "1"); // [HIDDEN]
pref("browser.safebrowsing.provider.google4.updateURL", "https://safebrowsing.ironfoxoss.org/v4/threatListUpdates:fetch?$ct=application/x-protobuf&key=%GOOGLE_SAFEBROWSING_API_KEY%&$httpMethod=POST");
pref("browser.safebrowsing.provider.google5.advisoryName", "Google Safe Browsing (Proxied by IronFox) - v5");
pref("browser.safebrowsing.provider.google5.gethashURL", "https://safebrowsing.ironfoxoss.org/v5/hashes:search?key=%GOOGLE_SAFEBROWSING_API_KEY%");
pref("browser.safebrowsing.provider.google5.nextupdatetime", "1"); // [HIDDEN]
pref("browser.safebrowsing.provider.google5.updateURL", "https://safebrowsing.ironfoxoss.org/v5/hashLists:batchGet?key=%GOOGLE_SAFEBROWSING_API_KEY%");
pref("browser.safebrowsing.provider.google.gethashURL", "https://safebrowsing.google.com/safebrowsing/gethash?client=navclient-auto-ffox&appver=%MAJOR_VERSION%&pver=2.2"); // [DEFAULT]
pref("browser.safebrowsing.provider.google.updateURL", "https://safebrowsing.google.com/safebrowsing/downloads?client=navclient-auto-ffox&appver=%MAJOR_VERSION%&pver=2.2&key=%GOOGLE_SAFEBROWSING_API_KEY%"); // [DEFAULT]
pref("browser.safebrowsing.provider.google.reportURL", "https://transparencyreport.google.com/safe-browsing/search?url=");
pref("browser.safebrowsing.provider.google4.reportURL", "https://transparencyreport.google.com/safe-browsing/search?url=");
pref("browser.safebrowsing.provider.google5.reportURL", "https://transparencyreport.google.com/safe-browsing/search?url=");
pref("browser.phoenix.status", "020");
pref("browser.disable_pickers_background_tabs", true); // [DEFAULT]
pref("browser.disable_pickers_in_hidden_extension_pages", true); // [DEFAULT - Nightly]
pref("accessibility.force_disabled", 1);
pref("browser.search.update", false); // [DEFAULT - Android]
pref("dom.battery.enabled", false);
pref("beacon.enabled", false);
pref("dom.events.testing.asyncClipboard", false, locked); // [DEFAULT]
pref("browser.contentanalysis.default_result", 0, locked); // [DEFAULT]
pref("browser.contentanalysis.enabled", false, locked); // [DEFAULT]
pref("browser.contentanalysis.interception_point.clipboard.enabled", false, locked);
pref("browser.contentanalysis.interception_point.drag_and_drop.enabled", false, locked);
pref("browser.contentanalysis.interception_point.file_upload.enabled", false, locked);
pref("browser.contentanalysis.interception_point.print.enabled", false, locked);
pref("browser.contentanalysis.max_connections", 0, locked); // Sets maximum number of allowed connections to 0
pref("browser.contentanalysis.show_blocked_result", true, locked); // [DEFAULT] Always notify users when Content Analysis blocks access to something...
pref("browser.contentanalysis.silent_notifications", false, locked); // [DEFAULT] If Content Analysis is enabled, ensure notifications aren't silenced so that users are fully aware
pref("dom.security.credentialmanagement.identity.enabled", false); // [DEFAULT - non-Nightly]
pref("dom.security.credentialmanagement.identity.heavyweight.enabled", false); // [DEFAULT - non-Nightly]
pref("dom.security.credentialmanagement.identity.lightweight.enabled", false); // [DEFAULT]
pref("webextensions.native-messaging.max-input-message-bytes", 1048576); // [ANDROID-ONLY] [HIDDEN] [DEFAULT]
pref("webextensions.native-messaging.max-output-message-bytes", 2147483647); // [ANDROID-ONLY] [HIDDEN] [DEFAULT: -1]
pref("webextensions.native-messaging.0.NOTE", "To disable Native Messaging...", locked); // [ANDROID-ONLY]
pref("webextensions.native-messaging.1.NOTE", "Set 'webextensions.native-messaging.max-input-message-bytes'", locked); // [ANDROID-ONLY]
pref("webextensions.native-messaging.2.NOTE", "AND 'webextensions.native-messaging.max-output-message-bytes'", locked); // [ANDROID-ONLY]
pref("webextensions.native-messaging.3.NOTE", "to 0", locked); // [ANDROID-ONLY]
pref("dom.reporting.crash.enabled", false); // [DEFAULT - non-Nightly]
pref("dom.reporting.enabled", false);
pref("dom.reporting.featurePolicy.enabled", false); // [DEFAULT]
pref("dom.reporting.header.enabled", false);
pref("dom.reporting.testing.enabled", false); // [DEFAULT]
pref("dom.webserial.gated", true); // [DEFAULT]
pref("permissions.default.serial", 2); // [HIDDEN]
pref("dom.webshare.enabled", false); // [DEFAULT - non-Android/non-Nightly Windows]
pref("dom.webshare.requireinteraction", true); // [DEFAULT] If enabled, ensure we always require interaction...
pref("dom.webgpu.enabled", false); // [DEFAULT - non-Windows/non-Silicon-OSX/non-Nightly]
pref("dom.sitepermsaddon-provider.enabled", false); // [DEFAULT - non-Android]
pref("dom.webmidi.gated", true); // [DEFAULT]
pref("permissions.default.midi", 2); // [HIDDEN]
pref("permissions.default.midi-sysex", 2); // [HIDDEN]
pref("accessibility.uia.enable", 0); // [Windows]
pref("network.lna.allow_top_level_navigation", false); // Enforce LNA for top-level document navigation https://searchfox.org/firefox-main/rev/8e6b6cb1/modules/libpref/init/StaticPrefList.yaml#14619
pref("network.lna.benchmarking-is-local", true); // Enable LNA for IP addresses in the 192.18.X.X range https://searchfox.org/firefox-main/rev/28328852/modules/libpref/init/StaticPrefList.yaml#14678
pref("network.lna.block_trackers", true); // https://searchfox.org/firefox-main/rev/7f33a0cc/modules/libpref/init/StaticPrefList.yaml#14469
pref("network.lna.defer_https_check", false); // Ensure we always perform LNA checks (for private IP addresses) before connecting https://searchfox.org/firefox-main/rev/f3695d1f/modules/libpref/init/StaticPrefList.yaml#15224
pref("network.lna.enabled", true); // [DEFAULT]
pref("network.lna.etp.enabled", false); // [DEFAULT] Enable LNA, regardless of ETP/ETP Strict https://searchfox.org/firefox-main/rev/7f33a0cc/browser/components/protections/ContentBlockingPrefs.sys.mjs#265
pref("network.lna.local-network-to-localhost.skip-checks", false); // Enforce LNA for requests from local network to your device https://searchfox.org/firefox-main/rev/8e6b6cb1/modules/libpref/init/StaticPrefList.yaml#14641
pref("network.lna.websocket.enabled", true); // Enforce LNA for WebSocket connections https://searchfox.org/firefox-main/rev/7f33a0cc/modules/libpref/init/StaticPrefList.yaml#14490
pref("network.lna.blocking", true); // [ANDROID-ONLY] [DEFAULT - Nightly]
pref("network.loopback-network.prompt.testing", true); // [ANDROID-ONLY] [HIDDEN]
pref("network.loopback-network.prompt.testing.allow", false); // [ANDROID-ONLY] [HIDDEN] Blocks websites from prompting to access apps and services (outside of the browser) on your device
pref("network.localnetwork.prompt.testing", true); // [ANDROID-ONLY] [HIDDEN]
pref("network.localnetwork.prompt.testing.allow", false); // [ANDROID-ONLY] [HIDDEN] Blocks websites from prompting to access the local network
pref("dom.origin-trials.mls.state", 1);
pref("permissions.expireUnused.enabled", true); // [DEFAULT - Nightly]
pref("network.http.referer.XOriginPolicy", 2); // [EXTENDED-ONLY]
pref("dom.use_components_shim", false); // [DEFAULT - Nightly]
pref("browser.phoenix.status", "021");
pref("network.security.ports.banned", "29009, 29010, 30102, 30103, 12387, 12388, 12580, 12581, 12582, 12583, 12584, 12585, 12586, 12587, 12588, 12589, 12590, 12591");
pref("security.csp.reporting.enabled", false);
pref("browser.send_pings", false); // [DEFAULT]
pref("browser.send_pings.max_per_link", 1); // [DEFAULT] Ensure max number of pings are limited to 1 if Hyperlink Auditing is enabled
pref("browser.send_pings.require_same_host", true); // [DEFENSE IN DEPTH]
pref("network.http.network_error_logging.enabled", false); // [DEFAULT]
pref("media.webspeech.service.endpoint", "data;"); // [HIDDEN]
pref("network.http.referer.hideOnionSource", true); // [DEFAULT]
pref("dom.storage_access.auto_grants", false); // Automatic storage access grants
pref("privacy.restrict3rdpartystorage.heuristic.navigation", false); // [DEFAULT - Android]
pref("privacy.restrict3rdpartystorage.heuristic.opened_window_after_interaction", false);
pref("privacy.restrict3rdpartystorage.heuristic.recently_visited", false); // [DEFAULT - non-Android]
pref("privacy.restrict3rdpartystorage.heuristic.redirect", false); // [DEFAULT]
pref("privacy.restrict3rdpartystorage.heuristic.window_open", false); // [DEFAULT]
pref("privacy.restrict3rdpartystorage.heuristic.recently_visited_time", 0);
pref("security.ssl.disable_session_identifiers", true);
pref("privacy.userContext.enabled", true); // [HIDDEN - Android] [DEFAULT - Firefox Desktop Nightly]
pref("cookiebanners.bannerClicking.enabled", true); // [DEFAULT]
pref("cookiebanners.cookieInjector.enabled", true); // [DEFAULT]
pref("cookiebanners.service.mode", 1);
pref("cookiebanners.service.mode.privateBrowsing", 1);
pref("cookiebanners.service.enableGlobalRules", true); // [DEFAULT]
pref("cookiebanners.service.enableGlobalRules.subFrames", true); // [DEFAULT]
pref("network.cookie.CHIPS.enabled", true); // [DEFAULT]
pref("network.cookie.chips.partitionLimitDryRun", false); // [DEFAULT]
pref("privacy.donottrackheader.enabled", true);
pref("privacy.globalprivacycontrol.enabled", true);
pref("privacy.globalprivacycontrol.functionality.enabled", true); // [DEFAULT - non-Thunderbird]
pref("privacy.globalprivacycontrol.pbmode.enabled", true); // [DEFAULT - non-Thunderbird]
pref("browser.ipProtection.enabled", true); // [DEFAULT - Android] https://searchfox.org/firefox-main/rev/ada2ab81/mobile/android/app/geckoview-prefs.js#387
pref("dom.storage_access.auto_grants.exclude_third_party_trackers", true); // [DEFAULT] Automatic storage access grants
pref("privacy.restrict3rdpartystorage.heuristic.exclude_third_party_trackers", true); // [DEFAULT]
pref("privacy.query_stripping.strip_list", "__hsfp __hssc __hstc __s _bhlid _branch_match_id _branch_referrer _gl _hsenc _hsmi _openstat action_object_map action_ref_map action_type_map at_campaign at_campaign_type at_channel at_creation at_custom1 at_custom2 at_custom3 at_custom4 at_detail_placement at_emailtype at_format at_general_placement at_identifier at_link at_link_id at_link_origin at_link_type at_medium at_network at_platform at_ptr_name at_recipient_id at_recipient_list at_send_date at_term at_type at_variant bbeml brave-campaign-id brave-creative-id brave-creative-set-id bsft_clkid bsft_uid cm_cr cm_me cm_re cm_sp cm_mmc cm_mmca1 cm_mmca2 cm_mmca3 cm_mmca4 cm_mmca5 cm_mmca6 cm_mmca7 cm_mmca8 cm_mmca9 cm_mmca10 cm_mmca11 cm_mmca12 cm_mmca13 cm_mmca14 cm_mmca15 ck_subscriber_id cx_click cx_recsOrder cx_recsWidget dclid et_cid et_lid et_rid ex_cid fb_action_ids fb_action_types fbclid fb_comment_id fb_ref fb_source gad_campaignid gad_source gbraid gclid gclsrc guccounter guce_referrer guce_referrer_sig hmb_campaign hmb_medium hmb_source hootPostID hsa_acc hsa_ad hsa_cam hsa_grp hsa_kw hsa_la hsa_mt hsa_net hsa_ol hsa_src hsa_tgt hsa_ver hsCtaTracking ig_rid igsh igshid ir_adid ir_campaignid ir_partnerid irclickid irgwc li_fat_id mc_cid mc_eid ml_sub ml_sub_hash ml_subscriber ml_subscriber_hash msclkid mtm_campaign mtm_cid mtm_content mtm_group mtm_keyword mtm_kwd mtm_medium mtm_placement mtm_source nb_adid nb_aname nb_asize nb_atype nb_cid nb_mtype nb_partner_name nb_partner_shared_id nb_pid nb_platform nb_product_sku notification_referrer_id oft_c oft_ck oft_d oft_id oft_ids oft_k oft_lk oft_sk oly_anon_id oly_enc_id piwik_campaign piwik_kwd pk_campaign pk_cid pk_content pk_cpn pk_keyword pk_kwd pk_medium pk_source rb_clickid ref_src ref_url s_campaign s_cid sc_customer sc_eh sc_lid sc_llid sc_src sc_uid ScCid sfmc_activityid sfmc_id sms_click sms_source sms_uph srsltid ss_campaign_id ss_campaign_name ss_campaign_sent_date ss_email_id ss_source syclid tblci ttclid twclid unicorn_click_id usp usqp utm_ad utm_affiliate utm_ag utm_brand utm_campaigncode utm_campaignid utm_channel utm_cid utm_content utm_creative utm_creative_format utm_custom1 utm_custom2 utm_device utm_emcid utm_emmid utm_id utm_id_ utm_internal utm_keyword utm_mailing utm_marketing_tactic utm_medium utm_name utm_place utm_product utm_pubreferrer utm_reader utm_referrer utm_serial utm_session utm_siteid utm_social utm_social-type utm_source utm_source_platform utm_supplier utm_swu utm_term utm_umguk utm_userid utm_viz_id var vero_conv vero_id vgo_ee wbraid wickedid wprov wt_mc yadclid yadordid yclid ymclid ymid ysclid"); // [ANDROID-ONLY]
pref("privacy.query_stripping.allow_list", "urldefense.com");
pref("permissions.isolateBy.userContext", true);
pref("privacy.antitracking.isolateContentScriptResources", true); // [DEFAULT - Nightly]
pref("network.cookie.maxageCap", 15552000);
pref("autoadmin.append_emailaddr", false, locked); // [HIDDEN] [DEFAULT]
pref("privacy.dynamic_firstparty.limitForeign", true);
// pref("network.http.referer.defaultPolicy.trackers", 1); // [DEFAULT]
// pref("network.http.referer.defaultPolicy.trackers.pbmode", 1); // [DEFAULT]
pref("privacy.query_stripping.strip_on_share.enabled", true); // [DEFAULT - non-Android/Thunderbird]
pref("network.http.referer.XOriginTrimmingPolicy", 2);
pref("browser.phoenix.status", "022");
pref("security.default_personal_cert", "Ask Every Time", locked); // [DEFAULT]
pref("security.browser_xhtml_csp.enabled", true); // [DEFAULT]
pref("security.disallow_privilegedabout_remote_script_loads", true);
pref("network.protocol-handler.expose.about", true); // [DEFAULT - Thunderbird]
pref("network.protocol-handler.expose.blob", true); // [DEFAULT - Thunderbird]
pref("network.protocol-handler.expose.chrome", true); // [DEFAULT - Thunderbird]
pref("network.protocol-handler.expose.data", true); // [DEFAULT - Thunderbird]
pref("network.protocol-handler.expose.file", true); // [DEFAULT - Thunderbird]
pref("network.protocol-handler.expose.http", true); // [DEFAULT - Thunderbird]
pref("network.protocol-handler.expose.https", true); // [DEFAULT - Thunderbird]
pref("network.protocol-handler.expose.javascript", true); // [DEFAULT - Thunderbird]
pref("network.protocol-handler.expose.moz-extension", true); // [DEFAULT - Thunderbird] [HIDDEN - non-Thunderbird]
pref("network.protocol-handler.expose.resource", true); // [HIDDEN]
pref("network.protocol-handler.external.about", false); // [HIDDEN]
pref("network.protocol-handler.external.afp", false); // [DEFAULT]
pref("network.protocol-handler.external.bankid", true); // [HIDDEN] Ensure we do not try to handle BankID authentication internally...
pref("network.protocol-handler.external.blob", false); // [HIDDEN]
pref("network.protocol-handler.external.chrome", false); // [HIDDEN]
pref("network.protocol-handler.external.data", false); // [DEFAULT]
pref("network.protocol-handler.external.disk", false); // [DEFAULT]
pref("network.protocol-handler.external.disks", false); // [DEFAULT]
pref("network.protocol-handler.external.element", true); // [HIDDEN] Ensure we do not try to handle Element links internally...
pref("network.protocol-handler.external.hcp", false); // [DEFAULT]
pref("network.protocol-handler.external.help", false); // [HIDDEN - non-macOS] [DEFAULT - macOS]
pref("network.protocol-handler.external.htp", false); // [DEFAULT]
pref("network.protocol-handler.external.htps", false); // [DEFAULT]
pref("network.protocol-handler.external.ie.http", false); // [DEFAULT]
pref("network.protocol-handler.external.iehistory", false); // [DEFAULT]
pref("network.protocol-handler.external.ierss", false); // [DEFAULT]
pref("network.protocol-handler.external.ile", false); // [DEFAULT]
pref("network.protocol-handler.external.javascript", false); // [DEFAULT]
pref("network.protocol-handler.external.le", false); // [DEFAULT]
pref("network.protocol-handler.external.mk", false); // [DEFAULT]
pref("network.protocol-handler.external.moz", false); // [HIDDEN]
pref("network.protocol-handler.external.moz-extension", false); // [HIDDEN]
pref("network.protocol-handler.external.moz-icon", false); // [DEFAULT]
pref("network.protocol-handler.external.moz-sbrs", false); // [HIDDEN]
pref("network.protocol-handler.external.ms-cxh", false); // [DEFAULT]
pref("network.protocol-handler.external.ms-cxh-full", false); // [DEFAULT]
pref("network.protocol-handler.external.ms-help", false); // [DEFAULT]
pref("network.protocol-handler.external.ms-msdt", false); // [DEFAULT]
pref("network.protocol-handler.external.obtainium", true); // [HIDDEN] Ensure we do not try to handle Obtainium app installation internally...
pref("network.protocol-handler.external.ps", false); // [DEFAULT]
pref("network.protocol-handler.external.res", false); // [DEFAULT]
pref("network.protocol-handler.external.resource", false); // [HIDDEN]
pref("network.protocol-handler.external.search", false); // [DEFAULT]
pref("network.protocol-handler.external.search-ms", false); // [DEFAULT]
pref("network.protocol-handler.external.shell", false, locked); // [DEFAULT] Never expose shell access https://www.stigviewer.com/stig/mozilla_firefox/2019-12-12/finding/V-15771
pref("network.protocol-handler.external.tel", true); // [HIDDEN] Ensure we do not try to handle tel (Phone) links internally...
pref("network.protocol-handler.external.tps", false); // [DEFAULT]
pref("network.protocol-handler.external.ttp", false); // [DEFAULT]
pref("network.protocol-handler.external.ttps", false); // [DEFAULT]
pref("network.protocol-handler.external.vbscript", false); // [DEFAULT]
pref("network.protocol-handler.external.view-source", false); // [HIDDEN]
pref("network.protocol-handler.external.vnd.ms.radio", false); // [DEFAULT]
pref("network.protocol-handler.warn-external.file", true); // [DEFAULT - non-Android]
pref("network.protocol-handler.warn-external.ftp", true); // [HIDDEN - non-Thunderbird] [DEFAULT - non-Thunderbird]
pref("network.protocol-handler.warn-external.mailto", true); // [HIDDEN - Thunderbird] [DEFAULT - non-Android/Firefox Desktop]
pref("network.protocol-handler.warn-external.shell", true, locked); // [HIDDEN] [DEFAULT]
pref("network.protocol-handler.warn-external.sms", true); // [HIDDEN - non-Android] [DEFAULT - non-Android]
pref("network.protocol-handler.warn-external.tel", true); // [HIDDEN - non-Android] [DEFAULT - non-Android]
pref("network.protocol-handler.warn-external.vnd.youtube", true); // [HIDDEN - non-Android] [DEFAULT - non-Android]
pref("network.protocol-handler.warn-external-default", true); // [DEFAULT]
pref("network.protocol-handler.external.http", false); // [NO-MAIL] [HIDDEN]
pref("network.protocol-handler.external.https", false); // [NO-MAIL] [HIDDEN]
pref("network.protocol-handler.expose.bankid", true); // [ANDROID-ONLY] [HIDDEN] Needed for BankID authentication on Android - see https://codeberg.org/ironfox-oss/bugs/issues/213
pref("network.protocol-handler.expose.element", true); // [ANDROID-ONLY] [HIDDEN] Needed for opening Element links (from ex. matrix.to) - see https://codeberg.org/celenity/Phoenix/issues/293
pref("network.protocol-handler.expose.obtainium", true); // [ANDROID-ONLY] [HIDDEN] Needed for installing apps from Obtainium - https://apps.obtainium.imranr.dev/
pref("network.protocol-handler.expose.tel", true); // [ANDROID-ONLY] [HIDDEN] Needed for opening links in the Phone app - https://codeberg.org/ironfox-oss/bugs/issues/231
pref("dom.ipc.keepProcessesAlive.extension", 0); // [HIDDEN - non-Android] [DEFAULT - non-Android]
pref("dom.ipc.keepProcessesAlive.privilegedabout", 0);
pref("dom.ipc.keepProcessesAlive.web", 0); // [HIDDEN - non-Android] [DEFAULT - non-Android]
pref("dom.documentpip.enabled", false); // [DEFAULT - Android]
pref("media.devices.insecure.enabled", false); // [DEFAULT]
pref("media.getusermedia.insecure.enabled", false); // [DEFAULT]
pref("network.security.ports.banned.override", ""); // [HIDDEN] [DEFAULT]
pref("browser.tabs.remote.coep.credentialless", true); // [DEFAULT - non-Android stable] 'credentialless'
pref("browser.tabs.remote.useCrossOriginEmbedderPolicy", true); // [DEFAULT]
pref("dom.origin-trials.coep-credentialless.state", 1); // 'credentialless'
pref("browser.tabs.remote.useCrossOriginOpenerPolicy", true); // [DEFAULT]
pref("security.sandbox.gpu.level", 2); // [1 = USER_RESTRICTED_NON_ADMIN (Default: Windows), 2 = USER_LIMITED (Stricter)]
pref("security.integrity_policy.enabled", true); // [DEFAULT]
pref("security.integrity_policy.stylesheet.enabled", true);
pref("browser.opaqueResponseBlocking", true); // [DEFAULT - non-Android]
pref("browser.opaqueResponseBlocking.javascriptValidator", true); // [DEFAULT]
pref("dom.origin_agent_cluster.default", true);
pref("dom.origin_agent_cluster.enabled", true); // [DEFAULT]
pref("browser.sessionstore.disable_platform_collection", false); // [DEFAULT - non-Thunderbird]
pref("fission.autostart", true); // [DEFAULT]
pref("fission.autostart.session", true); // [DEFAULT]
pref("fission.highValue.login.monitor", true); // [DEFAULT - Android] Ensure that we are always marking log-in attempts as "high value", even if Fission is disabled - for if/when users decide to enable it later https://searchfox.org/firefox-main/rev/d88792ab/dom/ipc/LoginDetectionService.cpp#64
pref("fission.webContentIsolationStrategy", 1); // [DEFAULT] Isolate everything https://searchfox.org/firefox-main/rev/d88792ab/dom/ipc/ProcessIsolation.cpp#50
pref("gfx.webrender.all", true);
pref("fission.disableSessionHistoryInParent", false); // [ESR] [DEFAULT - non-Android release] SHIP, required for Fission
pref("dom.security.sanitizer.enabled", true); // [DEFAULT]
pref("security.sandbox.socket.process.level", 2); // [DEFAULT - Linux, non-Thunderbird]
pref("javascript.options.spectre.disable_for_isolated_content", false);
pref("dom.security.trusted_types.enabled", true); // [DEFAULT]
pref("javascript.options.wasm_memory_control", true);
pref("security.fileuri.strict_origin_policy", true); // [DEFAULT]
pref("dom.block_external_protocol_in_iframes", true); // [DEFAULT]
pref("security.all_resource_uri_content_accessible", false); // [DEFAULT]
pref("security.allow_eval_in_parent_process", false); // [DEFAULT - non-Android/Thunderbird]
pref("security.allow_eval_with_system_principal", false); // [DEFAULT - non-Android]
pref("security.allow_parent_unrestricted_js_loads", false); // [DEFAULT - non-Android/Thunderbird]
pref("security.allow_unsafe_parent_loads", false); // [DEFAULT]
pref("security.data_uri.block_toplevel_data_uri_navigations", true); // [DEFAULT]
pref("media.libavcodec.allow-obsolete", false); // [DEFAULT]
pref("webgl.out-of-process", true); // [DEFAULT]
pref("webgl.out-of-process.force", true);
pref("webgl.out-of-process.worker", true); // [DEFAULT]
pref("dom.ipc.processCount", 8); // [ANDROID-ONLY]
pref("dom.ipc.processCount.webIsolated", 4); // [ANDROID-ONLY]
pref("dom.security.skip_about_page_has_csp_assert", false); // [DEFAULT - non-Thunderbird]
pref("browser.tabs.remote.subframesPreferUsed", false);
pref("javascript.options.content_process_write_protect_code", true); // [DEFAULT - OpenBSD?]
pref("general.config.sandbox_enabled", true, locked); // [HIDDEN] [DEFAULT - Release/Beta]
pref("browser.tabs.remote.enforceRemoteTypeRestrictions", true); // [DEFAULT - Nightly Desktop]
pref("network.cookie.sameSite.laxByDefault", true);
pref("network.cookie.sameSite.laxByDefaultWarningsForBeta", true); // If `network.cookie.sameSite.laxByDefault` is disabled, ensure we still display a warning in the web console
pref("network.cookie.sameSite.noneRequiresSecure", true); // [DEFAULT]
pref("network.cookie.sameSite.schemeful", true); // [DEFAULT - Nightly]
pref("network.sniff.use_extension", false); // [DEFAULT] Only use file extensions to sniff content for `file://` URLs - https://searchfox.org/firefox-main/rev/0fa53bd1/netwerk/streamconv/converters/nsUnknownDecoder.cpp#489 https://bugzilla.mozilla.org/show_bug.cgi?id=1948543
pref("security.block_fileuri_script_with_wrong_mime", true);
pref("security.block_Worker_with_wrong_mime", true); // [DEFAULT]
pref("media.cubeb.sandbox", true); // [DEFAULT]
pref("browser.tabs.remote.separateFileUriProcess", true); // [DEFAULT - non-Android]
pref("security.turn_off_all_security_so_that_viruses_can_take_over_this_computer", false, locked); // [HIDDEN] [DEFAULT]
pref("browser.phoenix.status", "023");
pref("dom.disable_open_during_load", true); // [DEFAULT - non-Thunderbird]
pref("dom.security.framebusting_intervention.enabled", true); // [DEFAULT]
pref("notification.prompt.testing", true); // [ANDROID-ONLY] [HIDDEN]
pref("notification.prompt.testing.allow", false); // [ANDROID-ONLY] [HIDDEN]
pref("captivedetect.canonicalURL", "");
pref("network.captive-portal-service.enabled", false); // [DEFAULT - Android/Thunderbird]
pref("network.connectivity-service.DNSv4.domain", "");
pref("network.connectivity-service.DNSv6.domain", "");
pref("network.connectivity-service.enabled", false);
pref("network.connectivity-service.IPv4.url", "");
pref("network.connectivity-service.IPv6.url", "");
pref("dom.fullscreen.keyboard_lock.enabled", false); // [DEFAULT - Android]
pref("network.manage-offline-status", false);
pref("network.offline-mirrors-connectivity", false); // [DEFAULT]
pref("network.socket.ip_addr_any.disabled", true); // [DEFAULT]
pref("media.webvtt.testing.events", false); // [DEFAULT]
pref("security.certerrors.felt-privacy-v1", true); // [HIDDEN - Android/Thunderbird] [DEFAULT - Firefox Desktop]
pref("security.tls.ech.disable_grease_on_fallback", false); // [DEFAULT]
pref("security.tls.ech.grease_http3", true); // [DEFAULT]
pref("security.tls.ech.grease_probability", 100); // [DEFAULT] Sets probability of using GREASE for ECH to 100%
pref("security.tls.grease_http3_enable", true);
pref("javascript.options.property_error_message_fix", true); // [DEFAULT]
pref("dom.event.contextmenu.shift_suppresses_event", true); // [DEFAULT]
pref("intl.locale.requested", ""); // [HIDDEN - non-Android] [DEFAULT - Android]
pref("browser.link.open_newwindow", 3); // [DEFAULT]
pref("browser.link.open_newwindow.restriction", 0); // [DEFAULT - Android/Thunderbird]
pref("network.http.http3.retry_different_ip_family", true); // [DEFAULT - Nightly]
pref("network.http.retry_with_another_half_open", true); // [DEFAULT - Nightly]
pref("dom.popup_allowed_events", "click dblclick");
pref("toolkit.startup.max_resumed_crashes", -1); // [HIDDEN - non-Firefox Desktop]
pref("dom.allow_scripts_to_close_windows", false); // [DEFAULT]
pref("dom.disable_window_flip", true); // [DEFAULT - non-Android]
pref("dom.disable_window_move_resize", true); // [DEFAULT - Android]
pref("browser.meta_refresh_when_inactive.disabled", true); // [DEFAULT - Android]
pref("browser.http.blank_page_with_error_response.enabled", false); // [DEFAULT - non-Android]
pref("browser.phoenix.status", "024");
pref("devtools.chrome.enabled", true); // [DEFAULT - Thunderbird]
pref("devtools.selfxss.count", 5); // [HIDDEN - Android] [DEFAULT - Nightly/Thunderbird]
pref("devtools.debugger.prompt-connection", true, locked); // [DEFAULT - non-Nightly]
pref("toolkit.gecko-trace.enable", false); // [DEFAULT]
pref("browser.dom.window.dump.enabled", false); // [DEFAULT - non-Android, desktop `MOZILLA_OFFICIAL` builds]
pref("devtools.performance.popup.intro-displayed", true);
pref("devtools.debugger.remote-enabled", false); // [DEFAULT - non-Thunderbird]
pref("devtools.debugger.remote-enabled", false);
pref("devtools.debugger.remote-websocket", false, locked); // [DEFAULT]
pref("consoleservice.logcat", false); // [ANDROID-ONLY]
pref("geckoview.console.enabled", false); // [ANDROID-ONLY]
pref("devtools.debugger.show-content-scripts", true); // [HIDDEN - Android] [DEFAULT - Thunderbird]
pref("devtools.inspector.showAllAnonymousContent", true); // [HIDDEN - Android]
pref("remote.experimental.enabled", false, locked); // [DEFAULT - non-Nightly]
pref("devtools.debugger.force-local", true, locked); // [DEFAULT]
pref("view_source.syntax_highlight", true); // [DEFAULT - non-Thunderbird]
pref("geckoview.logging", "Warn"); // [ANDROID-ONLY] [DEFAULT - non-Debug]
pref("devtools.console.stdout.chrome", false); // [DEFAULT - non-Android, `MOZILLA_OFFICIAL` builds]
pref("reader.errors.includeURLs", false); // [DEFAULT - Android/Thunderbird]
pref("remote.prefs.recommended", false);
pref("devtools.browsertoolbox.scope", "everything"); // [HIDDEN - Android] [DEFAULT - Thunderbird]
pref("view_source.wrap_long_lines", true); // [DEFAULT - Android]
pref("browser.phoenix.status", "025");
pref("browser.cache.jsbc_compression_level", 3);
pref("javascript.options.asyncstack", false);
pref("javascript.options.asyncstack_capture_debuggee_only", true); // [DEFAULT] If async stack tracing (javascript.options.asyncstack) is enabled, only capture data when devtools are open
pref("layout.css.report_errors", false); // [DEFAULT - Android]
pref("extensions.logging.enabled", false); // [DEFAULT]
pref("network.http.pacing.requests.enabled", false);
pref("javascript.options.wasm_simd_avx", true); // [DEFAULT]
pref("javascript.options.wasm_branch_hinting", true); // [DEFAULT]
pref("gfx.canvas.accelerated", true); // [DEFAULT]
pref("gfx.canvas.accelerated.cache-items", 32768); // [Default = 8192, Chromium = 4096]
pref("gfx.canvas.accelerated.cache-size", 4096); // Increase cache size (Default = 256, Chromium = 512)
pref("layout.css.grid-template-masonry-value.enabled", true); // [DEFAULT - Nightly/Thunderbird]
pref("layout.dynamic-reflow-roots.enabled", true); // [DEFAULT - Nightly]
pref("network.fetchpriority.enabled", true); // [DEFAULT]
pref("layers.acceleration.disabled", false); // [DEFAULT]
pref("javascript.options.mem.gc_parallel_marking", true); // [DEFAULT - non-Android]
pref("javascript.options.wasm_relaxed_simd", true); // [DEFAULT]
pref("gfx.webrender.compositor", true); // [DEFAULT - macOS/Windows]
pref("media.cache_readahead_limit", 600); // (Default = 60)
pref("media.cache_readahead_limit.cellular", 600); // (Default = 30)
pref("media.cache_resume_threshold", 300); // (Default = 30)
pref("media.cache_resume_threshold.cellular", 300); // (Default = 10)
pref("media.throttle-cellular-regardless-of-download-rate", false); // [HIDDEN - non-Android] [DEFAULT - non-Android]
pref("image.mem.decode_bytes_at_a_time", 65536);
pref("network.dnsCacheExpiration", 3600); // (Default = 60)
pref("network.dnsCacheEntries", 10000); // (Default = 1600)
pref("media.cache_size.cellular", 512000);
pref("image.cache.size", 20971520); // [ESR] [DEFAULT]
pref("media.memory_cache_max_size", 262144); // (Default = 8192)
pref("media.memory_caches_combined_limit_kb", 1048576); // (Default = 524288)
pref("browser.cache.memory.capacity", 131072); // (Default = -1)
pref("browser.cache.memory.max_entry_size", 20480); // (Default = 5120)
pref("gfx.content.skia-font-cache-size", 32);
pref("network.http.max-connections", 1800); // (Default = 128 for Android, 900 elsewhere)
pref("network.http.max-persistent-connections-per-proxy", 48); // (Default = 20 for Android, 32 elsewhere)
pref("network.http.max-persistent-connections-per-server", 10); // (Default = 6)
pref("network.http.max-urgent-start-excessive-connections-per-host", 5); // (Default = 3)
pref("network.http.request.max-start-delay", 5); // (Default = 10)
pref("network.ssl_tokens_cache_capacity", 8192); // [ESR] [DEFAULT]
pref("network.tcp.notsent_lowat", 32768); // [DEFAULT - Nightly]
pref("network.tcp.user_timeout", 30); // [DEFAULT - Nightly]
pref("gfx.webrender.low-quality-pinch-zoom", true); // [DEFAULT - Android]
pref("browser.phoenix.status", "026");
pref("media.videocontrols.picture-in-picture.respect-disablePictureInPicture", false);
pref("apz.allow_zooming", true); // [DEFAULT]
pref("browser.ui.zoom.force-user-scalable", true);
pref("apz.allow_zooming_out", true);
pref("full-screen-api.transition-duration.enter", "0 0"); // [Default = 200 200]
pref("full-screen-api.transition-duration.leave", "0 0"); // [Default = 200 200]
pref("layout.css.control-characters.visible", true); // [DEFAULT - Nightly]
pref("layout.forms.input-type-search.enabled", true);
pref("print.more-settings.open", true);
pref("media.mediacapabilities.from-database", true); // [DEFAULT - Nightly]
pref("apz.autoscroll.enabled", true); // [DEFAULT]
pref("general.autoScroll", true); // [HIDDEN - Android] [DEFAULT - non-Android/Unix (excluding macOS, where it is on by default)]
pref("devtools.performance.aboutprofiling.has-developer-options", true);
pref("toolkit.aboutProcesses.showAllSubframes", true);
pref("editor.inline_table_editing.enabled_by_default", true);
pref("editor.positioning.enabled_by_default", true);
pref("editor.resizing.enabled_by_default", true);
pref("toolkit.aboutProcesses.showThreads", true); // [DEFAULT - Nightly]
pref("browser.ai.control.translations", "enabled"); // [NO-MAIL]
pref("browser.translations.automaticallyPopup", true); // [NO-MAIL] [DEFAULT]
pref("browser.translations.enable", true); // [NO-MAIL] [DEFAULT - non-Thunderbird]
pref("browser.translations.select.enable", true); // [NO-MAIL] [DEFAULT - non-Android/Thunderbird]
pref("browser.translations.simulateUnsupportedEngine", false); // [NO-MAIL] [DEFAULT]
pref("network.dns.disableIPv6", false); // [DEFAULT]
pref("apz.overscroll.enabled", true); // [DEFAULT]
pref("print.show_page_setup_menu", true);
pref("general.smoothScroll", true); // [DEFAULT]
pref("dom.manifest.enabled", true); // [NO-MAIL] [DEFAULT]
pref("nimbus.debug", true); // [HIDDEN - non-Firefox Desktop]
pref("nimbus.validation.enabled", false); // [HIDDEN - non-Firefox Desktop]
pref("browser.tabs.inTitlebar", 1);
pref("findbar.highlightAll", true);
pref("layout.word_select.eat_space_to_next_word", false); // [DEFAULT - non-Windows]
pref("toolkit.backgroundtasks.loglevel", "error"); // [HIDDEN] [DEFAULT]
pref("browser.policies.loglevel", "error"); // [NO-MAIL] [HIDDEN] [DEFAULT]
pref("services.settings.loglevel", "warn"); // [HIDDEN] [DEFAULT]
pref("toolkit.rust-components.logging.crates", ""); // [HIDDEN - non-Firefox Desktop] [DEFAULT]
pref("toolkit.rust-components.logging.internal-level", "Warn"); // [HIDDEN - non-Firefox Desktop] [DEFAULT]
pref("toolkit.mozprotocol.url", "about:mozilla"); // [HIDDEN]
pref("ui.key.menuAccessKeyFocuses", true); // [NO-OSX] [DEFAULT - Windows/Linux]
pref("browser.phoenix.status", "027");
pref("extensions.systemAddon.update.enabled", true); // [DEFAULT] https://searchfox.org/firefox-main/rev/82e2435f/toolkit/mozapps/extensions/AddonManager.sys.mjs#1317
pref("extensions.systemAddon.update.url", "https://aus5.mozilla.org/update/3/SystemAddons/%VERSION%/%BUILD_ID%/%BUILD_TARGET%/%LOCALE%/%CHANNEL%/%OS_VERSION%/%DISTRIBUTION%/%DISTRIBUTION_VERSION%/update.xml"); // [HIDDEN - Thunderbird] [DEFAULT - non-Thunderbird]
pref("extensions.update.autoUpdateDefault", true); // [HIDDEN - ANDROID] [DEFAULT] https://searchfox.org/firefox-main/rev/82e2435f/toolkit/mozapps/extensions/AddonManager.sys.mjs#4580
pref("extensions.update.enabled", true); // [DEFAULT] https://searchfox.org/firefox-main/rev/82e2435f/toolkit/mozapps/extensions/AddonManager.sys.mjs#1348
pref("extensions.update.interval", 3600);
pref("media.gmp-manager.secondsBetweenChecks", 3600); // [HIDDEN]
pref("extensions.checkUpdateSecurity", true); // [HIDDEN] [DEFAULT]
pref("app.update.checkOnlyInstance.enabled", true); // [HIDDEN] [DEFAULT]
pref("app.update.background.checkPolicy.throttleEnabled", false); // [HIDDEN] [DEFAULT - ESR]
pref("services.settings.poll_interval", 3600);
pref("browser.phoenix.status", "028");
pref("browser.phoenix.status", "029");
pref("browser.phoenix.status", "030");
pref("browser.phoenix.status", "successfully applied :D", locked);
pref("browser.phoenix.applied.cfg", true, locked);
